/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 06950
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1995
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 06950-0001-statasetup.do)
 |
 **************************************************************************/

set mem 50m  /* Allocating 50 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Household Survey on Drug Abuse, 1995, Dataset 0001"

#delimit ;
label define SKPMARTL  1 "Respondent is 12-14 years old"
                       2 "Respondent is 15 years old or older"
                       3 "12-14 years old LOGICALLY ASSIGNED"
                       4 "15 years or older LOGICALLY ASSIGNED" ;
label define MILSTAT   2 "In a reserves component"
                       3 "Now separated or retired from reserves/active duty"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EDUC      0 "No schooling" 1 "First grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "Freshman/13th year"
                       14 "Sophomore/14th year" 15 "Junior/15th year"
                       16 "Senior/16th year"
                       17 "Graduate/Professional School (or higher)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DIPLOMA   1 "High School Diploma" 2 "GED Certificate"
                       3 "Neither of the above"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ENROLLD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" ;
label define EENROLLD  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" ;
label define WORKSTAT  1 "Working full-time, 35 hours or more a week"
                       2 "Working part-time, less than 35 hours a week"
                       3 "Have a job but out: illness/leave/furlough/strike"
                       4 "Have a job but it is seasonal"
                       5 "Unemployed or laid off and looking for work"
                       6 "Unemployed and not looking for work"
                       7 "Full-time homemaker" 8 "In school only" 9 "Retired"
                       10 "Disabled for work" 11 "Other, not specified"
                       21 "Working full-time, 35 hours or more a week"
                       22 "Working part-time, less than 35 hours a week"
                       23 "Have a job but out: illness/leave/furlough/strike"
                       24 "Have a job, but it is seasonal"
                       25 "Unemployed or laid off and looking for work"
                       26 "Unemployed and not looking for work"
                       27 "Full-time homemaker" 28 "In school only"
                       30 "Disabled for work" 31 "Other, in labor force"
                       32 "Other, not in the labor force"
                       85 "BAD DATA Logically assigned"
                       98 "BLANK (NO ANSWER)" ;
label define HTININCH  985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       995 "BAD DATA" 996 "MULTIPLE RESPONSE" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define POUNDS    985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       995 "BAD DATA" 996 "MULTIPLE RESPONSE" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HEALTH    1 "Excellent" 2 "Very good" 3 "Good" 4 "Fair" 5 "Poor"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CIGEVER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 98 "BLANK (NO ANSWER)" ;
label define CIGTRY    981 "NEVER USED CIGARETTES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES" 994 "DON'T KNOW"
                       995 "BAD DATA" 998 "BLANK (NO ANSWER)" ;
label define CIGTOT    1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define CIGREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       91 "NEVER USED CIGARETTES" 98 "BLANK (NO ANSWER)" ;
label define CIG30USE  35 "Date specified within the past 30 days"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       83 "DID NOT USE CIGARETTES IN PAST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define AVCIG     1 "At least a puff but less than one cig each day"
                       2 "1 to 5 cigarettes each day"
                       3 "6 to 15 cigarettes (about 1/2 pack) each day"
                       4 "16 to 25 cigarettes (about 1 pack) each day"
                       5 "26 to 35 cigarettes (about 1 1/2 pk) each day"
                       6 "35 or more cigarettes (about 2 packs) each day"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       83 "DID NOT USE CIGARETTES PAST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define CIG30WOK  1 "5 minutes or less" 2 "6 to 30 minutes"
                       3 "31 to 60 minutes" 4 "1 to 3 hours"
                       5 "4 or more hours"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       83 "DID NOT USE CIGARETTES IN PAST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define CIGEVYDA  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 98 "BLANK (NO ANSWER)" ;
label define CIGAGE    981 "NEVER USED CIGARETTES Logically assigned"
                       983 "NEVER USED CIGARETTES EVERYDAY Log assn"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES"
                       993 "NEVER USED CIGARETTES EVERYDAY" 994 "DON'T KNOW"
                       995 "BAD DATA" 998 "BLANK (NO ANSWER)" ;
label define CIGYRS    0 "I smoked cigs every day but only for < one year"
                       981 "NEVER USED CIGARETTES Logically assigned"
                       983 "NEVER USED CIGARETTES EVERYDAY Log assn"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES"
                       993 "NEVER USED CIGARETTES EVERYDAY" 994 "DON'T KNOW"
                       995 "BAD DATA" 998 "BLANK (NO ANSWER)" ;
label define SNUFEVER  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       98 "BLANK (NO ANSWER)" ;
label define SNUFREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs."
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED SMOKELESS TOBACCO Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SMOKELESS TOBACCO"
                       98 "BLANK (NO ANSWER)" ;
label define SKPALCRD  1 "Yes, respondent can complete the answer sht. alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define ALCREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCEVER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" ;
label define ALCTRY    981 "NEVER USED ALCOHOL Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL" 994 "DON'T KNOW"
                       995 "BAD DATA" 998 "BLANK (NO ANSWER)" ;
label define ALCREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       91 "NEVER USED ALCOHOL" ;
label define ALCPAT    1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN PAST 12 MONTHS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define DRUNKYR   1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN PAST 12 MONTHS Log assn"
                       85 "BAD DATA Logically assigned"
                       90 "HAD A DRINK BUT DID NOT GET DRUNK PST 12 MONTHS"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define ALCDAYS   35 "Date specified within the past 30 days"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define NODR30A   81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define DR5DAY    0 "No days" 81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT DRINK ALCOHOL IN PAST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       90 "HAD A DRINK BUT NEVER MORE THAN 5 PAST 30 DAYS"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define MJEVER    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" ;
label define MJAGE     981 "NEVER USED MARIJUANA Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED MARIJUANA" 994 "DON'T KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define MJTOT     1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MJREC     1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       91 "NEVER USED MARIJUANA" ;
label define MJYRFREQ  1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJDAY30A  81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA IN THE PAST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SKPCOCRD  1 "Yes, respondent can complete the answer sht. alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define COCREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define COCEVER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" ;
label define COCAGE    981 "NEVER USED COCAINE Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED COCAINE" 994 "DON'T KNOW"
                       995 "BAD DATA" 998 "BLANK (NO ANSWER)" ;
label define COCTOT    1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED COCAINE Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE" 98 "BLANK (NO ANSWER)" ;
label define COCREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED COCAINE Logically assigned"
                       91 "NEVER USED COCAINE" ;
label define COCYRFRQ  1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 12 MONTHS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCUS30A  81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN THE PAST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN THE PAST 30 DAYS"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define SKPCRKRD  1 "Yes, respondent can complete answer sheet alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define CRKREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CRKEVER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 98 "BLANK (NO ANSWER)" ;
label define CRKAGE    981 "NEVER USED'CRACK' Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED'CRACK'" 995 "BAD DATA"
                       998 "BLANK (NO ANSWER)" ;
label define CRKTOT    1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED'CRACK' Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED'CRACK'" 98 "BLANK (NO ANSWER)" ;
label define CRAKREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED'CRACK' Logically assigned"
                       91 "NEVER USED'CRACK'" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define CRKYRFRQ  1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED'CRACK' Logically assigned"
                       83 "DID NOT USE'CRACK' PAST 12 MONTHS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED'CRACK'"
                       93 "DID NOT USE'CRACK' IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define CRKUS30A  81 "NEVER USED'CRACK' Logically assigned"
                       83 "DID NOT USE'CRACK' IN THE PAST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED'CRACK'"
                       93 "DID NOT USE'CRACK' IN THE PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define SKPHERRD  1 "Yes, respondent can complete answer sheet alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define HERREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HEREVER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERAGE    981 "NEVER USED HEROIN Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED HEROIN" 994 "DON'T KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HERTOT    1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED HEROIN Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED HEROIN Logically assigned"
                       91 "NEVER USED HEROIN" 94 "DON'T KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERYRFRQ  1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED HEROIN Logically assigned"
                       83 "DID NOT USE HEROIN PAST 12 MONTHS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HER30USE  81 "NEVER USED HEROIN Logically assigned"
                       83 "DID NOT USE HEROIN IN PAST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPHALRD  1 "Yes, respondent can complete answer sheet alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define HALREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LSD       1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (LSDREC=1,2,3,4 or 9)"
                       4 "No LOGICALLY ASSIGNED (LSDREC=91)"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define PCP       1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (PCPREC=1,2,3,4 or 9)"
                       4 "No LOGICALLY ASSIGNED (PCPREC=91)"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define PEYOTE    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define MESC      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define PSILCY    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define ECSTASY   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define HALDKNAM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define HALNOLST  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define HALNEWA   116 "Methaqualone, Parest, Quaalude, Sopor"
                       142 "Belladona" 267 "Marezine"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Met"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       459 "Ketamine" 502 "Spray paints"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       516 "Freon" 520 "Old paint"
                       524 "White-Out (see also 509)"
                       525 "Butane (see also 521,544)"
                       601 "LSD ('acid,''white lightning') (see also 618)"
                       603 "Mescaline" 604 "Psilocybin (mushrooms), shooms"
                       605 "PCP ('angel dust,' phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 609 "sic"
                       611 "Greens" 614 "MDA, Methylenedioxy amphetamine"
                       616 "DET, Dimethyltryptamine, DMT"
                       617 "Morning glory seeds"
                       618 "Acid paper, blotter (acid) (see also 601)"
                       622 "Microdot(s), purple microdot"
                       623 "Mickey, mickey mouse club, mickey mousers"
                       624 "Orange sunshine, sunshine, yellow sunshine"
                       625 "Window pane" 636 "STP" 637 "Purple haze"
                       639 "Cloves, Nutmeg" 649 "sic" 650 "Daytura" 675 "sic"
                       676 "sic" 677 "Skunk II" 678 "Banana peels"
                       679 "Hell bells" 680 "Tweak" 681 "Lovely" 682 "sic"
                       683 "sic" 684 "sic" 685 "sic" 686 "Spider in my feet"
                       687 "Spary" 688 "AMP" 703 "Opium"
                       802 "THC, cannabinol" 803 "sic" 852 "sic"
                       864 "Dramamine (OTC), Motion sickness pill (OTC)"
                       890 "sic" 9900 "NOT A DRUG"
                       9981 "NEVER USED HALLUCINOGENS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define HALNEWB   116 "Methaqualone, Parest, Quaalude, Sopor"
                       142 "Belladona" 267 "Marezine"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Met"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       459 "Ketamine" 502 "Spray paints"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       516 "Freon" 520 "Old paint"
                       524 "White-Out (see also 509)"
                       525 "Butane (see also 521,544)"
                       601 "LSD ('acid,''white lightning') (see also 618)"
                       603 "Mescaline" 604 "Psilocybin (mushrooms), shooms"
                       605 "PCP ('angel dust,' phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 609 "sic"
                       611 "Greens" 614 "MDA, Methylenedioxy amphetamine"
                       616 "DET, Dimethyltryptamine, DMT"
                       617 "Morning glory seeds"
                       618 "Acid paper, blotter (acid) (see also 601)"
                       622 "Microdot(s), purple microdot"
                       623 "Mickey, mickey mouse club, mickey mousers"
                       624 "Orange sunshine, sunshine, yellow sunshine"
                       625 "Window pane" 636 "STP" 637 "Purple haze"
                       639 "Cloves, Nutmeg" 649 "sic" 650 "Daytura" 675 "sic"
                       676 "sic" 677 "Skunk II" 678 "Banana peels"
                       679 "Hell bells" 680 "Tweak" 681 "Lovely" 682 "sic"
                       683 "sic" 684 "sic" 685 "sic" 686 "Spider in my feet"
                       687 "Spary" 688 "AMP" 703 "Opium"
                       802 "THC, cannabinol" 803 "sic" 852 "sic"
                       864 "Dramamine (OTC), Motion sickness pill (OTC)"
                       890 "sic" 9900 "NOT A DRUG"
                       9981 "NEVER USED HALLUCINOGENS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define HALNEWC   116 "Methaqualone, Parest, Quaalude, Sopor"
                       142 "Belladona" 267 "Marezine"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Met"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       459 "Ketamine" 502 "Spray paints"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       516 "Freon" 520 "Old paint"
                       524 "White-Out (see also 509)"
                       525 "Butane (see also 521,544)"
                       601 "LSD ('acid,''white lightning') (see also 618)"
                       603 "Mescaline" 604 "Psilocybin (mushrooms), shooms"
                       605 "PCP ('angel dust,' phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 609 "sic"
                       611 "Greens" 614 "MDA, Methylenedioxy amphetamine"
                       616 "DET, Dimethyltryptamine, DMT"
                       617 "Morning glory seeds"
                       618 "Acid paper, blotter (acid) (see also 601)"
                       622 "Microdot(s), purple microdot"
                       623 "Mickey, mickey mouse club, mickey mousers"
                       624 "Orange sunshine, sunshine, yellow sunshine"
                       625 "Window pane" 636 "STP" 637 "Purple haze"
                       639 "Cloves, Nutmeg" 649 "sic" 650 "Daytura" 675 "sic"
                       676 "sic" 677 "Skunk II" 678 "Banana peels"
                       679 "Hell bells" 680 "Tweak" 681 "Lovely" 682 "sic"
                       683 "sic" 684 "sic" 685 "sic" 686 "Spider in my feet"
                       687 "Spary" 688 "AMP" 703 "Opium"
                       802 "THC, cannabinol" 803 "sic" 852 "sic"
                       864 "Dramamine (OTC), Motion sickness pill (OTC)"
                       890 "sic" 9900 "NOT A DRUG"
                       9981 "NEVER USED HALLUCINOGENS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define HALNEWD   116 "Methaqualone, Parest, Quaalude, Sopor"
                       142 "Belladona" 267 "Marezine"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Met"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       459 "Ketamine" 502 "Spray paints"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       516 "Freon" 520 "Old paint"
                       524 "White-Out (see also 509)"
                       525 "Butane (see also 521,544)"
                       601 "LSD ('acid,''white lightning') (see also 618)"
                       603 "Mescaline" 604 "Psilocybin (mushrooms), shooms"
                       605 "PCP ('angel dust,' phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 609 "sic"
                       611 "Greens" 614 "MDA, Methylenedioxy amphetamine"
                       616 "DET, Dimethyltryptamine, DMT"
                       617 "Morning glory seeds"
                       618 "Acid paper, blotter (acid) (see also 601)"
                       622 "Microdot(s), purple microdot"
                       623 "Mickey, mickey mouse club, mickey mousers"
                       624 "Orange sunshine, sunshine, yellow sunshine"
                       625 "Window pane" 636 "STP" 637 "Purple haze"
                       639 "Cloves, Nutmeg" 649 "sic" 650 "Daytura" 675 "sic"
                       676 "sic" 677 "Skunk II" 678 "Banana peels"
                       679 "Hell bells" 680 "Tweak" 681 "Lovely" 682 "sic"
                       683 "sic" 684 "sic" 685 "sic" 686 "Spider in my feet"
                       687 "Spary" 688 "AMP" 703 "Opium"
                       802 "THC, cannabinol" 803 "sic" 852 "sic"
                       864 "Dramamine (OTC), Motion sickness pill (OTC)"
                       890 "sic" 9900 "NOT A DRUG"
                       9981 "NEVER USED HALLUCINOGENS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define HALNEWE   116 "Methaqualone, Parest, Quaalude, Sopor"
                       142 "Belladona" 267 "Marezine"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Met"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       459 "Ketamine" 502 "Spray paints"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       516 "Freon" 520 "Old paint"
                       524 "White-Out (see also 509)"
                       525 "Butane (see also 521,544)"
                       601 "LSD ('acid,''white lightning') (see also 618)"
                       603 "Mescaline" 604 "Psilocybin (mushrooms), shooms"
                       605 "PCP ('angel dust,' phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 609 "sic"
                       611 "Greens" 614 "MDA, Methylenedioxy amphetamine"
                       616 "DET, Dimethyltryptamine, DMT"
                       617 "Morning glory seeds"
                       618 "Acid paper, blotter (acid) (see also 601)"
                       622 "Microdot(s), purple microdot"
                       623 "Mickey, mickey mouse club, mickey mousers"
                       624 "Orange sunshine, sunshine, yellow sunshine"
                       625 "Window pane" 636 "STP" 637 "Purple haze"
                       639 "Cloves, Nutmeg" 649 "sic" 650 "Daytura" 675 "sic"
                       676 "sic" 677 "Skunk II" 678 "Banana peels"
                       679 "Hell bells" 680 "Tweak" 681 "Lovely" 682 "sic"
                       683 "sic" 684 "sic" 685 "sic" 686 "Spider in my feet"
                       687 "Spary" 688 "AMP" 703 "Opium"
                       802 "THC, cannabinol" 803 "sic" 852 "sic"
                       864 "Dramamine (OTC), Motion sickness pill (OTC)"
                       890 "sic" 9900 "NOT A DRUG"
                       9981 "NEVER USED HALLUCINOGENS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define HALLAGE   981 "NEVER USED HALLUCINOGENS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED HALLUCINOGENS" 994 "DON'T KNOW"
                       995 "BAD DATA" 998 "BLANK (NO ANSWER)" ;
label define HALLTOT   1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define HALLREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define HALYRFRQ  1 "More than 300 days (every day/almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than 1 day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED HALLUCINOGENS Logically assigned"
                       83 "DID NOT USE HALLUCINOGENS PST 12 MOS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 98 "BLANK (NO ANSWER)" ;
label define HAL30USE  81 "NEVER USED HALLUCINOGENS Logically assigned"
                       83 "DID NOT USE HALLUCINOGENS IN PAST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 98 "BLANK (NO ANSWER)" ;
label define LSDREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED LSD Logically assigned"
                       91 "NEVER USED LSD" 94 "DON'T KNOW" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define PCPREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED PCP Logically assigned"
                       91 "NEVER USED PCP" 94 "DON'T KNOW" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define SKPINHRD  1 "Yes, respondent can complete the answer sht. alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define INHREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AMYLNIT   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define CLEFLU    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define GAS       1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define GLUE      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define ETHER     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define SOLVENT   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define LGAS      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define NITOXID   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define SPPAINT   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define AEROS     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define INHDKNAM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define INHNOLST  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define INHNEWA   333 "357 Magnum, Magnum 44"
                       435 "Tylenol, Tylenol Extra Strength <OTC>"
                       501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       506 "Amyl nitrite,'poppers,' locker rm odorizer,'rush'"
                       508 "Nitrous oxide,'whippets,' dentist gas"
                       509 "Corr flds, degreasers, cleaning flds, Liquid Paper"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens" 515 "Vicks"
                       516 "Freon" 517 "sic" 519 "Helium"
                       524 "White-Out (see also 509)" 526 "Nail polish"
                       528 "Whipped-cream can"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       539 "ScotchGard" 540 "PAM"
                       545 "Car tailpipe exhaust fumes, CO2"
                       548 "Cologne, isopropanol vapors, rubbing alcohol"
                       551 "sic" 568 "sic" 576 "C.A.T." 578 "sic" 579 "sic"
                       580 "sic" 581 "sic" 582 "WD-40" 583 "sic" 584 "sic"
                       803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       9981 "NEVER USED INHALANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9998 "BLANK (NO ANSWER)" ;
label define INHNEWB   333 "357 Magnum, Magnum 44"
                       435 "Tylenol, Tylenol Extra Strength <OTC>"
                       501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       506 "Amyl nitrite,'poppers,' locker rm odorizer,'rush'"
                       508 "Nitrous oxide,'whippets,' dentist gas"
                       509 "Corr flds, degreasers, cleaning flds, Liquid Paper"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens" 515 "Vicks"
                       516 "Freon" 517 "sic" 519 "Helium"
                       524 "White-Out (see also 509)" 526 "Nail polish"
                       528 "Whipped-cream can"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       539 "ScotchGard" 540 "PAM"
                       545 "Car tailpipe exhaust fumes, CO2"
                       548 "Cologne, isopropanol vapors, rubbing alcohol"
                       551 "sic" 568 "sic" 576 "C.A.T." 578 "sic" 579 "sic"
                       580 "sic" 581 "sic" 582 "WD-40" 583 "sic" 584 "sic"
                       803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       9981 "NEVER USED INHALANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9998 "BLANK (NO ANSWER)" ;
label define INHNEWC   333 "357 Magnum, Magnum 44"
                       435 "Tylenol, Tylenol Extra Strength <OTC>"
                       501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       506 "Amyl nitrite,'poppers,' locker rm odorizer,'rush'"
                       508 "Nitrous oxide,'whippets,' dentist gas"
                       509 "Corr flds, degreasers, cleaning flds, Liquid Paper"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens" 515 "Vicks"
                       516 "Freon" 517 "sic" 519 "Helium"
                       524 "White-Out (see also 509)" 526 "Nail polish"
                       528 "Whipped-cream can"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       539 "ScotchGard" 540 "PAM"
                       545 "Car tailpipe exhaust fumes, CO2"
                       548 "Cologne, isopropanol vapors, rubbing alcohol"
                       551 "sic" 568 "sic" 576 "C.A.T." 578 "sic" 579 "sic"
                       580 "sic" 581 "sic" 582 "WD-40" 583 "sic" 584 "sic"
                       803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       9981 "NEVER USED INHALANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9998 "BLANK (NO ANSWER)" ;
label define INHNEWD   333 "357 Magnum, Magnum 44"
                       435 "Tylenol, Tylenol Extra Strength <OTC>"
                       501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       506 "Amyl nitrite,'poppers,' locker rm odorizer,'rush'"
                       508 "Nitrous oxide,'whippets,' dentist gas"
                       509 "Corr flds, degreasers, cleaning flds, Liquid Paper"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens" 515 "Vicks"
                       516 "Freon" 517 "sic" 519 "Helium"
                       524 "White-Out (see also 509)" 526 "Nail polish"
                       528 "Whipped-cream can"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       539 "ScotchGard" 540 "PAM"
                       545 "Car tailpipe exhaust fumes, CO2"
                       548 "Cologne, isopropanol vapors, rubbing alcohol"
                       551 "sic" 568 "sic" 576 "C.A.T." 578 "sic" 579 "sic"
                       580 "sic" 581 "sic" 582 "WD-40" 583 "sic" 584 "sic"
                       803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       9981 "NEVER USED INHALANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9998 "BLANK (NO ANSWER)" ;
label define INHNEWE   333 "357 Magnum, Magnum 44"
                       435 "Tylenol, Tylenol Extra Strength <OTC>"
                       501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       506 "Amyl nitrite,'poppers,' locker rm odorizer,'rush'"
                       508 "Nitrous oxide,'whippets,' dentist gas"
                       509 "Corr flds, degreasers, cleaning flds, Liquid Paper"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens" 515 "Vicks"
                       516 "Freon" 517 "sic" 519 "Helium"
                       524 "White-Out (see also 509)" 526 "Nail polish"
                       528 "Whipped-cream can"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       539 "ScotchGard" 540 "PAM"
                       545 "Car tailpipe exhaust fumes, CO2"
                       548 "Cologne, isopropanol vapors, rubbing alcohol"
                       551 "sic" 568 "sic" 576 "C.A.T." 578 "sic" 579 "sic"
                       580 "sic" 581 "sic" 582 "WD-40" 583 "sic" 584 "sic"
                       803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       9981 "NEVER USED INHALANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9998 "BLANK (NO ANSWER)" ;
label define INHAGE    981 "NEVER USED INHALANTS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED INHALANTS" 994 "DON'T KNOW"
                       995 "BAD DATA" 998 "BLANK (NO ANSWER)" ;
label define INHTOT    1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED INHALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define INHREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       7 "Use in past 30 days LOGICALLY ASSIGNED"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define INHYRFRQ  1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANTS IN PAST 12 MONTHS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define INHDY30A  81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANTS IN THE PAST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 30 DAYS"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define SKPANLRD  1 "Yes, respondent can complete answer sheet alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define ANLREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CODEINE   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DARVON    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEMEROL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DILAUD    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define METHDON   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MORPHINE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PERCODAN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TALWIN    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TYLCOD    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLDKNAM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLNOLST  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANALNEWA  105 "Placidyl" 109 "Seconal" 110 "Tuinal"
                       115 "Phenobarbital"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       124 "Yellow jackets" 125 "sic" 129 "Reds" 138 "sic"
                       161 "sic" 201 "Valium" 209 "Xanax"
                       225 "Desyrel, Trazodone hydrochloride, Trazora, Trialod"
                       234 "Cyclobenzaprine, Flexeril" 244 "sic"
                       311 "Preludin" 326 "White cross"
                       327 "Black beauties, Black Beauty"
                       332 "Ephedrine (HCl) (see also 346)"
                       334 "Crossroads, cross tops" 374 "Christmas tree(s)"
                       402 "Dolene" 404 "Wygesic" 405 "Levo-Dromoran"
                       406 "Oxycodone, Percodan, Roxicet" 407 "Demerol"
                       413 "Talacen" 415 "Codeine" 419 "Stadol"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       421 "USED ANALGESIC, DON'T KNOW NAME" 422 "Motrin"
                       423 "Percocet" 425 "Advil"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       427 "Darvocet" 431 "Tylox"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin"
                       435 "Tylenol, Tylenol Extra Strength (OTC)"
                       438 "Anaprox, Naprosyn" 439 "222, Canadian 222"
                       440 "Soma" 442 "Ibuprofen" 450 "Acetaminophen (OTC)"
                       455 "Fiorinal with Codeine"
                       456 "Lorcet HD, Lorcet Plus, Lortab (see also 434)"
                       458 "Mepergan, Mepergan Fortis" 463 "sic"
                       465 "Fentanyl" 484 "sic" 487 "Ariel" 488 "sic"
                       489 "sic" 490 "Nubain"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       811 "Muscle relaxers" 9900 "NOT A DRUG"
                       9981 "NEVER USED PAIN KILLERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED PAIN KILLERS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define ANALNEWB  105 "Placidyl" 109 "Seconal" 110 "Tuinal"
                       115 "Phenobarbital"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       124 "Yellow jackets" 125 "sic" 129 "Reds" 138 "sic"
                       161 "sic" 201 "Valium" 209 "Xanax"
                       225 "Desyrel, Trazodone hydrochloride, Trazora, Trialod"
                       234 "Cyclobenzaprine, Flexeril" 244 "sic"
                       311 "Preludin" 326 "White cross"
                       327 "Black beauties, Black Beauty"
                       332 "Ephedrine (HCl) (see also 346)"
                       334 "Crossroads, cross tops" 374 "Christmas tree(s)"
                       402 "Dolene" 404 "Wygesic" 405 "Levo-Dromoran"
                       406 "Oxycodone, Percodan, Roxicet" 407 "Demerol"
                       413 "Talacen" 415 "Codeine" 419 "Stadol"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       421 "USED ANALGESIC, DON'T KNOW NAME" 422 "Motrin"
                       423 "Percocet" 425 "Advil"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       427 "Darvocet" 431 "Tylox"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin"
                       435 "Tylenol, Tylenol Extra Strength (OTC)"
                       438 "Anaprox, Naprosyn" 439 "222, Canadian 222"
                       440 "Soma" 442 "Ibuprofen" 450 "Acetaminophen (OTC)"
                       455 "Fiorinal with Codeine"
                       456 "Lorcet HD, Lorcet Plus, Lortab (see also 434)"
                       458 "Mepergan, Mepergan Fortis" 463 "sic"
                       465 "Fentanyl" 484 "sic" 487 "Ariel" 488 "sic"
                       489 "sic" 490 "Nubain"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       811 "Muscle relaxers" 9900 "NOT A DRUG"
                       9981 "NEVER USED PAIN KILLERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED PAIN KILLERS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define ANALNEWC  105 "Placidyl" 109 "Seconal" 110 "Tuinal"
                       115 "Phenobarbital"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       124 "Yellow jackets" 125 "sic" 129 "Reds" 138 "sic"
                       161 "sic" 201 "Valium" 209 "Xanax"
                       225 "Desyrel, Trazodone hydrochloride, Trazora, Trialod"
                       234 "Cyclobenzaprine, Flexeril" 244 "sic"
                       311 "Preludin" 326 "White cross"
                       327 "Black beauties, Black Beauty"
                       332 "Ephedrine (HCl) (see also 346)"
                       334 "Crossroads, cross tops" 374 "Christmas tree(s)"
                       402 "Dolene" 404 "Wygesic" 405 "Levo-Dromoran"
                       406 "Oxycodone, Percodan, Roxicet" 407 "Demerol"
                       413 "Talacen" 415 "Codeine" 419 "Stadol"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       421 "USED ANALGESIC, DON'T KNOW NAME" 422 "Motrin"
                       423 "Percocet" 425 "Advil"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       427 "Darvocet" 431 "Tylox"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin"
                       435 "Tylenol, Tylenol Extra Strength (OTC)"
                       438 "Anaprox, Naprosyn" 439 "222, Canadian 222"
                       440 "Soma" 442 "Ibuprofen" 450 "Acetaminophen (OTC)"
                       455 "Fiorinal with Codeine"
                       456 "Lorcet HD, Lorcet Plus, Lortab (see also 434)"
                       458 "Mepergan, Mepergan Fortis" 463 "sic"
                       465 "Fentanyl" 484 "sic" 487 "Ariel" 488 "sic"
                       489 "sic" 490 "Nubain"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       811 "Muscle relaxers" 9900 "NOT A DRUG"
                       9981 "NEVER USED PAIN KILLERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED PAIN KILLERS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define ANALNEWD  105 "Placidyl" 109 "Seconal" 110 "Tuinal"
                       115 "Phenobarbital"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       124 "Yellow jackets" 125 "sic" 129 "Reds" 138 "sic"
                       161 "sic" 201 "Valium" 209 "Xanax"
                       225 "Desyrel, Trazodone hydrochloride, Trazora, Trialod"
                       234 "Cyclobenzaprine, Flexeril" 244 "sic"
                       311 "Preludin" 326 "White cross"
                       327 "Black beauties, Black Beauty"
                       332 "Ephedrine (HCl) (see also 346)"
                       334 "Crossroads, cross tops" 374 "Christmas tree(s)"
                       402 "Dolene" 404 "Wygesic" 405 "Levo-Dromoran"
                       406 "Oxycodone, Percodan, Roxicet" 407 "Demerol"
                       413 "Talacen" 415 "Codeine" 419 "Stadol"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       421 "USED ANALGESIC, DON'T KNOW NAME" 422 "Motrin"
                       423 "Percocet" 425 "Advil"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       427 "Darvocet" 431 "Tylox"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin"
                       435 "Tylenol, Tylenol Extra Strength (OTC)"
                       438 "Anaprox, Naprosyn" 439 "222, Canadian 222"
                       440 "Soma" 442 "Ibuprofen" 450 "Acetaminophen (OTC)"
                       455 "Fiorinal with Codeine"
                       456 "Lorcet HD, Lorcet Plus, Lortab (see also 434)"
                       458 "Mepergan, Mepergan Fortis" 463 "sic"
                       465 "Fentanyl" 484 "sic" 487 "Ariel" 488 "sic"
                       489 "sic" 490 "Nubain"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       811 "Muscle relaxers" 9900 "NOT A DRUG"
                       9981 "NEVER USED PAIN KILLERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED PAIN KILLERS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define ANALNEWE  105 "Placidyl" 109 "Seconal" 110 "Tuinal"
                       115 "Phenobarbital"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       124 "Yellow jackets" 125 "sic" 129 "Reds" 138 "sic"
                       161 "sic" 201 "Valium" 209 "Xanax"
                       225 "Desyrel, Trazodone hydrochloride, Trazora, Trialod"
                       234 "Cyclobenzaprine, Flexeril" 244 "sic"
                       311 "Preludin" 326 "White cross"
                       327 "Black beauties, Black Beauty"
                       332 "Ephedrine (HCl) (see also 346)"
                       334 "Crossroads, cross tops" 374 "Christmas tree(s)"
                       402 "Dolene" 404 "Wygesic" 405 "Levo-Dromoran"
                       406 "Oxycodone, Percodan, Roxicet" 407 "Demerol"
                       413 "Talacen" 415 "Codeine" 419 "Stadol"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       421 "USED ANALGESIC, DON'T KNOW NAME" 422 "Motrin"
                       423 "Percocet" 425 "Advil"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       427 "Darvocet" 431 "Tylox"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin"
                       435 "Tylenol, Tylenol Extra Strength (OTC)"
                       438 "Anaprox, Naprosyn" 439 "222, Canadian 222"
                       440 "Soma" 442 "Ibuprofen" 450 "Acetaminophen (OTC)"
                       455 "Fiorinal with Codeine"
                       456 "Lorcet HD, Lorcet Plus, Lortab (see also 434)"
                       458 "Mepergan, Mepergan Fortis" 463 "sic"
                       465 "Fentanyl" 484 "sic" 487 "Ariel" 488 "sic"
                       489 "sic" 490 "Nubain"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       811 "Muscle relaxers" 9900 "NOT A DRUG"
                       9981 "NEVER USED PAIN KILLERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED PAIN KILLERS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define ANALNONE  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANALAGE   981 "NEVER USED PAIN KILLERS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED PAIN KILLERS" 994 "DON'T KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ANALTOT   1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANALREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       91 "NEVER USED PAIN KILLERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLYRFRQ  1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED PAIN KILLERS Logically assigned"
                       83 "DID NOT USE PAIN KILLERS IN PST 12 MONTHS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN KILLERS"
                       93 "DID NOT USE PAIN KILLERS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPTRNRD  1 "Yes, I think resp can complete answer sheet alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define TRNREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ATARAX    1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ATIVAN    1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DIAZEPAM  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define LIBRIUM   1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRANXENE  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define VALIUM    1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define XANAX     1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRDKNAM   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRNOLST   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRNEWA    113 "Halcion"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       129 "Reds" 161 "sic" 168 "sic" 211 "Buspar"
                       212 "Miltown" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       234 "Cyclobenzaprine, Flexeril"
                       239 "Elavil (see also 228)" 241 "Prozac"
                       247 "Adapin, Doxepin, Sinequan" 271 "Zoloft"
                       345 "Black Molly"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       425 "Advil" 430 "Aspirin, Ecotrin, Empirin (OTC)"
                       435 "Tylenol, Tylenol Extra Strength (OTC)" 440 "Soma"
                       451 "sic"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define TRNEWB    113 "Halcion"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       129 "Reds" 161 "sic" 168 "sic" 211 "Buspar"
                       212 "Miltown" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       234 "Cyclobenzaprine, Flexeril"
                       239 "Elavil (see also 228)" 241 "Prozac"
                       247 "Adapin, Doxepin, Sinequan" 271 "Zoloft"
                       345 "Black Molly"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       425 "Advil" 430 "Aspirin, Ecotrin, Empirin (OTC)"
                       435 "Tylenol, Tylenol Extra Strength (OTC)" 440 "Soma"
                       451 "sic"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define TRNEWC    113 "Halcion"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       129 "Reds" 161 "sic" 168 "sic" 211 "Buspar"
                       212 "Miltown" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       234 "Cyclobenzaprine, Flexeril"
                       239 "Elavil (see also 228)" 241 "Prozac"
                       247 "Adapin, Doxepin, Sinequan" 271 "Zoloft"
                       345 "Black Molly"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       425 "Advil" 430 "Aspirin, Ecotrin, Empirin (OTC)"
                       435 "Tylenol, Tylenol Extra Strength (OTC)" 440 "Soma"
                       451 "sic"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define TRNEWD    113 "Halcion"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       129 "Reds" 161 "sic" 168 "sic" 211 "Buspar"
                       212 "Miltown" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       234 "Cyclobenzaprine, Flexeril"
                       239 "Elavil (see also 228)" 241 "Prozac"
                       247 "Adapin, Doxepin, Sinequan" 271 "Zoloft"
                       345 "Black Molly"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       425 "Advil" 430 "Aspirin, Ecotrin, Empirin (OTC)"
                       435 "Tylenol, Tylenol Extra Strength (OTC)" 440 "Soma"
                       451 "sic"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define TRNEWE    113 "Halcion"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       129 "Reds" 161 "sic" 168 "sic" 211 "Buspar"
                       212 "Miltown" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       234 "Cyclobenzaprine, Flexeril"
                       239 "Elavil (see also 228)" 241 "Prozac"
                       247 "Adapin, Doxepin, Sinequan" 271 "Zoloft"
                       345 "Black Molly"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       425 "Advil" 430 "Aspirin, Ecotrin, Empirin (OTC)"
                       435 "Tylenol, Tylenol Extra Strength (OTC)" 440 "Soma"
                       451 "sic"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define NOTRANQ   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRANAGE   981 "NEVER USED TRANQUILIZERS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED TRANQUILIZERS" 994 "DON'T KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define TRANTOT   1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRANREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRNYRFRQ  1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       83 "DID NOT USE TRANQUILIZERS PAST 12 MOS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPSTMRD  1 "Yes, I think respondent can complete it alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       98 "BLANK (NO ANSWER)" ;
label define STMREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BENZ      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BIPHET    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEXAMYL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEXED     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define FASTIN    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define IONAMIN   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define METHAMP   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define METHI     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PRELUDIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMDKNAM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMNOLST  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STIMNEWA  124 "Yellow jackets" 135 "Mini Thins" 241 "Prozac"
                       271 "Zoloft" 303 "Eskatrol"
                       307 "Tenuate, Diethylpropion"
                       308 "Tepanil, Diethylpropion" 309 "Didrex"
                       313 "Adipex-P, Fastin, Phentermine hydrochloride"
                       316 "Sanorex" 317 "Mazanor"
                       318 "Ritalin, Methylphenidate" 319 "Cylert"
                       320 "Dextroamphetamine"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Met"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       325 "USED STIMULANT, DON'T KNOW NAME"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       328 "Pink hearts" 329 "Robins eggs, speckled eggs"
                       331 "Blancas, Whites"
                       332 "Ephedrine (HCl) (see also 346)"
                       333 "357 Magnum, Magnum 44"
                       334 "Crossroads, cross tops"
                       339 "Amphetamines (speed generically)"
                       342 "Purple hearts" 345 "Black Molly"
                       347 "Phenylpropanolamine (OTC)" 348 "Crystal"
                       353 "No-Doz (OTC)" 354 "Vivarin (OTC)"
                       355 "Crystal meth" 358 "20/20" 359 "Criss cross"
                       366 "sic" 373 "sic" 374 "Christmas tree(s)"
                       382 "Footballs, purple footballs" 466 "Midol (OTC)"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       603 "Mescaline" 809 "Pills" 814 "Caffeine" 876 "Glass"
                       3001 "Brown and clear" 3002 "Pep ups"
                       3003 "Primatine tablets" 3004 "Black cadillac"
                       3005 "Methylandlanamine"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define STIMNEWB  124 "Yellow jackets" 135 "Mini Thins" 241 "Prozac"
                       271 "Zoloft" 303 "Eskatrol"
                       307 "Tenuate, Diethylpropion"
                       308 "Tepanil, Diethylpropion" 309 "Didrex"
                       313 "Adipex-P, Fastin, Phentermine hydrochloride"
                       316 "Sanorex" 317 "Mazanor"
                       318 "Ritalin, Methylphenidate" 319 "Cylert"
                       320 "Dextroamphetamine"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Met"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       325 "USED STIMULANT, DON'T KNOW NAME"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       328 "Pink hearts" 329 "Robins eggs, speckled eggs"
                       331 "Blancas, Whites"
                       332 "Ephedrine (HCl) (see also 346)"
                       333 "357 Magnum, Magnum 44"
                       334 "Crossroads, cross tops"
                       339 "Amphetamines (speed generically)"
                       342 "Purple hearts" 345 "Black Molly"
                       347 "Phenylpropanolamine (OTC)" 348 "Crystal"
                       353 "No-Doz (OTC)" 354 "Vivarin (OTC)"
                       355 "Crystal meth" 358 "20/20" 359 "Criss cross"
                       366 "sic" 373 "sic" 374 "Christmas tree(s)"
                       382 "Footballs, purple footballs" 466 "Midol (OTC)"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       603 "Mescaline" 809 "Pills" 814 "Caffeine" 876 "Glass"
                       3001 "Brown and clear" 3002 "Pep ups"
                       3003 "Primatine tablets" 3004 "Black cadillac"
                       3005 "Methylandlanamine"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define STIMNEWC  124 "Yellow jackets" 135 "Mini Thins" 241 "Prozac"
                       271 "Zoloft" 303 "Eskatrol"
                       307 "Tenuate, Diethylpropion"
                       308 "Tepanil, Diethylpropion" 309 "Didrex"
                       313 "Adipex-P, Fastin, Phentermine hydrochloride"
                       316 "Sanorex" 317 "Mazanor"
                       318 "Ritalin, Methylphenidate" 319 "Cylert"
                       320 "Dextroamphetamine"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Met"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       325 "USED STIMULANT, DON'T KNOW NAME"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       328 "Pink hearts" 329 "Robins eggs, speckled eggs"
                       331 "Blancas, Whites"
                       332 "Ephedrine (HCl) (see also 346)"
                       333 "357 Magnum, Magnum 44"
                       334 "Crossroads, cross tops"
                       339 "Amphetamines (speed generically)"
                       342 "Purple hearts" 345 "Black Molly"
                       347 "Phenylpropanolamine (OTC)" 348 "Crystal"
                       353 "No-Doz (OTC)" 354 "Vivarin (OTC)"
                       355 "Crystal meth" 358 "20/20" 359 "Criss cross"
                       366 "sic" 373 "sic" 374 "Christmas tree(s)"
                       382 "Footballs, purple footballs" 466 "Midol (OTC)"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       603 "Mescaline" 809 "Pills" 814 "Caffeine" 876 "Glass"
                       3001 "Brown and clear" 3002 "Pep ups"
                       3003 "Primatine tablets" 3004 "Black cadillac"
                       3005 "Methylandlanamine"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define STIMNEWD  124 "Yellow jackets" 135 "Mini Thins" 241 "Prozac"
                       271 "Zoloft" 303 "Eskatrol"
                       307 "Tenuate, Diethylpropion"
                       308 "Tepanil, Diethylpropion" 309 "Didrex"
                       313 "Adipex-P, Fastin, Phentermine hydrochloride"
                       316 "Sanorex" 317 "Mazanor"
                       318 "Ritalin, Methylphenidate" 319 "Cylert"
                       320 "Dextroamphetamine"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Met"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       325 "USED STIMULANT, DON'T KNOW NAME"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       328 "Pink hearts" 329 "Robins eggs, speckled eggs"
                       331 "Blancas, Whites"
                       332 "Ephedrine (HCl) (see also 346)"
                       333 "357 Magnum, Magnum 44"
                       334 "Crossroads, cross tops"
                       339 "Amphetamines (speed generically)"
                       342 "Purple hearts" 345 "Black Molly"
                       347 "Phenylpropanolamine (OTC)" 348 "Crystal"
                       353 "No-Doz (OTC)" 354 "Vivarin (OTC)"
                       355 "Crystal meth" 358 "20/20" 359 "Criss cross"
                       366 "sic" 373 "sic" 374 "Christmas tree(s)"
                       382 "Footballs, purple footballs" 466 "Midol (OTC)"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       603 "Mescaline" 809 "Pills" 814 "Caffeine" 876 "Glass"
                       3001 "Brown and clear" 3002 "Pep ups"
                       3003 "Primatine tablets" 3004 "Black cadillac"
                       3005 "Methylandlanamine"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define STIMNEWE  124 "Yellow jackets" 135 "Mini Thins" 241 "Prozac"
                       271 "Zoloft" 303 "Eskatrol"
                       307 "Tenuate, Diethylpropion"
                       308 "Tepanil, Diethylpropion" 309 "Didrex"
                       313 "Adipex-P, Fastin, Phentermine hydrochloride"
                       316 "Sanorex" 317 "Mazanor"
                       318 "Ritalin, Methylphenidate" 319 "Cylert"
                       320 "Dextroamphetamine"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Met"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       325 "USED STIMULANT, DON'T KNOW NAME"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       328 "Pink hearts" 329 "Robins eggs, speckled eggs"
                       331 "Blancas, Whites"
                       332 "Ephedrine (HCl) (see also 346)"
                       333 "357 Magnum, Magnum 44"
                       334 "Crossroads, cross tops"
                       339 "Amphetamines (speed generically)"
                       342 "Purple hearts" 345 "Black Molly"
                       347 "Phenylpropanolamine (OTC)" 348 "Crystal"
                       353 "No-Doz (OTC)" 354 "Vivarin (OTC)"
                       355 "Crystal meth" 358 "20/20" 359 "Criss cross"
                       366 "sic" 373 "sic" 374 "Christmas tree(s)"
                       382 "Footballs, purple footballs" 466 "Midol (OTC)"
                       530 "Asthma inhaler, asthma med., bronchial dilators"
                       603 "Mescaline" 809 "Pills" 814 "Caffeine" 876 "Glass"
                       3001 "Brown and clear" 3002 "Pep ups"
                       3003 "Primatine tablets" 3004 "Black cadillac"
                       3005 "Methylandlanamine"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define NOSTIMS   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STIMAGE   981 "NEVER USED STIMULANTS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED STIMULANTS" 994 "DON'T KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define STIMTOT   1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STIMREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMYRFRQ  1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       83 "DID NOT USE STIMULANTS IN PAST 12 MONTHS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPSEDRD  1 "Yes, I think that respondent can complete it alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define SEDREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DALMANE   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALCION   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define METHAQ    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NEMBUTAL  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PHENOBAR  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PLACIDYL  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SECONAL   1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TUINAL    1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDDKNAM  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDNOLST  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDNEWA   101 "Butisol" 104 "Mebaral" 106 "Doriden"
                       107 "Noludar"
                       112 "Rasepam, Restoril, Temaz, Temazepam"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       121 "USED SEDATIVE, DON'T KNOW NAME" 129 "Reds"
                       161 "sic" 169 "sic" 201 "Valium" 209 "Xanax"
                       343 "Nitroglycerine"
                       435 "Tylenol, Tylenol Extra Strength (OTC)"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define SEDNEWB   101 "Butisol" 104 "Mebaral" 106 "Doriden"
                       107 "Noludar"
                       112 "Rasepam, Restoril, Temaz, Temazepam"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       121 "USED SEDATIVE, DON'T KNOW NAME" 129 "Reds"
                       161 "sic" 169 "sic" 201 "Valium" 209 "Xanax"
                       343 "Nitroglycerine"
                       435 "Tylenol, Tylenol Extra Strength (OTC)"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define SEDNEWC   101 "Butisol" 104 "Mebaral" 106 "Doriden"
                       107 "Noludar"
                       112 "Rasepam, Restoril, Temaz, Temazepam"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       121 "USED SEDATIVE, DON'T KNOW NAME" 129 "Reds"
                       161 "sic" 169 "sic" 201 "Valium" 209 "Xanax"
                       343 "Nitroglycerine"
                       435 "Tylenol, Tylenol Extra Strength (OTC)"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define SEDNEWD   101 "Butisol" 104 "Mebaral" 106 "Doriden"
                       107 "Noludar"
                       112 "Rasepam, Restoril, Temaz, Temazepam"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       121 "USED SEDATIVE, DON'T KNOW NAME" 129 "Reds"
                       161 "sic" 169 "sic" 201 "Valium" 209 "Xanax"
                       343 "Nitroglycerine"
                       435 "Tylenol, Tylenol Extra Strength (OTC)"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define SEDNEWE   101 "Butisol" 104 "Mebaral" 106 "Doriden"
                       107 "Noludar"
                       112 "Rasepam, Restoril, Temaz, Temazepam"
                       116 "Methaqualone, Parest, Quaalude, Sopor"
                       121 "USED SEDATIVE, DON'T KNOW NAME" 129 "Reds"
                       161 "sic" 169 "sic" 201 "Valium" 209 "Xanax"
                       343 "Nitroglycerine"
                       435 "Tylenol, Tylenol Extra Strength (OTC)"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define NOSEDAT   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SEDAGE    981 "NEVER USED SEDATIVES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED SEDATIVES" 994 "DON'T KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SEDTOT    1 "More than 300 days"
                       2 "At least 101 but not more than 300 days"
                       3 "At least 12 but not more than 100 days"
                       4 "At least 3 but not more than 11 days"
                       5 "At least 1 but not more than 2 days"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDYRFRQ  1 "More than 300 days (every day or almost every day)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days ( 1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       83 "DID NOT USE SEDATIVES IN PAST 12 MONTHS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BIRMONTH  98 "BLANK (NO ANSWER)" ;
label define BIRYEAR   9998 "BLANK (NO ANSWER)" ;
label define IIAGE     1 "Age from birthdate"
                       2 "Age from cover of questionnaire"
                       3 "Age from roster"
                       4 "Age statistically imputed using age gr from roster" ;
label define IRSEX     1 "Male" 2 "Female" ;
label define IISEX     1 "Sex from questionnaire"
                       2 "Sex from relationship on roster"
                       3 "Sex from roster" ;
label define IRRACE    1 "American Indian or Alaskan native"
                       2 "Asian or Pacific islander" 3 "Black" 4 "White" ;
label define IIRACE    1 "Race from questionnaire"
                       2 "Race from interview observation"
                       3 "Race from roster"
                       4 "Race statis imputed using race -'Other' on roster"
                       5 "Race statistically imputed, no infor. from roster" ;
label define IRHOIND   1 "Hispanic" 2 "Nonhispanic" ;
label define IIHOIND   1 "Hispanicity derived from questionnaire"
                       2 "Hispanicity derived from roster" ;
label define IRHOGRP   1 "Puerto Rican" 2 "Mexican" 3 "Cuban" 4 "Other"
                       99 "LEGITIMATE SKIP" ;
label define IIHOGRP   1 "Hispanic-Origin Group taken from questionnaire"
                       3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP Respondent is not hispanic" ;
label define IRHOGRP2  1 "Puerto Rican" 2 "Mexican" 3 "Cuban" 4 "Other"
                       5 "Central American" 6 "South American" 7 "Caribbean"
                       99 "LEGITIMATE SKIP Respondent is not hispanic" ;
label define IIHOGRP2  1 "Hispanic-Origin Group taken from questionnaire"
                       3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP Respondent is not hispanic" ;
label define IRMARIT   1 "Married" 2 "Widowed" 3 "Divorced or Separated"
                       4 "Never Married" 99 "LEGITIMATE SKIP" ;
label define IIMARIT   1 "Questionnaire data" 3 "Statistically imputed data"
                       4 "Logically imputed data from roster"
                       5 "Statistically imputed data"
                       9 "LEGITIMATE SKIP (less than or =14 years old)" ;
label define IREDUC    0 "No schooling" 1 "First grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "Freshman/13th year"
                       14 "Sophomore/14th year" 15 "Junior/15th year"
                       16 "Senior/16th year"
                       17 "Graduate/Professional School (or higher)" ;
label define IIEDUC    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRHSGRAD  1 "Yes, graduated from high school"
                       2 "No, did not graduate from high school" ;
label define IIHSGRAD  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRWORKST  1 "Working full-time, 35 hours or more a week"
                       2 "Working part-time, less than 35 hours a week"
                       3 "Have a job, but not at work, illness/maternity"
                       4 "Have a job but not at work b/c it is seasonal"
                       5 "Unemployed or laid off and looking for work"
                       6 "Unemployed or laid off and not looking for work"
                       7 "Full-time homemaker" 8 "In school only" 9 "Retired"
                       10 "Disabled for work" 11 "Other, in labor force"
                       12 "Other, not in labor force" ;
label define IIWORKST  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRCIGRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never smoked cigarettes" ;
label define IICIGRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IROTBRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Never used smokeless tobacco" ;
label define IIOTBRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRALCRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used alcohol" ;
label define IIALCRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRMJRC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used marijuana" ;
label define IIMJRC    1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRCOCRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used cocaine" ;
label define IICOCRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRCRKRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used'CRACK'" ;
label define IICRKRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHERRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used heroin" ;
label define IIHERRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHALRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used hallucinogens" ;
label define IIHALRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRLSDRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used LSD" ;
label define IILSDRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRPCPRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used PCP" ;
label define IIPCPRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRINHRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used inhalants" ;
label define IIINHRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRANLRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used analgesics" ;
label define IIANLRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRTRNRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used tranquilizers" ;
label define IITRNRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSTMRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used stimulants" ;
label define IISTMRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSEDRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used sedatives" ;
label define IISEDRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRALCFQ   1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       10 "Never used or did not use in the past year" ;
label define IIALCFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRMJFQ    1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       10 "Never used or did not use in the past year" ;
label define IIMJFQ    1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRCOCFQ   1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       10 "Never used or did not use in the past year" ;
label define IICOCFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRCRKFQ   1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       10 "Never used or did not use in the past year" ;
label define IICRKFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHERFQ   1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       10 "Never used or did not use in the past year" ;
label define IIHERFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHALFQ   1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       10 "Never used or did not use in the past year" ;
label define IIHALFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRINHFQ   1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       10 "Never used or did not use in the past year" ;
label define IIINHFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRANLFQ   1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       10 "Never used or did not use in the past year" ;
label define IIANLFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRTRNFQ   1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       10 "Never used or did not use in the past year" ;
label define IITRNFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSTMFQ   1 "More than 300 days (every day or almost every day)"
                       2 "201 to 300 days (5 to 6 days a week)"
                       3 "101 to 200 days (3 to 4 days a week)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       10 "Never used or did not use in the past year" ;
label define IISTMFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSEDFQ   1 "More than 300 days (every day or almost every day)"
                       4 "51 to 100 days (1 to 2 days a week)"
                       5 "25 to 50 days (3 to 4 days a month)"
                       6 "12 to 24 days (1 to 2 days a month)"
                       7 "6 to 11 days (less than one day a month)"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 to 2 days in the past 12 months"
                       10 "Never used or did not use in the past year" ;
label define IISEDFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define CATAGE    1 "12-17 years" 2 "18-25 years" 3 "26-34 years"
                       4 "35+ years" ;
label define CATAG2    1 "12-17 years" 2 "18-25 years" 3 "26+ years" ;
label define CATAG3    1 "12-17 years" 2 "18-25 years" 3 "26-34 years"
                       4 "35-49 years" 5 "50+ years" ;
label define RACE      1 "White (IRRACE =4 and IRHOIND =2)"
                       2 "Black (IRRACE =3 and IRHOIND =2)"
                       3 "Hispanic (IRHOIND =1)"
                       4 "Other (IRRACE =1-2 and IRHOIND =2)" ;
label define HISPRACE  1 "Hispanic" 2 "Nonhispanic Black"
                       3 "Nonhispanic Nonblack" ;
label define EDUCCAT2  1 "Less than high school (IREDUC=0-11 and IRAGE=>18)"
                       2 "High school graduate (IREDUC =12 and IRAGE=>18)"
                       3 "Some college (IREDUC =13-15 and IRAGE => 18)"
                       4 "College graduate (IREDUC =16-17 and IRAGE => 18)"
                       5 "12-17 year olds (IRAGE =12-17)" ;
label define EMPSTAT2  1 "Full=time (IRWORKST =1,3 and IRAGE => 18)"
                       2 "Part-time (IRWORKST =2 and IRAGE => 18)"
                       3 "Unemployed (IRWORKST =4,5,6,11 and IRAGE => 18)"
                       4 "Other (IRWORKST =7,8,9,10,12 and IRAGE => 18)"
                       5 "12-17 year olds (IRAGE =12-17)" ;
label define MARISTAT  1 "Married (IRMARIT=1)"
                       2 "Not Married (IRMARIT=2,3,4)"
                       3 "LEGITIMATE SKIP (IRMARIT=99)" ;
label define NOTMAR    1 "Never Married (IRMARIT=4)"
                       2 "Divorced/Separated or Widowed (IRMARIT=2,3)"
                       3 "Married/Legitimate Skip (IRMARIT=1,99)" ;
label define CIGFLAG   0 "Never used (IRCIGRC =9)"
                       1 "Ever used (IRCIGRC =1-4)" ;
label define CIGYR     0 "Did not use in the past year (IRCIGRC =3,4,9)"
                       1 "Used within the past year (IRCIGRC =1,2)" ;
label define CIGMON    0 "Did not use in the past month (IRCIGRC =2-4,9)"
                       1 "Used within the past month (IRCIGRC =1)" ;
label define SMKFLAG   0 "Never used (IROTBRC =9)"
                       1 "Ever used (IROTBRC =1-4)" ;
label define SMKYR     0 "Did not use in the past year (IROTBRC =3,4,9)"
                       1 "Used within the past year (IROTBRC =1,2)" ;
label define SMKMON    0 "Did not use in the past month (IROTBRC =2-4,9)"
                       1 "Used within the past month (IROTBRC =1)" ;
label define ALCFLAG   0 "Never used (IRALCRC =9)"
                       1 "Ever used (IRALCRC =1-4)" ;
label define ALCYR     0 "Did not use in the past year (IRALCRC =3,4,9)"
                       1 "Used within the past year (IRALCRC =1,2)" ;
label define ALCMON    0 "Did not use in the past month (IRALCRC =2-4,9)"
                       1 "Used within the past month (IRALCRC =1)" ;
label define MRJFLAG   0 "Never used (IRMJRC =9)" 1 "Ever used (IRMJRC =1-4)" ;
label define MRJYR     0 "Did not use in the past year (IRMJRC =3,4,9)"
                       1 "Used within the past year (IRMJRC =1,2)" ;
label define MRJMON    0 "Did not use in the past month (IRMJRC =2-4,9)"
                       1 "Used within the past month (IRMJRC =1)" ;
label define COCFLAG   0 "Never used (IRCOCRC =9)"
                       1 "Ever used (IRCOCRC =1-4)" ;
label define COCYR     0 "Did not use in the past year (IRCOCRC =3,4,9)"
                       1 "Used within the past year (IRCOCRC =1,2)" ;
label define COCMON    0 "Did not use in the past month (IRCOCRC =2-4,9)"
                       1 "Used within the past month (IRCOCRC =1)" ;
label define CRKFLAG   0 "Never used (IRCRKRC =9)"
                       1 "Ever used (IRCRKRC =1-4)" ;
label define CRKYR     0 "Did not use in the past year (IRCRKRC =3,4,9)"
                       1 "Used within the past year (IRCRKRC =1,2)" ;
label define CRKMON    0 "Did not use in the past month (IRCRKRC =2-4,9)"
                       1 "Used within the past month (IRCRKRC =1)" ;
label define HERFLAG   0 "Never used (IRHERRC =9)"
                       1 "Ever used (IRHERRC =1-4)" ;
label define HERYR     0 "Did not use in the past year (IRHERRC =3,4,9)"
                       1 "Used within the past year (IRHERRC =1,2)" ;
label define HERMON    0 "Did not use in the past month (IRHERRC =2-4,9)"
                       1 "Used within the past month (IRHERRC =1)" ;
label define HALFLAG   0 "Never used (IRHALRC =9)"
                       1 "Ever used (IRHALRC =1-4)" ;
label define HALYR     0 "Did not use in the past year (IRHALRC =3,4,9)"
                       1 "Used within the past year (IRHALRC =1,2)" ;
label define HALMON    0 "Did not use in the past month (IRHALRC =2-4,9)"
                       1 "Used within the past month (IRHALRC =1)" ;
label define LSDFLAG   0 "Never used (IRLSDRC =9)"
                       1 "Ever used (IRLSDRC =1-4)" ;
label define LSDYR     0 "Did not use in the past year (IRLSDRC =3,4,9)"
                       1 "Used within the past year (IRLSDRC =1,2)" ;
label define LSDMON    0 "Did not use in the past month (IRLSDRC =2-4,9)"
                       1 "Used within the past month (IRLSDRC =1)" ;
label define PCPFLAG   0 "Never used (IRPCPRC =9)"
                       1 "Ever used (IRPCPRC =1-4)" ;
label define PCPYR     0 "Did not use in the past year (IRPCPRC =3,4,9)"
                       1 "Used within the past year (IRPCPRC =1,2)" ;
label define PCPMON    0 "Did not use in the past month (IRPCPRC =2-4,9)"
                       1 "Used within the past month (IRPCPRC =1)" ;
label define INHFLAG   0 "Never used (IRINHRC =9)"
                       1 "Ever used (IRINHRC =1-4)" ;
label define INHYR     0 "Did not use in the past year (IRINHRC =3,4,9)"
                       1 "Used within the past year (IRINHRC =1,2)" ;
label define INHMON    0 "Did not use in the past month (IRINHRC =2-4,9)"
                       1 "Used within the past month (IRINHRC =1)" ;
label define ANLFLAG   0 "Never used (IRANLRC =9)"
                       1 "Ever used (IRANLRC =1-4)" ;
label define ANLYR     0 "Did not use in the past year (IRANLRC =3,4,9)"
                       1 "Used within the past year (IRANLRC =1,2)" ;
label define ANLMON    0 "Did not use in the past month (IRANLRC =2-4,9)"
                       1 "Used within the past month (IRANLRC =1)" ;
label define TRQFLAG   0 "Never used (IRTRNRC =9)"
                       1 "Ever used (IRTRNRC =1-4)" ;
label define TRQYR     0 "Did not use in the past year (IRTRNRC =3,4,9)"
                       1 "Used within the past year (IRTRNRC =1,2)" ;
label define TRQMON    0 "Did not use in the past month (IRTRNRC =2-4,9)"
                       1 "Used within the past month (IRTRNRC =1)" ;
label define STMFLAG   0 "Never used (IRSTMRC =9)"
                       1 "Ever used (IRSTMRC =1-4)" ;
label define STMYR     0 "Did not use in the past year (IRSTMRC =3,4,9)"
                       1 "Used within the past year (IRSTMRC =1,2)" ;
label define STMMON    0 "Did not use in the past month (IRSTMRC =2-4,9)"
                       1 "Used within the past month (IRSTMRC =1)" ;
label define SEDFLAG   0 "Never used (IRSEDRC =9)"
                       1 "Ever used (IRSEDRC =1-4)" ;
label define SEDYR     0 "Did not use in the past year (IRSEDRC =3,4,9)"
                       1 "Used within the past year (IRSEDRC =1,2)" ;
label define SEDMON    0 "Did not use in the past month (IRSEDRC =2-4,9)"
                       1 "Used within the past month (IRSEDRC =1)" ;
label define ALCYRF    0 "Never used or not used in past year (IRALCFQ=10)"
                       1 "Any use within the past year (IRALCFQ=1-9)" ;
label define ALCMONF   0 "Did not use monthly/more past year (IRALCFQ=7-10)"
                       1 "Used monthly or more often past year (IRALCFQ=1-6)" ;
label define ALCWKF    0 "Did not use weekly or more pst year (IRALCFQ=5-10)"
                       1 "Used weekly or more in past year (IRALCFQ=1-4)" ;
label define ALCOCCF   0 "Used monthly/more or none pst yr (IRALCFQ=1-6,10)"
                       1 "Used past year but less than monthly (IRALCFQ=7-9)" ;
label define ALCDLYF   0 "Did not use daily/almost dly pst yr(IRALCFQ=4-10)"
                       1 "Used daily/almost daily in past year (IRALCFQ=1-3)" ;
label define MRJYRF    0 "Never used or did not use in past year (IRMJFQ=10)"
                       1 "Any use within the past year (IRMJFQ=1-9)" ;
label define MRJMONF   0 "Did not use monthly/more past year (IRMJFQ=7-10)"
                       1 "Used monthly or more in past year (IRMJFQ=1-6)" ;
label define MRJWKF    0 "Did not use weekly/more past year (IRMJFQ=5-10)"
                       1 "Used weekly or more in past year (IRMJFQ=1-4)" ;
label define MRJOCCF   0 "Used monthly/more or none in pst yr(IRMJFQ=1-6,10)"
                       1 "Used past year but less than monthly (IRMJFQ=7-9)" ;
label define MRJDLYF   0 "Did not use daily/almost daily pst yr(IRMJFQ=4-10)"
                       1 "Used daily/almost daily in past year (IRMJFQ=1-3)" ;
label define COCYRF    0 "Never used or did not use in pst year (IRCOCFQ=10)"
                       1 "Any use within the past year (IRCOCFQ =1-9)" ;
label define COCMONF   0 "Did not use monthly/more past year (IRCOCFQ=7-10)"
                       1 "Used monthly or more often past year (IRCOCFQ=1-6)" ;
label define COCWKF    0 "Did not use weekly or more pst year (IRCOCFQ=5-10)"
                       1 "Used weekly or more often past year (IRCOCFQ=1-4)" ;
label define COCOCCF   0 "Used monthly/more or none in pst yr(IRCOCFQ=1-6,9)"
                       1 "Used past year but less than monthly (IRCOCFQ=7-9)" ;
label define COCDLYF   0 "Did not use daily/almost dly pst yr(IRCOCFQ=4-10)"
                       1 "Used daily/almost daily in past year (IRCOCFQ=1-3)" ;
label define CRKYRF    0 "Never used or did not use in pst year (IRCRKFQ=10)"
                       1 "Any use within the past year (IRCRKFQ =1-9)" ;
label define CRKMONF   0 "Did not use monthly/more past year (IRCRKFQ=7-10)"
                       1 "Used monthly or more often past year (IRCRKFQ=1-6)" ;
label define CRKWKF    0 "Did not use weekly or more pst year (IRCRKFQ=5-10)"
                       1 "Used weekly or more often past year (IRCRKFQ=1-4)" ;
label define CRKOCCF   0 "Used monthly/more or none in pst yr(IRCRKFQ=1-6,9)"
                       1 "Used past year but less than monthly (IRCRKFQ=7-9)" ;
label define CRKDLYF   0 "Did not use daily/almost dly pst yr(IRCRKFQ=4-10)"
                       1 "Used daily/almost daily in past year (IRCRKFQ=1-3)" ;
label define HERYRF    0 "Never used or did not use in pst year (IRHERFQ=10)"
                       1 "Any use within the past year (IRHERFQ=1-9)" ;
label define HERMONF   0 "Did not use monthly/more past year (IRHERFQ=7-9)"
                       1 "Used monthly or more often past year (IRHERFQ=1-6)" ;
label define HERWKF    0 "Did not use weekly or more pst year (IRHERFQ=5-10)"
                       1 "Used weekly or more often past year (IRHERFQ=1-4)" ;
label define HEROCCF   0 "Used monthly/more or none pst yr(IRHERFQ=1-6,10)"
                       1 "Used past year but less than monthly (IRHERFQ=7-9)" ;
label define HERDLYF   0 "Did not use daily/almost daly pst yr(IRHERFQ=4-10)"
                       1 "Used daily/almost daily in past year (IRHERFQ=1-3)" ;
label define HALYRF    0 "Never used or did not use in pst year (IRHALFQ=10)"
                       1 "Any use within the past year (IRHALFQ=1-9)" ;
label define HALMONF   0 "Did not use monthly/more past year (IRHALFQ=7-10)"
                       1 "Used monthly or more often past year (IRHALFQ=1-6)" ;
label define HALWKF    0 "Did not use weekly or more pst year (IRHALFQ=5-10)"
                       1 "Used weekly or more often past year (IRHALFQ=1-4)" ;
label define HALOCCF   0 "Used monthly/more or none pst yr(IRHALFQ=1-6,10)"
                       1 "Used past year but less than monthly (IRHALFQ=7-9)" ;
label define HALDLYF   0 "Did not use daily/almost dly pst yr(IRHALFQ=4-10)"
                       1 "Used daily/almost daily in past year (IRHALFQ=1-3)" ;
label define INHYRF    0 "Never used or did not use in pst year (IRINHFQ=10)"
                       1 "Any use within the past year (IRINHFQ=1-9)" ;
label define INHMONF   0 "Did not use monthly/more past year (IRINHFQ=7-10)"
                       1 "Used monthly or more often past year (IRINHFQ=1-6)" ;
label define INHWKF    0 "Did not use weekly or more pst year (IRINHFQ=5-10)"
                       1 "Used weekly or more often past year (IRINHFQ=1-4)" ;
label define INHOCCF   0 "Used monthly/more or none pst yr(IRINHFQ=1-6,10)"
                       1 "Used past year but less than monthly (IRINHFQ=7-9)" ;
label define INHDLYF   0 "Did not use daily/almost dly pst yr(IRINHFQ=4-10)"
                       1 "Used daily/almost daily in past year (IRINHFQ=1-3)" ;
label define ANLYRF    0 "Never used or did not use in pst year (IRANLFQ=10)"
                       1 "Any use within the past year (IRANLFQ=1-9)" ;
label define ANLMONF   0 "Did not use monthly/more past year (IRANLFQ=7-10)"
                       1 "Used monthly or more often past year (IRANLFQ=1-6)" ;
label define ANLWKF    0 "Did not use weekly or more pst year (IRANLFQ=5-10)"
                       1 "Used weekly or more often past year (IRANLFQ=1-4)" ;
label define ANLOCCF   0 "Used monthly/more or none pst yr(IRANLFQ=1-6,10)"
                       1 "Used past year but less than monthly (IRANLFQ=7-9)" ;
label define ANLDLYF   0 "Did not use daily/almost dly pst yr(IRANLFQ=4-10)"
                       1 "Used daily/almost daily in past year (IRANLFQ=1-3)" ;
label define TRQYRF    0 "Never used or did not use in pst year (IRTRNFQ=10)"
                       1 "Any use within the past year (IRTRNFQ=1-9)" ;
label define TRQMONF   0 "Did not use monthly/more past year (IRTRNFQ=7-10)"
                       1 "Used monthly or more often past year (IRTRNFQ=1-6)" ;
label define TRQWKF    0 "Did not use weekly or more pst year (IRTRNFQ=5-10)"
                       1 "Used weekly or more often past year (IRTRNFQ=1-4)" ;
label define TRQOCCF   0 "Used monthly/more or none pst yr(IRTRNFQ=1-6,10)"
                       1 "Used past year but less than monthly (IRTRNFQ=7-9)" ;
label define TRQDLYF   0 "Did not use daily/almost dly pst yr(IRTRNFQ=4-10)"
                       1 "Used daily/almost daily in past year (IRTRNFQ=1-3)" ;
label define STMYRF    0 "Never used or did not use in pst year (IRSTMFQ=10)"
                       1 "Any use within the past year (IRSTMFQ=1-9)" ;
label define STMMONF   0 "Did not use monthly/more past year (IRSTMFQ=7-10)"
                       1 "Used monthly or more often past year (IRSTMFQ=1-6)" ;
label define STMWKF    0 "Did not use weekly or more pst year (IRSTMFQ=5-10)"
                       1 "Used weekly or more often past year (IRSTMFQ=1-4)" ;
label define STMOCCF   0 "Used monthly/more or none in pst yr(IRSTMFQ=1-6,9)"
                       1 "Used past year but less than monthly (IRSTMFQ=7-9)" ;
label define STMDLYF   0 "Did not use daily/almost dly pst yr(IRSTMFQ=4-10)"
                       1 "Used daily/almost daily in past year (IRSTMFQ=1-3)" ;
label define SEDYRF    0 "Never used or did not use in pst year (IRSEDFQ=10)"
                       1 "Any use within the past year (IRSEDFQ=1-9)" ;
label define SEDMONF   0 "Did not use monthly/more past year (IRSEDFQ=7-10)"
                       1 "Used monthly or more often past year (IRSEDFQ=1-6)" ;
label define SEDWKF    0 "Did not use weekly or more pst year (IRSEDFQ=5-10)"
                       1 "Used weekly or more often past year (IRSEDFQ=1-4)" ;
label define SEDOCCF   0 "Used monthly/more or none pst yr(IRSEDFQ=1-6,10)"
                       1 "Used past year but less than monthly (IRSEDFQ=7-9)" ;
label define SEDDLYF   0 "Did not use daily/almost dly pst yr(IRSEDFQ=4-10)"
                       1 "Used daily/almost daily in past year (IRSEDFQ=1-3)" ;
label define PSYFLAG2  0 "Never used (ALL SOURCE VARIABLES =9)"
                       1 "Ever used (ANY SOURCE VARIABLE < 9)" ;
label define PSYYR2    0 "Did not use within past year (ALL SOURCE VARS > 2)"
                       1 "Used in past year (ANY SOURCE VARIABLE < 3)" ;
label define PSYMON2   0 "Did not use in past month (ALL SOURCE VARS > 1)"
                       1 "Used in past month (ANY SOURCE VARIABLE =1)" ;
label define SUMFLAG   0 "Never used (ALL SOURCE VARIABLES =0)"
                       1 "Ever used (ANY SOURCE VARIABLE =1)" ;
label define SUMYR     0 "Did not use in past year (ALL SOURCE VARS =0)"
                       1 "Used in past year (ANY SOURCE VARIABLE =1)" ;
label define SUMMON    0 "Did not use in past month (ALL SOURCE VARS =0)"
                       1 "Used in past month (ANY SOURCE VARIABLE =1)" ;
label define MJOFLAG   0 "Never used MJ/has used both MJ & anothr illct drug"
                       1 "Marijuana is only (illicit) drug ever used" ;
label define MJOYR2    0 "MJ not used past yr/Used MJ & othr drug past yr"
                       1 "Marijuana is only (illicit) drug in past year" ;
label define MJOMON2   0 "MJ not used past mnth/Used MJ & othr drug past mo"
                       1 "Marijuana only (illicit) drug in past month" ;
label define IEMFLAG   0 "Never used drug/used only marijuana"
                       1 "Illicit drug except for marijuana are ever used" ;
label define IEMYR     0 "Never used drug/used only marijuana past year"
                       1 "Illicit drug except for marijuana used past year" ;
label define IEMMON    0 "Never used drug/used only marijuana past month"
                       1 "Illicit drug except for marijuana used past month" ;
label define BINGEDRK  0 "Never/No 'Binge' ALC use (DR5DAY=0,81,83,90,91,93)"
                       1 "'Binge' alcohol use (DR5DAY =1-30)"
                       99 "Unknown (DR5DAY =85,94,95,98)" ;
label define HVYDRK2   0 "Never/No heavy ALC use(DR5DAY=0-4,81,83,90,91,93)"
                       1 "Heavy alcohol use (DR5DAY =5-30)"
                       99 "Unknown (DR5DAY =85,94,95,98)" ;
label define BINGEHVY  1 "Heavy alcohol use"
                       2 "'Binge' alcohol use but not heavy use"
                       3 "Past 30 day alcohol use but not 'binge' use"
                       4 "Did not use alcohol in the past 30 days"
                       99 "Unknown" ;
label define PEYOTE2   0 "No/Unknown (PEYOTE=2,81,91,94,98)"
                       1 "Yes (PEYOTE=1)" ;
label define MESC2     0 "No/Unknown (MESC=2,81,91,94,98)" 1 "Yes (MESC=1)" ;
label define PSILCY2   0 "No/Unknown (PSILCY=2,81,91,94,98)"
                       1 "Yes (PSILCY=1,3)" ;
label define ECSTASY2  0 "No/Unknown (ECSTASY=2,81,91,94,98)"
                       1 "Yes (ECSTASY=1)" ;
label define METHAMP2  0 "No/Unknown (METHAMP=2,81,91,94,97,98)"
                       1 "Yes (METHAMP=1,3)" ;
label define HERSMOK2  0 "No/Unknown (HERSMOKE=2,4,85,89,95,97,98,99)"
                       1 "Yes (HERSMOKE=1,3)" ;
label define HERSNIF2  0 "No/Unknown (HERSNIFF=2,4,85,89,95,97,98,99)"
                       1 "Yes (HERSNIFF=1,3)" ;
label define AMYLNIT2  0 "No/Unknown (AMYLNIT=2,81,91,98)"
                       1 "Yes (AMYLNIT=1,3)" ;
label define CLEFLU2   0 "No/Unknown (CLEFLU=2,81,91,98)"
                       1 "Yes (CLEFLU=1,3)" ;
label define GAS2      0 "No/Unknown (GAS=2,81,91,98)" 1 "Yes (GAS=1)" ;
label define GLUE2     0 "No/Unknown (GLUE=2,81,91,98)" 1 "Yes (GLUE=1,3)" ;
label define ETHER2    0 "No/Unknown (ETHER=2,81,91,98)" 1 "Yes (ETHER=1)" ;
label define SOLVENT2  0 "No/Unknown (SOLVENT=2,81,91,98)"
                       1 "Yes (SOLVENT=1)" ;
label define LGAS2     0 "No/Unknown (LGAS=2,81,91,98)" 1 "Yes (LGAS=1)" ;
label define NITOXID2  0 "No/Unknown (NITOXID=2,81,91,98)"
                       1 "Yes (NITOXID=1,3)" ;
label define SPPAINT2  0 "No/Unknown (SPPAINT=2,81,91,98)"
                       1 "Yes (SPPAINT=1)" ;
label define AEROS2    0 "No/Unknown (AEROS=2,81,91,98)" 1 "Yes (AEROS=1)" ;
label define CG04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define CG12      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SMOKELESS TOBACCO"
                       98 "BLANK (NO ANSWER)" ;
label define AL03      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MJ04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CC04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CK04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED'CRACK'" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HE04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 94 "DON'T KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LS04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define LS07      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED LSD"
                       94 "DON'T KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define LS08      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED PCP"
                       94 "DON'T KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define IN04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define PK04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define TR04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned"
                       98 "BLANK (NO ANSWER)" ;
label define ST04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define SE04      1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define SKPSDRD   1 "Yes, I think that respondent can complete it alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define SDREAD    1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HRANYFRM  1 "Yes, I have used heroin"
                       2 "No, I have never used heroin"
                       3 "Yes LOGICALLY ASSIGNED" 4 "No LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERSMOKE  1 "Yes, I have smoked heroin"
                       2 "No, I have used heroin, but never smoked it"
                       3 "Yes LOGICALLY ASSIGNED" 4 "No LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (HRANYFRM=2,4)"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (HRANYFRM =2, 4)" ;
label define HRSMKREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       83 "USED HEROIN BUT NEVER SMOKED IT Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (HRANYFRM=2,4)"
                       93 "USED HEROIN BUT NEVER SMOKED IT" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (HRANYFRM =2, 4)" ;
label define HERSNIFF  1 "Yes, I have sniffed (snorted) heroin"
                       2 "No, I have used heroin, but have never sniffed it"
                       3 "Yes LOGICALLY ASSIGNED" 4 "No LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (HRANYFRM=2,4)"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (HRANYFRM =2, 4)" ;
label define HRSNFREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       83 "USED HEROIN BUT NEVER SNIFFED IT Log assn"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (HRANYFRM=2,4)"
                       93 "USED HEROIN BUT NEVER SNIFFED IT" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (HRANYFRM =2, 4)" ;
label define GNNDLLIF  1 "Yes, I have used a needle to inject a drug"
                       2 "No, I have never used a needle to inject a drug"
                       3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define COCNEEDL  1 "Yes, I have used a needle to inject cocaine"
                       3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "USED COCAINE BUT NEVER WITH A NEEDLE Log assn"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF =2)"
                       91 "NEVER USED COCAINE"
                       93 "USED COCAINE BUT NEVER WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF =2)" ;
label define CONDLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "USED COCAINE BUT NEVER WITH A NEEDLE Log assn"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF =2)"
                       91 "NEVER USED COCAINE"
                       93 "USED COCAINE BUT NEVER WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF =2)" ;
label define HERNEEDL  1 "Yes, I have used a needle to inject heroin"
                       3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED HEROIN Logically assigned"
                       83 "USED HEROIN BUT NEVER W/NEEDLE Log assn"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF =2)"
                       91 "NEVER USED HEROIN"
                       93 "USED HEROIN BUT NEVER WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF =2)" ;
label define HRNDLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED HEROIN Logically assigned"
                       83 "USED HEROIN BUT NEVER WITH A NEEDLE Log assn"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF =2)"
                       91 "NEVER USED HEROIN"
                       93 "USED HEROIN BUT NEVER WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF =2)" ;
label define STNEEDLE  1 "Yes, I have used a needle to inject a stimulant"
                       3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       83 "USED STIMULANTS BUT NEVER WITH A NEEDLE Log assn"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF =2)"
                       91 "NEVER USED STIMULANTS"
                       93 "USED STIMULANTS BUT NEVER WITH A NEEDLE"
                       95 "BAD DATA" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF =2)" ;
label define STNDLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       83 "USED STIMULANTS BUT NEVER WITH A NEEDLE Log assn"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF =2)"
                       91 "NEVER USED STIMULANTS"
                       93 "USED STIMULANTS BUT NEVER WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF =2)" ;
label define GNNDREUS  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF =2)"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF =2)" ;
label define GNNDLSH1  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF =2)"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF =2)" ;
label define GNNDCLEN  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF =2)"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF =2)" ;
label define GNNDLSH2  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF =2)"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF =2)" ;
label define GNNDGET   1 "I bought the needle from a pharmacy"
                       2 "I got the needle from a needle exchange"
                       3 "I bought the needle on the street"
                       4 "I got the needle in a shooting gallery"
                       5 "I got the needle some other way"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF =2)"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF =2)" ;
label define GNNDGTSP  6 "Given by, stolen from a friend"
                       7 "Given by, stolen from a relative"
                       8 "Given by, stolen from someone, relation unspecfied"
                       9 "Came with drugs" 10 "Found it/got from a waste can"
                       12 "I got the needle from a needle exchange"
                       13 "I bought the needle on the street"
                       15 "Given by, stolen from medical facility/professionl"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF =2)" ;
label define SKPDRGRD  1 "Yes, I think that respondent can complete it alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       98 "BLANK (NO ANSWER)" ;
label define DRGREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define USEDCIG   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDALC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDMRJ   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDCOC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDHER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDHAL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDINH   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDANL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDTRN   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDSTM   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define USEDSED   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NODRUGYR  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY ASSIGNED"
                       4 "Response not circled LOGICALLY ASSIGNED"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRTMCIG   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define GRTMALC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define GRTMMRJ   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define GRTMCOC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define GRTMHER   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define GRTMHAL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define GRTMINH   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define GRTMANL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define GRTMTRN   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define GRTMSTM   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define GRTMSED   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define LAMTCIG   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define LAMTALC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define LAMTMRJ   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define LAMTCOC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define LAMTHER   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define LAMTHAL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define LAMTINH   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define LAMTANL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define LAMTTRN   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define LAMTSTM   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define LAMTSED   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define BTOLCIG   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define BTOLALC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define BTOLMRJ   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define BTOLCOC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define BTOLHER   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define BTOLHAL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define BTOLINH   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define BTOLANL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define BTOLTRN   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define BTOLSTM   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define BTOLSED   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define ACRDCIG   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define ACRDALC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define ACRDMRJ   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define ACRDCOC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define ACRDHER   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define ACRDHAL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define ACRDINH   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define ACRDANL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define ACRDTRN   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define ACRDSTM   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define ACRDSED   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define EMPBCIG   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define EMPBALC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define EMPBMRJ   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define EMPBCOC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define EMPBHER   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define EMPBHAL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define EMPBINH   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define EMPBANL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define EMPBTRN   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define EMPBSTM   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define EMPBSED   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define HLPBCIG   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define HLPBALC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define HLPBMRJ   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define HLPBCOC   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define HLPBHER   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define HLPBHAL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define HLPBINH   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define HLPBANL   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define HLPBTRN   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define HLPBSTM   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define HLPBSED   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define UCDCIG    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define UCDALC    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define UCDMRJ    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define UCDCOC    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define UCDHER    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define UCDHAL    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define UCDINH    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define UCDANL    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define UCDTRN    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define UCDSTM    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define UCDSED    1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (NODRUGYR =1,3)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NODRUGYR =1,3)" ;
label define SKPSPTRD  1 "Yes, I think that respondent can complete it alone"
                       2 "No, I doubt that resp. can complt it alone - SKIP"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define SPTREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXRCVD  1 "Yes, I received treatment in the past 12 months"
                       2 "No, I have not received trmt in past 12 months"
                       5 "Yes, recvd Tx pst 12 mos and NDTXNEED 'YES'"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NDTXNEED  1 "Yes, I needed trmt/counseling during pst 12 mos"
                       2 "No, I did not need trmt/counseling in pst 12 mos"
                       3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Log assn (NDTXRCVD=1)"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXRCVD=1)" ;
label define NDTXALC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXMJ    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXCOC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXHER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXHAL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXINH   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXANL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXTRAN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXSTIM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXSED   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXSOD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXDRG1  322 "Methamphetamine ('speed' or 'ice' or 'crank')"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       818 "Nicotine" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define NDTXDRG2  322 "Methamphetamine ('speed' or 'ice' or 'crank')"
                       813 "Cigarettes, smoking (subst spec), tobacco not spec"
                       818 "Nicotine" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define NDTXDRG3  9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXDRG4  9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXDRG5  9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXSTEP  1 "Yes, I took steps to obtain trmt past 12 months"
                       2 "No, during the past 12 months, I did not take step"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXTRSP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXTFAR  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXBDHR  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXOPEN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXTYPE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXMONY  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXHCAP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXTCMP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXLANG  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXSPSV  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXSOR   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define NDTXRSC1  5 "Programs did not offer what I wanted"
                       12 "Did not need it"
                       13 "Do not have a problem/feeling OK now"
                       14 "Do not want to (quit/get treatment)"
                       15 "Was using at the time/not ready/unmotivated"
                       16 "Can do it myself"
                       17 "Do not know where to go/did not look for"
                       19 "Lack of time"
                       20 "Shame/wanted to hide problem (from parents)"
                       21 "Unsuccessful in the past"
                       22 "Conflict with spouse"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NDTXNEED=2,89,99)"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NDTXNEED=2,89,99)" ;
label define BOOKED    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NOBOOKYR  83 "NOT BEEN ARRSTD & BKD PAST 12 MONTHS Log assn"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (BOOKED=2)"
                       93 "NOT ARRESTED AND BOOKED PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (BOOKED=2)" ;
label define BKLARCNY  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKBURGL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKAGASLT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKSMASLT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKMVTHFT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKROB     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKRAPE    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKMURDER  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKARSON   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKDRVINF  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKDRUNK   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKDRUG    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKPROS    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKVANDAL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKOTH     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn (NOBOOKYR=83,89,93,99)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)" ;
label define BKOTHOFF  1 "Larceny or theft"
                       2 "Burglary or breaking and entering"
                       3 "Aggravated assault"
                       4 "Other assault, such as simple assault or battery"
                       10 "Driving under the influence"
                       11 "Drunkenness or other liquor law violation"
                       12 "Possession or sale of drugs"
                       14 "Oth proprty offns:- fraud, poss stln goods, vndlsm"
                       15 "Other offenses (NOT SPECIFIED)"
                       16 "Weapons offenses"
                       17 "Other offenses against persons"
                       18 "Violation of court order, parole, probation"
                       19 "Public order offenses"
                       20 "Juvenile status offenses" 22 "Traffic violations"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PROBATON  1 "Yes" 2 "No" 95 "BAD DATA" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PAROLE    1 "Yes, I was on parole during the past 12 months"
                       2 "No, I was not on parole during the past 12 months"
                       95 "BAD DATA" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STRSTEAL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTHSTEAL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DAMAGE    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CARSTEAL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FORCEMON  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BREAKIN   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PHYFIGHT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HURTBAD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GUNMONEY  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRVALDR   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRIVEAL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRIVEDR   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SOLDDRUG  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTHDOING  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTHDOSP1  1 "Shoplifting" 2 "Other larceny or theft"
                       3 "Property damage/destruction (incl. vandalism)"
                       4 "Motor vehicle theft" 6 "Breaking and entering"
                       7 "Hitting someone or physically fighting"
                       8 "Hurting someone enough to need medical attn"
                       9 "Other assault, battery"
                       10 "Driving under the influence of alcohol or drugs"
                       11 "Selling illegal drugs"
                       12 "Drug offense (except sales) involving marijuana"
                       13 "Other drug_related offenses"
                       14 "Drunkenness or other liquor law violation"
                       17 "Other offenses against persons" 18 "Arson"
                       19 "Nondestructive prop offenses, fraud, stln goods"
                       20 "Prostitution of commercialized sex"
                       21 "Weapons offenses"
                       22 "Violation of court order, parole, probation"
                       23 "Public order offenses"
                       24 "Juvenile status offenses" 26 "Traffic violations"
                       27 "Other offenses, NOT SPECIFIED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTHDOSP2  1 "Shoplifting" 2 "Other larceny or theft"
                       3 "Property damage/destruction (incl. vandalism)"
                       4 "Motor vehicle theft" 6 "Breaking and entering"
                       7 "Hitting someone or physically fighting"
                       8 "Hurting someone enough to need medical attn"
                       9 "Other assault, battery"
                       10 "Driving under the influence of alcohol or drugs"
                       11 "Selling illegal drugs"
                       12 "Drug offense (except sales) involving marijuana"
                       13 "Other drug_related offenses"
                       14 "Drunkenness or other liquor law violation"
                       17 "Other offenses against persons" 18 "Arson"
                       19 "Nondestructive prop offenses, fraud, stln goods"
                       20 "Prostitution of commercialized sex"
                       21 "Weapons offenses"
                       22 "Violation of court order, parole, probation"
                       23 "Public order offenses"
                       24 "Juvenile status offenses" 26 "Traffic violations"
                       27 "Other offenses, NOT SPECIFIED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SKPTMTRD  1 "Yes, I think that respondent can complete it alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define TMTREAD   1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXEVER    1 "Yes, I have received treatment for alc/drug use"
                       2 "No, I have never received treat. alc/drug use"
                       3 "Yes, rcvd trmt for alc/drug use LOG ASSN"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TXTIMELF  0 "No times" 985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       994 "DON'T KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXYRFREQ  0 "No times" 985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       994 "DON'T KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALHOSP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALRFIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALRFOP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALMHC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALEMRG  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALDOC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALJAIL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALSHG   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALSOP   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXALSP    4 "AA or NA or CA" 5 "Residential placement"
                       9 "Within myself (self-treatment)"
                       10 "Church or religious influence" 12 "Friends"
                       13 "Court or correctional facilities"
                       14 "Counselor, therapist, psychologist" 15 "School"
                       17 "Employer's hotline, job Corps, on the job"
                       18 "Homeless shelter" 19 "Alternative medicine"
                       22 "Hospital" 24 "Drug treatment or rehab. center"
                       25 "Mental health center" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRHOSP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRFIN   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRFOP   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRMHC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDREMRG  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXDRSP    4 "AA or NA or CA" 5 "Residential placement"
                       9 "Within myself (self-treatment)"
                       10 "Church or religious influence" 12 "Friends"
                       13 "Court or correctional facilities"
                       14 "Counselor, therapist, psychologist" 15 "School"
                       17 "Employer's hotline, job Corps, on the job"
                       18 "Homeless shelter" 19 "Alternative medicine"
                       22 "Hospital" 24 "Drug treatment or rehab. center"
                       25 "Mental health center" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXYREMRG  0 "No times" 985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXADGREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos."
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Use in past year LOGICALLY ASSIGNED"
                       9 "Use in lifetime LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       91 "NEVER USED ALCOHOL OR DRUGS"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTHOSP  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TXLTRFIN  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TXLTRFOP  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TXLTMHC   1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TXLTEMRG  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TXLTDOC   1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TXLTJAIL  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TXLTSHG   1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TXLTSOP   1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED"
                       6 "Response not marked LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TXLTSP    4 "AA or NA or CA" 5 "Residential placement"
                       9 "Within myself (self-treatment)"
                       10 "Church or religious influence" 12 "Friends"
                       13 "Court or correctional facilities"
                       14 "Counselor, therapist, psychologist" 15 "School"
                       17 "Employer's hotline, job Corps, on the job"
                       18 "Homeless shelter" 19 "Alternative medicine"
                       22 "Hospital" 24 "Drug treatment or rehab. center"
                       25 "Mental health center" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTALC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTMJ    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTCOC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTHER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTHAL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTINH   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTANL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTRAN   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTSTIM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTSED   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTSOD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTA     127 "Nytol (OTC)"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       306 "Desoxyn, Methamphetamine hydrochloride"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Me"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 401 "Darvon" 417 "Morphine"
                       418 "Methadone" 801 "OTHER Drugs, NOT SPECIFIED"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spe"
                       843 "Antihistamine, cold tablets (OTC)" 889 "sic"
                       9900 "NOT A DRUG" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXLTB     127 "Nytol (OTC)"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       306 "Desoxyn, Methamphetamine hydrochloride"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Me"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 401 "Darvon" 417 "Morphine"
                       418 "Methadone" 801 "OTHER Drugs, NOT SPECIFIED"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spe"
                       843 "Antihistamine, cold tablets (OTC)" 889 "sic"
                       9900 "NOT A DRUG" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXLTC     127 "Nytol (OTC)"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       306 "Desoxyn, Methamphetamine hydrochloride"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Me"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 401 "Darvon" 417 "Morphine"
                       418 "Methadone" 801 "OTHER Drugs, NOT SPECIFIED"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spe"
                       843 "Antihistamine, cold tablets (OTC)" 889 "sic"
                       9900 "NOT A DRUG" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXLTD     127 "Nytol (OTC)"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       306 "Desoxyn, Methamphetamine hydrochloride"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Me"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 401 "Darvon" 417 "Morphine"
                       418 "Methadone" 801 "OTHER Drugs, NOT SPECIFIED"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spe"
                       843 "Antihistamine, cold tablets (OTC)" 889 "sic"
                       9900 "NOT A DRUG" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXLTE     127 "Nytol (OTC)"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       306 "Desoxyn, Methamphetamine hydrochloride"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Me"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth" 401 "Darvon" 417 "Morphine"
                       418 "Methadone" 801 "OTHER Drugs, NOT SPECIFIED"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       813 "Cigarettes, smoking (subst spec), tobacco not spe"
                       843 "Antihistamine, cold tablets (OTC)" 889 "sic"
                       9900 "NOT A DRUG" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXDRGA    110 "Tuinal" 127 "Nytol (OTC)" 201 "Valium"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       225 "Desyrel, Trazodone hydrochloride, Trazora, Trialo"
                       240 "Lithium carbonate"
                       259 "Desipramine, Norpramin, Pertofrane"
                       262 "Prolixin"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Me"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       418 "Methadone" 427 "Darvocet"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin"
                       440 "Soma" 502 "Spray paints"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       520 "Old paint"
                       601 "LSD ('acid,' 'white lightning') (see also 618)"
                       606 "sic" 607 "OTHER Hallucinogen, NOT SPECIFIED"
                       702 "Heroin" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "sic" 804 "Hashish" 805 "Cocaine, coca, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       811 "Muscle relaxers"
                       813 "Cigarettes, smoking (subst spec), tobacco not spe"
                       818 "Nicotine" 843 "Antihistamine, cold tablets (OTC)"
                       9900 "NOT A DRUG" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXDRGB    110 "Tuinal" 127 "Nytol (OTC)" 201 "Valium"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       225 "Desyrel, Trazodone hydrochloride, Trazora, Trialo"
                       240 "Lithium carbonate"
                       259 "Desipramine, Norpramin, Pertofrane"
                       262 "Prolixin"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Me"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       418 "Methadone" 427 "Darvocet"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin"
                       440 "Soma" 502 "Spray paints"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       520 "Old paint"
                       601 "LSD ('acid,' 'white lightning') (see also 618)"
                       606 "sic" 607 "OTHER Hallucinogen, NOT SPECIFIED"
                       702 "Heroin" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "sic" 804 "Hashish" 805 "Cocaine, coca, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       811 "Muscle relaxers"
                       813 "Cigarettes, smoking (subst spec), tobacco not spe"
                       818 "Nicotine" 843 "Antihistamine, cold tablets (OTC)"
                       9900 "NOT A DRUG" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXDRGC    110 "Tuinal" 127 "Nytol (OTC)" 201 "Valium"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       225 "Desyrel, Trazodone hydrochloride, Trazora, Trialo"
                       240 "Lithium carbonate"
                       259 "Desipramine, Norpramin, Pertofrane"
                       262 "Prolixin"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Me"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       418 "Methadone" 427 "Darvocet"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin"
                       440 "Soma" 502 "Spray paints"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       520 "Old paint"
                       601 "LSD ('acid,' 'white lightning') (see also 618)"
                       606 "sic" 607 "OTHER Hallucinogen, NOT SPECIFIED"
                       702 "Heroin" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "sic" 804 "Hashish" 805 "Cocaine, coca, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       811 "Muscle relaxers"
                       813 "Cigarettes, smoking (subst spec), tobacco not spe"
                       818 "Nicotine" 843 "Antihistamine, cold tablets (OTC)"
                       9900 "NOT A DRUG" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXDRGD    110 "Tuinal" 127 "Nytol (OTC)" 201 "Valium"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       225 "Desyrel, Trazodone hydrochloride, Trazora, Trialo"
                       240 "Lithium carbonate"
                       259 "Desipramine, Norpramin, Pertofrane"
                       262 "Prolixin"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Me"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       418 "Methadone" 427 "Darvocet"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin"
                       440 "Soma" 502 "Spray paints"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       520 "Old paint"
                       601 "LSD ('acid,' 'white lightning') (see also 618)"
                       606 "sic" 607 "OTHER Hallucinogen, NOT SPECIFIED"
                       702 "Heroin" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "sic" 804 "Hashish" 805 "Cocaine, coca, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       811 "Muscle relaxers"
                       813 "Cigarettes, smoking (subst spec), tobacco not spe"
                       818 "Nicotine" 843 "Antihistamine, cold tablets (OTC)"
                       9900 "NOT A DRUG" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXDRGE    110 "Tuinal" 127 "Nytol (OTC)" 201 "Valium"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       225 "Desyrel, Trazodone hydrochloride, Trazora, Trialo"
                       240 "Lithium carbonate"
                       259 "Desipramine, Norpramin, Pertofrane"
                       262 "Prolixin"
                       322 "Methamphetamine ('speed' or 'ice' or 'crank'), Me"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       418 "Methadone" 427 "Darvocet"
                       434 "Co-Gesic, Hydrocodone, Lortab, Tussionex, Vicodin"
                       440 "Soma" 502 "Spray paints"
                       504 "Shoeshine liq, glue,toluene,Super Glue,rubber cem"
                       520 "Old paint"
                       601 "LSD ('acid,' 'white lightning') (see also 618)"
                       606 "sic" 607 "OTHER Hallucinogen, NOT SPECIFIED"
                       702 "Heroin" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "sic" 804 "Hashish" 805 "Cocaine, coca, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       811 "Muscle relaxers"
                       813 "Cigarettes, smoking (subst spec), tobacco not spe"
                       818 "Nicotine" 843 "Antihistamine, cold tablets (OTC)"
                       9900 "NOT A DRUG" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXOUTC    1 "Still in treatment"
                       2 "Successfully completed treatment"
                       3 "Had a problem with program"
                       4 "Couldn't afford to continue treatment"
                       5 "Family needed me" 6 "Began using drug(s) again"
                       7 "Other outcome, not specified"
                       8 "Didn't need treatment"
                       9 "Treatment is for lifetime"
                       10 "Successful because of own efforts, not trmt."
                       11 "Use to a lesser extent"
                       14 "Successful because of religious reasons"
                       15 "Discontinued treatment, success unknown"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXTIME    0 "No days"
                       9989 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       9994 "DON'T KNOW" 9995 "BAD DATA" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDINS   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDCARE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDCAID  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDSAVE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDFMLY  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDEMPL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDFREE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDSOS   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDSP    1 "Health Insurance" 2 "Own savings or earnings"
                       3 "Family member" 4 "Employer or union"
                       5 "Medicare or Medicaid" 6 "Free" 8 "Friend/Sponsor"
                       9 "State/city public assistance/welfare/relief"
                       10 "Court" 11 "Church" 12 "School"
                       14 "Veterans administration/military services"
                       15 "Treatment program" 16 "Indian Health Service"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXENROLL  1 "Yes, I was enrolled in treatment Oct. 1, 1994"
                       2 "No, I was not enrolled in treatment Oct. 1, 1994"
                       89 "LEGITIMATE SKIP Logically assigned (TXEVER=2)"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define SKPYCANS  1 "Respondent is 18 years or older - SKIP"
                       2 "Respondent is 12-17 years old"
                       3 "18 or older LOGICALLY ASSIGNED - SKIP"
                       4 "12 to 17 LOGICALLY ASSIGNED" ;
label define SKPYCRD   1 "Yes, I think that respondent can complete it alone"
                       2 "No, I doubt that resp. can complt. it alone - SKIP"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YCREAD    1 "Wants interviewer to read questions aloud"
                       2 "Wants to complete the answer sheet on his/her own"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YACTYNG   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YALLERGY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YARGUE    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YASTHMA   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YACOPPSX  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YLKANIML  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YBRAG     1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTRBCONC  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YCNTHGTS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTRBSIT   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDPTADLT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YFLONELY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YFLCONFU  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YCRYLOT   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YHONEST   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YMEANOTH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDAYDREM  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTRYKLSF  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTRYATTN  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDSTYTHG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDSTYOTH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDSBYPAR  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDSBYSCH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDNTEATW  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDNTKIDS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDNTGLTY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YJEALOTH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YHELPOTH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YAFRPLAC  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YAFRSCHL  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YAFRBAD   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YFLPRFCT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YFLNOLOV  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YFLGETME  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YFLWTHLS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YACCHURT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YFIGHTS   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YGTEASED  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YKIDSTRB  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YHRVOICS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YACTTNK   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YALONE    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YLIE      1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YBITNAIL  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YNERVOUS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YBTWITCH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YNGHTMAR  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YNOTKIDS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDOBETTR  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YANXIOUS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YFLDIZZY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YFLGUILT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YEATMUCH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YFLTIRED  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YOVRWGHT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YACHES    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YHEADACH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YNAUSEA   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YEYEPROB  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YRASHES   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YCRAMPS   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YVOMIT    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YATTACK   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YPKBPART  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YPFRNDLY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTRYTHNG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSCPOOR   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YCLUMSY   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YOLDKIDS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YYNGKIDS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YRFSTALK  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YREPACTN  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YRUNHOME  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSCREAM   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSECRET   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSEETHNG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSLFCONS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSETFIRE  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YWELHNDS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSHOWOFF  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSHY      1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSLPLESS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSLPMORE  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YGDIMAG   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSPCHPRB  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSTDRGHT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSTEALHO  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSTEALPL  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDNTNEED  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDOSTRNG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTHSTRNG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSTUBORN  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YMOODS    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YENJOY    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSUSPICS  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YDRTLANG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTHKKLSF  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YLKLAUGH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTALKMCH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTEASE    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTEMPER   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTHNKSEX  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTHRTPEO  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YLKHELP   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YCONNEAT  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTRBSLEP  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YSKIPSCH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YNOENRGY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUNHAPPY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YLOUDER   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUSEDRUG  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YFAIROTH  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YENJYJOK  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YLIFEASY  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YTRYHELP  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YWSOPPSX  1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YINVOTH   1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YWORRY    1 "Not true" 2 "Somewhat or sometimes true"
                       3 "Very true or often true"
                       89 "LEGITIMATE SKIP Logically assigned (SKPYCANS=3)"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MOVESPYR  0 "No times" 94 "DON'T KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STUDENT   1 "A full-time student" 2 "A part-time student"
                       3 "Not now enrolled in any school"
                       6 "Not now enrolled in any school LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define ESTUDENT  1 "A full-time student" 2 "A part-time student"
                       3 "Not now enrolled in any school"
                       6 "Not now enrolled in any school LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define SCHDAYS   0 "No days" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       90 "SCHOOL NOT IN SESSION" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ESCHDAYS  0 "No days" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       90 "SCHOOL NOT IN SESSION" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SKIPPED   0 "No days" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       90 "SCHOOL NOT IN SESSION" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ESKIPPED  0 "No days" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       90 "SCHOOL NOT IN SESSION" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NJOBSPYR  0 "No different employers" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PAYMO     85 "BAD DATA Logically assigned"
                       91 "NEVER WORKED FOR PAY" 94 "DON'T KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PAYYR     985 "BAD DATA Logically assigned"
                       991 "NEVER WORKED FOR PAY" 994 "DON'T KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SKPWKST3  1 "Work stat=Now in labor force (codes 1-4/21-24)"
                       2 "Work stat=Not in labor frc (5-11/25-31) - SKIP"
                       3 "Work stat=Now in labor force LOGICALLY ASSIGNED"
                       4 "Work stat=Not in labor frc LOG ASSN - SKIP"
                       98 "BLANK (NO ANSWER)" ;
label define WORKDAYS  0 "No days" 89 "LEGITIMATE SKIP Logically assigned"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKBLAH  0 "No days" 89 "LEGITIMATE SKIP Logically assigned"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPPREG   1 "Respondent is female less than 45 years old"
                       2 "Respondent is female 45 years or older - SKIP"
                       3 "Respondent is male - SKIP"
                       4 "Female less than 45 LOGICALLY ASSIGNED"
                       5 "Female 45 years or older LOGICALLY ASSIGNED - SKIP"
                       6 "Male LOGICALLY ASSIGNED - SKIP" ;
label define PREGNANT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PREGMOS   89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPCWE    1 "Yes - SKIP" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED - SKIP"
                       4 "No LOGICALLY ASSIGNED" ;
label define CWE       1 "Respondent" 2 "Someone else (specify)"
                       3 "Income equally by resp and someone else (spec)"
                       4 "No one" 6 "Someone else LOGICALLY ASSIGNED"
                       7 "Income eql by resp and someone else LOG ASSN"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CWESC1    8 "Respondent" 9 "Head of Household" 10 "Spouse"
                       20 "Parent/Guardian"
                       50 "Grandparent/Great+ Grandparent"
                       60 "Live-In Partner" 61 "Friend/Roommate/Companion"
                       71 "Cousin/Cousin's Spouse" 85 "Landlord/Home Owner"
                       90 "Other Relative, Gender not specified"
                       91 "Other Non-Relative, Gender not specified"
                       92 "Other, Relation and Gender Unspecified"
                       110 "Husband" 115 "Male In-Law"
                       120 "Father/Male Guardian"
                       121 "Step/Adopted/Foster Father/Future Step Father"
                       122 "Father/Step Father/Future Father In-Law"
                       130 "Son" 132 "Son In-Law" 133 "Grandson"
                       140 "Brother/Half Brother" 142 "Brother In-Law"
                       150 "Grandfather/Great+ Grandfather"
                       160 "Male Live-In Partner"
                       161 "Male Fiance/Boyfriend/Roommate/Companion"
                       170 "Uncle/Step Uncle/Aunt's Husband"
                       171 "Male Cousin" 172 "Nephew"
                       181 "Other Male God Relative"
                       191 "Other Male Non-Relative"
                       192 "Other Male, Relation Unspecified" 210 "Wife"
                       211 "Ex-Wife" 220 "Mother/Female Guardian"
                       221 "Step/Adopted/Foster Mother/Future Step Mother"
                       222 "Mother/Step Mother/Future Mother In-Law"
                       230 "Daughter" 232 "Daughter In-Law"
                       233 "Granddaughter" 240 "Sister/Half Sister"
                       241 "Step/Adopted/Foster Sister/Future Step Sister"
                       242 "Sister In-Law"
                       250 "Grandmother/Great+ Grandmother"
                       260 "Female Live-In Partner"
                       261 "Female Fiancee/Girlfriend/Roommate/Companion"
                       270 "Aunt" 272 "Niece"
                       285 "Female Landlord/Home Owner"
                       290 "Other Female Relative"
                       291 "Other Female Non-Relative"
                       292 "Other Female, Relation Unspecified"
                       309 "Head of Household" 315 "In-Laws"
                       320 "Parents/Guardians"
                       350 "Grandparents/Great+ Grandparents"
                       361 "Friends/Roommates/Companions"
                       371 "Cousins/Cousins' Spouses"
                       390 "Other Relatives, Gender not specified"
                       392 "Others, Relation and Gender Unspecified"
                       430 "Sons" 431 "Step/Adopted/Foster Sons"
                       440 "Brothers/Half Brothers"
                       540 "Sisters/Half Sisters" 570 "Aunts"
                       900 "NOT A PERSON" 985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define FULLPART  1 "Full-time" 2 "Part-time"
                       3 "Chief wage earner does not work"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPMHC    1 "Respondent is 18 years or older"
                       2 "Respondent is 12-17 years old - SKIP"
                       3 "18 or older LOGICALLY ASSIGNED"
                       4 "12 to 17 LOGICALLY ASSIGNED - SKIP" ;
label define DEPRESS   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPDAYS   1 "All day long" 2 "Most of the day"
                       3 "About half the day" 4 "Less than half the day"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPFREQ   1 "Every day" 2 "Almost every day" 3 "Less often"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LOSTINT1  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TIRED1    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WTCHNG1   1 "Gained weight" 2 "Lost weight"
                       3 "Both gained and lost weight" 4 "Stayed the same"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define LBSCHNG1  0 "No pounds" 989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define SLPLOSS1  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SLPFREQ1  1 "Every night" 2 "Nearly every night" 3 "Less often"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CONCEN1   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DOWN1     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define IDEAT1    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SKPDEP1   1 "Yes" 2 "No - SKIP" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED - SKIP"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPWKS1   85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPMO1    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPYR1    985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define LOSTINT2  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LOSINDAY  1 "All day long" 2 "Most of the day"
                       3 "About half the day" 4 "Less than half the day"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LOSINFRQ  1 "Every day" 2 "Almost every day" 3 "Less often"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TIRED2    1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WTCHNG2   1 "Gained weight" 2 "Lost weight"
                       3 "Both gained and lost weight" 4 "Stayed the same"
                       5 "Respondent was on a diet"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LBSCHNG2  989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SLPLOSS2  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SLPFREQ2  1 "Every night" 2 "Nearly every night" 3 "Less often"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CONCEN2   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DOWN2     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define IDEAT2    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SKPDEP2   1 "Yes" 2 "No - SKIP" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED - SKIP"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPWKS2   85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEPMO2    89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEPYR2    985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define WORRIED   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WOREND    1 "Ended" 2 "Still going on"
                       3 "Ended LOGICALLY ASSIGNED"
                       4 "Still going on LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORNOMO1  9989 "LEGITIMATE SKIP Logically assigned"
                       9994 "DON'T KNOW" 9995 "BAD DATA" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define WORHAPN1  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORSERI1  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORDIFF1  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORNOMO2  9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define WORHAPN2  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORSERI2  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORDIFF2  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPWOR    1 "Question HE-33 or HE-37 '6 months or more'"
                       2 "Question HE-33 or HE-37 'Less than 6 mo. - SKIP'"
                       3 "Q.HE-33 or HE-37 '6 mo. or more LOG ASSN'"
                       4 "Q.HE-33 or HE-37 '< 6 mo. LOG ASSN - SKIP'"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORREST   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WOREDGE   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORIRRIT  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORHEART  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORTIRED  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORSLEEP  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORFAINT  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FEARPUB   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FEAROUT   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FEARBRDG  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPFEAR1  1 "Any yes answer" 2 "All answered no - SKIP"
                       3 "Any yes answer LOGICALLY ASSIGNED"
                       4 "All answered no LOGICALLY ASSIGNED - SKIP"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FEAROFT   1 "Every time" 2 "Most of the time"
                       3 "Some of the time" 4 "Only one or two times"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FEARYRS   1 "Less than 1 year" 2 "Between 1 and 5 years"
                       3 "More than 5 years"
                       5 "Between 1 and 5 yrs LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FEARMOS   85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FEARFANT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FEARTRAP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FEARHELP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANIC1    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANIC2    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANICNUM  985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define PANICMO   89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PANICYR   985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define PANIDANG  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKPFEAR2  1 "Any yes answer" 2 "All answered no - SKIP"
                       3 "Any yes answer LOGICALLY ASSIGNED"
                       4 "All answered no LOGICALLY ASSIGNED - SKIP"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PANIFEAR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANINOFR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANIHART  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANIPAIN  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANISWET  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANISHAK  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANIHOT   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANIUNRL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NUERTMT   0 "No times" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NUHSPOV   0 "No nights" 94 "DON'T KNOW" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NUHSPPE   0 "No nights" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define OUTPTPE   1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PROXABLE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned (FAMSKIP=1)"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PROXYREL  1 "Respondent's spouse/live-in partner"
                       2 "Respondent's father" 3 "Respondent's mother"
                       4 "Respondent's brother" 5 "Respondent's sister"
                       6 "Other family member (specify relation to resp)"
                       20 "Parent/Guardian" 61 "Friend/Roommate/Companion"
                       71 "Cousin/Cousin's Spouse" 120 "Father/Male Guardian"
                       121 "Step/Adopted/Foster Father/Future Step Father"
                       130 "Son" 142 "Brother In-Law"
                       150 "Grandfather/Great+ Grandfather"
                       161 "Male Fiance/Boyfriend/Roommate/Companion"
                       170 "Uncle/Step Uncle/Aunt's Husband" 210 "Wife"
                       220 "Mother/Female Guardian"
                       221 "Step/Adopted/Foster Mother/Future Step Mother"
                       222 "Mother/Step Mother/Future Mother In-Law"
                       230 "Daughter" 242 "Sister In-Law"
                       250 "Grandmother/Great+ Grandmother"
                       251 "Step/Adopted/Foster/Great+ Grandmother"
                       261 "Female Fiancee/Girlfriend/Roommate/Companion"
                       270 "Aunt" 272 "Niece" 320 "Parents/Guardians"
                       530 "Daughters"
                       989 "LEGITIMATE SKIP Logically assigned" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define PROXHOME  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PROXJOIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CAREUSU   1 "Yes" 2 "No" 3 "Don't know"
                       4 "There is more than one place" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NCARERSN  1 "Two or more usual doctors/places"
                       2 "Don't need a doctor"
                       3 "Don't like/trust/believe in doctors"
                       4 "Don't know where to go"
                       5 "Previous doctor is not available/moved"
                       6 "No insurance/can't afford it"
                       7 "Speak a different language"
                       8 "No care available/care too far away/inconvenient"
                       9 "Other specify (see NCRRSNSP & NCRRSNSC)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NCRRSNSP  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NCRRSNSC  1 "Two or more usual doctors/places"
                       2 "Don't need a doctor"
                       3 "Don't like/trust/believe in doctors"
                       4 "Don't know where to go"
                       5 "Previous doctor is not available/moved"
                       6 "No insurance/can't afford it"
                       8 "No care available/care too far away or inconvenien"
                       10 "New to area/recently moved"
                       11 "Do not have a regular doctor"
                       12 "Self treatment/treatment by family member"
                       13 "Religious reasons"
                       14 "Health care plan determines source"
                       15 "Hospital/urgent care/clinic" 16 "School/workplace"
                       17 "Medicare/Medicaid/public assistance"
                       18 "Alternative medicine" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CAREOFT   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PYRCARE   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PYRCRTYP  1 "Doctor's office or private clinic"
                       2 "Company or school health clinic/center"
                       3 "Community/migrant/rural clinic or center"
                       4 "County/city/public hospital outpatient clinic"
                       5 "Private/other hospital outpatient clinic"
                       6 "Hospital emergency room" 7 "HMO"
                       9 "VA hospital or clinic"
                       10 "Military health care facility"
                       11 "Some other place specified (see PYRCRTSP/SC)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PYRCRTSP  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PYRCRTSC  2 "Company or school health clinic/center"
                       3 "Community/migrant/rural clinic or center"
                       5 "Private/other hospital outpatient clinic"
                       10 "Military health care facility"
                       12 "Self treatment/family member" 13 "Friend"
                       14 "Urgent care/walk-in medical facility"
                       16 "Alternative medicine" 18 "Family planning clinic"
                       19 "Indian clinic or hospital"
                       22 "Workman's Compensation health provider"
                       82 "ILLEGIBLE" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CARENOW   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MNRSNNCR  1 "Respondent changed residence/moved"
                       2 "Respondent changed jobs"
                       3 "Employer changed insurance companies"
                       4 "Formal usual source left area"
                       6 "Dissatsfd with frmr source/like new source better"
                       7 "Medical care needs changed"
                       8 "Frmr usual source stopped taking ins/coverage"
                       9 "Other reason specified (see MNRSNNSP/SC)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MNRSNNSP  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MNRSNNSC  1 "Respondent changed residence/moved"
                       4 "Former usual source left area"
                       6 "Dissatsfd with frmr source/liked new source better"
                       7 "Medical care needs changed"
                       8 "Frmr usual source stopped taking ins/coverage"
                       10 "Gynecological/obstetric care only"
                       11 "Medical care received through workman's comp"
                       12 "Do not need/like doctors"
                       13 "Cannot afford it/no insurance"
                       14 "Have insurance/ability to pay now" 15 "Military"
                       16 "Former student" 18 "Medicare/Medicaid recipient"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define UCARETYP  1 "Doctor's office or private clinic"
                       2 "Company or school health clinic/center"
                       3 "Community/migrant/rural clinic or center"
                       4 "County/city/public hospital outpatient clinic"
                       5 "Private/other hospital outpatient clinic"
                       6 "Hospital emergency room" 7 "HMO"
                       8 "Psychiatric hospital or clinic"
                       9 "VA hospital or clinic"
                       10 "Military health care facility"
                       11 "Some other place specified (see UCRTYPSP/SC)"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define UCRTYPSP  1 "Response marked"
                       3 "Response marked LOGICALLY ASSIGNED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UCRTYPSC  1 "Doctor's office or private clinic"
                       2 "Company or school health clinic/center"
                       3 "Community/migrant/rural clinic or center"
                       4 "County/city/public hospital outpatient clinic"
                       5 "Private/other hospital outpatient clinic"
                       6 "Hospital emergency room"
                       7 "HMO (Health maintenance organization/pre-paid grp)"
                       8 "Psychiatric hospital or clinic"
                       10 "Military health care facility"
                       12 "Self treatment/family member" 13 "Friend"
                       14 "Urgent care/walk-in medical facility"
                       15 "Religion/church" 16 "Alternative medicine"
                       17 "Non-physician health care professional"
                       18 "Family planning clinic"
                       19 "Indian clinic or hospital"
                       20 "Drug treatment/rehab center" 21 "Home health care"
                       22 "Workman's Compensation health provider"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MEDICARE  1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MEDICAID  1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CHAMPUS   1 "Yes" 2 "No" 94 "DON'T KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PRVHLTIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define GRPHLTIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PDHINPRM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTINALC  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTINDRG  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTINMNT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SOC1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SOC2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SSI1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SSI2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PUB1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PUB2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AFDC      1 "AFDC/ADC" 2 "OTHER" 3 "BOTH"
                       4 "AFDC/ADC Logically assigned"
                       5 "OTHER Logically assigned"
                       6 "BOTH Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define INT1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define INT2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CHD1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CHD2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OTH1      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define OTH2      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FSTAMP    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PINC1     1 "$20,000 or more" 2 "Less than $20,000"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SKPTFMIN  1 "Yes" 2 "No - SKIP" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FINC1     1 "$20,000 or more" 2 "Less than $20,000"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TELNO     0 "No telephone lines" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define IRPINSUR  1 "Yes, respondent does have private health insurance"
                       2 "No, respondent does not have private health insur." ;
label define IIPINSUR  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRINSUR   1 "Yes, respondent does have health insurance"
                       2 "No, respondent does not have health insurance" ;
label define IIINSUR   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRSOC1    1 "Yes" 2 "No" ;
label define IISOC1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRSSI1    1 "Yes" 2 "No" ;
label define IISSI1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRPUB1    1 "Yes" 2 "No" ;
label define IIPUB1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRAFDC    1 "AFDC/ADC" 2 "OTHER" 3 "BOTH"
                       89 "LEGITIMATE SKIP Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IIAFDC    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRINT1    1 "Yes" 2 "No" ;
label define IIINT1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRCHD1    1 "Yes" 2 "No" ;
label define IICHD1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IROTH1    1 "Yes" 2 "No" ;
label define IIOTH1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRFSTAMP  1 "Yes" 2 "No" ;
label define IIFSTAMP  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRPINC1   1 "$20,000 or more" 2 "Less than $20,000" ;
label define IIPINC1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRFINC1   1 "$20,000 or more" 2 "Less than $20,000"
                       89 "LEGITIMATE SKIP Logically assigned" ;
label define IIFINC1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRSOC2    1 "Yes" 2 "No" ;
label define IISOC2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRSSI2    1 "Yes" 2 "No" ;
label define IISSI2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRPUB2    1 "Yes" 2 "No" ;
label define IIPUB2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRINT2    1 "Yes" 2 "No" ;
label define IIINT2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRCHD2    1 "Yes" 2 "No" ;
label define IICHD2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IROTH2    1 "Yes" 2 "No" ;
label define IIOTH2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRKIDS    0 "No children under 12" ;
label define FEMBABY   0 "No" 1 "Yes" ;
label define FEMKIDS   0 "No" 1 "Yes" ;
label define MALEBABY  0 "No" 1 "Yes" ;
label define MALEKIDS  0 "No" 1 "Yes" ;
label define F15_44    0 "No" 1 "Yes" ;
label define M15_44    0 "No" 1 "Yes" ;
label define PREG      0 "No" 1 "Yes" ;
label define PREG2     1 "Pregnant (PREGNANT = 1,3)"
                       2 "Not pregnant (PREGNANT = 2)"
                       3 "Males/Females not age 12-44 (PREGNANT = 89,99)"
                       94 "Female, pregnancy status not known" ;
label define TRIMEST   1 "1st 3 months of pregnancy (PREG=1 & PREGMOS=1-3)"
                       2 "2nd 3 months of pregnancy (PREG=1 & PREGMOS=4-6)"
                       3 "Last 3 months of pregnancy (PREG=1 & PREGMOS=7-9)"
                       4 "Males/Not pregnant females (PREG=0)"
                       94 "Pregnant, trimester not known (PREG=1 and" ;
label define INDCAT    1 "$0" 2 "$1-$4,999" 3 "$5,000-$6,999"
                       4 "$7,000-$8,999" 5 "$9,000-$11,999"
                       6 "$12,000-$14,999" 7 "$15,000-$19,999"
                       8 "$20,000-$24,999" 9 "$25,000-$29,999"
                       10 "$30,000-$39,999" 11 "$40,000-$49,999"
                       12 "$50,000-$74,999" 13 "$75,000+" ;
label define PERINC    1 "$0-$8,999" 2 "$9,000-$19,999" 3 "$20,000-$39,999"
                       4 "$40,000-$74,999" 5 "$75,000+" ;
label define PERINC2   1 "$0-9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" ;
label define PERINC3   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" 8 "12-17 Years Old" ;
label define WELFARE   1 "Yes, respondent or another fam member on welfare"
                       2 "No, there was no one in the family on welfare" ;
label define NEEDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 12 months ago"
                       3 "12 or more months ago but less than 3 years ago"
                       4 "More than 3 years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       98 "NEEDLE USE NOT INDICATED BUT 1+ SOURCE VAR BLANK" ;
label define NEDFLAG4  0 "Never used (GNNDLLIF=2,85,97,98)"
                       1 "Ever Used (GNNDLLIF=1,3)" ;
label define NEDYR4    0 "No (NEEDLREC=3,4,9,91,98)" 1 "Yes (NEEDLREC=1,2)" ;
label define WITHDRW   98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SOMCOM    98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ANXDEP    98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SOCPROB   98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define THPROB    98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ATTPROB   98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DELBEH    98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AGGBEH    98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WITHDRWT  998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define SOMCOMT   998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define ANXDEPT   998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define SOCPROBT  998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define THPROBT   998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define ATTPROBT  998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define DELBEHT   998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define AGGBEHT   998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define MDESFS1   99 "LEGITIMATE SKIP" ;
label define PROBMDE1  99.0000 "LEGITIMATE SKIP" ;
label define MDE1      0 "Probable noncase" 1 "Probable case"
                       99 "LEGITIMATE SKIP" ;
label define GADSFS1   99 "LEGITIMATE SKIP" ;
label define PROBGAD1  99.0000 "LEGITIMATE SKIP" ;
label define GAD1      0 "Probable noncase" 1 "Probable case"
                       99 "LEGITIMATE SKIP" ;
label define AGPSFS1   99 "LEGITIMATE SKIP" ;
label define PROBAGP1  99 "LEGITIMATE SKIP" ;
label define AGP1      0 "Probable noncase" 1 "Probable case"
                       99 "LEGITIMATE SKIP" ;
label define PASFS1    99 "LEGITIMATE SKIP" ;
label define PROBPA1   99.0000 "LEGITIMATE SKIP" ;
label define PA1       0 "Probable noncase" 1 "Probable case"
                       99 "LEGITIMATE SKIP" ;
label define LANGVER   1 "English" 2 "Spanish" ;
label define UNDINT    1 "No difficulty--no language or reading problem"
                       2 "Just a little difficulty--almost no lang/read prob"
                       3 "A fair amount of difficulty--some lang/read probs"
                       4 "A lot of difficulty--considerable lang/read probs"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define COOPINT   1 "Very cooperative" 2 "Fairly cooperative"
                       3 "Not very cooperative" 4 "Openly hostile"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define PRIVACY   1 "Completely private-no one present/able to overhear"
                       3 "Minor distractions"
                       5 "Person(s) in the room or listening 1/3 of time"
                       7 "Serious interruption of privacy more than 1/2 time"
                       9 "Constant presence of other person(s)"
                       85 "BAD DATA Logically assigned"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define PPRES     1 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SPRES     2 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PARPRES   3 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OARPRES   4 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OAPRES    5 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CPRES     6 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OPRESNSP  7 "Response marked" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OPRESSPA  10 "Spouse" 20 "Parent/Guardian"
                       37 "Child, Relation Unspecified"
                       50 "Grandparent/Great+ Grandparent"
                       61 "Friend/Roommate/Companion"
                       71 "Cousin/Cousin's Spouse"
                       82 "Housekeeper/Maid/Caretaker/Butler"
                       84 "Neighbor/Co-Worker/Visitor"
                       85 "Landlord/Home Owner"
                       91 "Other Non-Relative, Gender not specified"
                       92 "Other, Relation and Gender Unspecified"
                       110 "Husband" 120 "Father/Male Guardian" 130 "Son"
                       137 "Male child, Relation Unspecified"
                       140 "Brother/Half Brother" 142 "Brother In-Law"
                       150 "Grandfather/Great+ Grandfather"
                       161 "Male Fiance/Boyfriend/Roommate/Companion"
                       170 "Uncle/Step Uncle/Aunt's Husband" 172 "Nephew"
                       191 "Other Male Non-Relative" 210 "Wife"
                       220 "Mother/Female Guardian"
                       221 "Step/Adopted/Foster Mother/Future Step Mother"
                       230 "Daughter" 232 "Daughter In-Law"
                       240 "Sister/Half Sister"
                       250 "Grandmother/Great+ Grandmother"
                       261 "Female Fiancee/Girlfriend/Roommate/Companion"
                       270 "Aunt"
                       283 "Female Nurse/Health Care Aide/Home Care Worker"
                       290 "Other Female Relative"
                       291 "Other Female Non-Relative"
                       292 "Other Female, Relation Unspecified"
                       337 "Children, Relation Unspecified" 340 "Siblings"
                       350 "Grandparents/Great+ Grandparents"
                       361 "Friends/Roommates/Companions"
                       371 "Cousins/Cousins' Spouses"
                       384 "Neighbors/Co-Workers/Visitors"
                       390 "Other Relatives, Gender not specified"
                       391 "Other Non-Relatives, Gender not specified"
                       392 "Others, Relation and Gender Unspecified"
                       440 "Brothers/Half Brothers"
                       531 "Step/Adopted/Foster Daughters"
                       540 "Sisters/Half Sisters"
                       571 "Female Cousins/Cousins' wives" 900 "NOT A PERSON"
                       985 "BAD DATA Logically assigned"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define OPRESSPB  37 "Child, Relation Unspecified"
                       61 "Friend/Roommate/Companion"
                       91 "Other Non-Relative, Gender not specified"
                       161 "Male Fiance/Boyfriend/Roommate/Companion"
                       170 "Uncle/Step Uncle/Aunt's Husband"
                       241 "Step/Adopted/Foster Sister/Future Step Sister"
                       361 "Friends/Roommates/Companions"
                       384 "Neighbors/Co-Workers/Visitors" 900 "NOT A PERSON"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define WHOMARKD  1 "Respondent marked all the Answer Sheet responses"
                       2 "Interviewer marked all the Answer Sheet responses"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define QUARTER   1 "Quarter 1" 2 "Quarter 2" 3 "Quarter 3"
                       4 "Quarter 4" ;
label define FAMSKIP   0 "Respondent has other family members in household"
                       1 "Respondent didn't have other family in household" ;
label define GQTYPE    1 "Halfway House" 2 "Boarding House" 3 "College Dorm"
                       4 "Shelter" 5 "Other" 9 "Not Group Quarters" ;
label define PDEN      1 "Segment in a MSA with 1 million or more persons"
                       2 "Segment in a MSA with fewer than 1 million persons"
                       3 "Segment not in MSA" ;
label define PDEN2     1 "Segment in MSA with 1 million or more persons"
                       2 "Segm. in a MSA from 250000 to 999999 persons"
                       3 "Segment in a MSA with fewer than 250000 persons"
                       4 "Segment not in a MSA and not in a rural area"
                       5 "Segment not in a MSA and in a rural area" ;
label define REGION    1 "Northeast" 2 "North Central" 3 "South" 4 "West" ;
label define DIVISION  1 "New England" 2 "Middle Atlantic"
                       3 "East North Central" 4 "West North Central"
                       5 "South Atlantic" 6 "East South Central"
                       7 "West South Central" 8 "Mountain" 9 "Pacific" ;
label define RURORURB  1 "Rural" 2 "Urban" ;
label define ROCCUP2
                       1 "Executive, Administrative, and Managerial Occupations"
                       2 "Professional Specialty Occupations"
                       3 "Technicians and Related Support Occupations"
                       4 "Sales Occupations"
                       5 "Administrative Support Occupations, Including Clerical"
                       6 "Private Household Occupations"
                       7 "Protective Service Occupations"
                       8 "Service Occupations, Except Protective and Private Household"
                       9 "Farming, Forestry, and Fishing Occupations"
                       10 "Mechanics and Repairers" 11 "Construction Trades"
                       12 "Extractive Occupations"
                       13 "Machine Operators, Assemblers, and Inspectors"
                       14 "Transportation and Material Moving Occupations"
                       15 "Handlers, Equipment Cleaners, Helpers, and Laborers"
                       16 "Military" 995 "BAD DATA" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define BUSINES2  1 "Agriculture, Forestry, And Fisheries" 2 "Mining"
                       3 "Construction" 4 "Manufacturing Nondurable Goods"
                       5 "Manufacturing Durable Goods"
                       6 "Transportation, Communications, And Other Public Utilities"
                       7 "Wholesale Durable Goods"
                       8 "Wholesale Nondurable Goods" 9 "Retail Trade"
                       10 "Finance, Insurance, and Real Estate"
                       11 "Business And Repair Services"
                       12 "Personal Services"
                       13 "Entertainment and Recreation Services"
                       14 "Professional and Related Services"
                       15 "Public Administration" 16 "Military Duty"
                       992 "UNEMPLOYED/NOT CLASSIFIED BY INDUSTRY"
                       995 "BAD DATA" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define RELINTHH  0 "No other person in the household was interviewed"
                       10 "Spouse" 20 "Parent/guardian"
                       21 "Step/adopted/foster parent"
                       22 "Parent in-law (also step-)" 30 "Child"
                       31 "Step/adopted/foster child" 32 "Child in-law"
                       40 "Sibling" 41 "Step/adopted/foster sibling"
                       42 "Sibling in-law" 50 "Grandparent"
                       60 "Live in partner, fiancee" 61 "Friend/roommate"
                       70 "Other, relative" 71 "Other, non-relative"
                       99 "Other, relation unspecified" ;
label define PRVHLIN2  0 "UNKNOWN (PRVHLTIN = 94,96,97,98)"
                       1 "Yes (PRVHLTIN = 1, 3)" 2 "No (PRVHLTIN = 2)" ;
label define HLTINDR2  0 "NO ANSWER/NOT COVERED BY PRIVATE PLAN"
                       1 "Yes (HLTINDRG = 1)" 2 "No (HLTINDRG = 2)" ;
label define HLTINAL2  0 "NO ANSWER/NOT COVERED BY PRIVATE PLAN"
                       1 "Yes (HLTINALC = 1)" 2 "No (HLTINALC = 2)" ;
label define TRMTHLP2  0 "No" 1 "Yes" ;
label define DRNKHLP2  0 "No" 1 "Yes" ;
label define DRALHELP  0 "No (TRMTHLP2 =0 AND DRNKHLP2 =0)"
                       1 "Yes (TRMTHLP2 =1 OR DRNKHLP2 =1)" ;
label define BKLARCN2  0 "No (BKLARCNY = 2, 85, 89, 97, 98, 99)"
                       1 "Yes (BKLARCNY = 1, 3)" ;
label define BKBURGL2  0 "No (BKBURGL = 2, 85, 89, 97, 98, 99)"
                       1 "Yes (BKBURGL = 1)" ;
label define BKAGASL2  0 "No (BKAGASLT = 2, 85, 89, 97, 98, 99)"
                       1 "Yes (BKAGASLT = 1)" ;
label define BKSMASL2  0 "No (BKSMASLT = 2, 85, 89, 97, 98, 99)"
                       1 "Yes (BKSMASLT = 1)" ;
label define BKMVTHF2  0 "No (BKMVTHFT = 2, 85, 89, 97, 98, 99)"
                       1 "Yes (BKMVTHFT = 1)" ;
label define BKROB2    0 "No (BKROB = 2, 85, 89, 97, 98, 99)"
                       1 "Yes (BKROB = 1)" ;
label define BKRAPE2   0 "No (BKRAPE = 2, 85, 89, 97, 98, 99)"
                       1 "Yes (BKRAPE = 1)" ;
label define BKMURDE2  0 "No (BKMURDER = 2, 85, 89, 97, 98, 99)" ;
label define BKARSON2  0 "No (BKARSON = 2, 85, 89, 97, 98, 99)"
                       1 "Yes (BKARSON = 1)" ;
label define BKDRVIN2  0 "No (BKDRVINF = 2, 85, 89, 97, 98, 99)"
                       1 "Yes (BKDRVINF = 1, 3)" ;
label define BKDRUNK2  0 "No (BKDRUNK = 2, 85, 89, 97, 98, 99)"
                       1 "Yes (BKDRUNK = 1, 3)" ;
label define BKDRUG2   0 "No (BKDRUG = 2, 85, 89, 97, 98, 99)"
                       1 "Yes (BKDRUG = 1)" ;
label define BKPROS2   0 "No (BKPROS = 2, 85, 89, 97, 98, 99)"
                       1 "Yes (BKPROS = 1, 3)" ;
label define STRSTEA2  0 "No (STRSTEAL = 2, 85, 97, 98)"
                       1 "Yes (STRSTEAL = 1)" ;
label define OTHSTEA2  0 "No (OTHSTEAL = 2, 85, 97, 98)"
                       1 "Yes (OTHSTEAL = 1)" ;
label define DAMAGE2   0 "No (DAMAGE = 2, 85, 97, 98)"
                       1 "Yes (DAMAGE = 1, 3)" ;
label define CARSTEA2  0 "No (CARSTEAL = 2, 85, 97, 98)"
                       1 "Yes (CARSTEAL = 1, 3)" ;
label define FORCEMO2  0 "No (FORCEMON = 2, 85, 97, 98)"
                       1 "Yes (FORCEMON = 1)" ;
label define BREAKIN2  0 "No (BREAKIN = 2, 85, 97, 98)"
                       1 "Yes (BREAKIN = 1, 3)" ;
label define PHYFIGH2  0 "No (PHYFIGHT = 2, 85, 97, 98)"
                       1 "Yes (PHYFIGHT = 1, 3)" ;
label define HURTBAD2  0 "No (HURTBAD = 2, 85, 97, 98)"
                       1 "Yes (HURTBAD = 1, 3)" ;
label define GUNMONE2  0 "No (GUNMONEY = 2, 85, 97, 98)"
                       1 "Yes (GUNMONEY = 1, 3)" ;
label define DRVALDR2  0 "No (DRVALDR = 2, 85, 97, 98)"
                       1 "Yes (DRVALDR = 1, 3)" ;
label define DRIVEAL2  0 "No (DRIVEAL = 2, 85, 97, 98)" 1 "Yes (DRIVEAL = 1)" ;
label define DRIVEDR2  0 "No (DRIVEDR = 2, 85, 97, 98)" 1 "Yes (DRIVEDR = 1)" ;
label define SOLDDRU2  0 "No (SOLDDRUG = 2, 85, 97, 98)"
                       1 "Yes (SOLDDRUG = 1, 3)" ;
label define DRUNKYR2  1 "Yes (DRUNKYR = 1, 2, 3, 4)"
                       2 "No (DRUNKYR = 5,6,7,8,9,81,83,85,90,91,93,98)" ;
label define BINGDRK2  0 "No (BINGEDRK = 99 OR BINGEDRK = 0)"
                       1 "Yes (BINGEDRK = 1)" ;
label define FERTAGE   1 "Women ages 15-25 (CATAGE = 1, 2 AND F15_44 =1)"
                       2 "Women ages 26-44 (CATAGE = 3, 4 AND F15_44 =1)"
                       99 "Men/women 12-14, 45+" ;
label define PREG3     1 "Pregnant (PREG2 =1 AND F15_44 =1)"
                       2 "Not pregnant (PREG2 =2 AND F15_44 =1)"
                       99 "Otherwise (F15_44 =0 OR PREG2 =3, MISSING)" ;
label define TRIMEST2  1 "1st 3 mos of pregnancy (TRIMEST = 1 AND F15_44 =1)"
                       2 "2nd 3 mos of pregnancy (TRIMEST = 2 AND F15_44 =1)"
                       3 "Last 3 mos of pregnancy (TRIMEST = 3 AND F15_44 =1)"
                       99 "Otherwise (F15_44 =0 OR TRIMEST = 4, MISSING)" ;
label define MJTOT3    1 "1-2 days (MJTOT = 5)" 2 "3-11 days (MJTOT = 4)"
                       3 "12-100 days (MJTOT = 3)"
                       4 "101+ days (MJTOT = 1-2)"
                       5 "NEVER USED (MJTOT = 81,91)"
                       6 "BAD DATA/NO ANSWER (MJTOT = 85,94,97,98)" ;
label define COCTOT3   1 "1-2 days (COCTOT = 5)" 2 "3-11 days (COCTOT = 4)"
                       3 "12-100 days (COCTOT = 3)"
                       4 "101+ days (COCTOT = 1 OR 2)"
                       5 "NEVER USED/NO ANSWER (COCTOT = 81 OR 91)"
                       99 "UNKNOWN (COCTOT = 85 OR 98)" ;
label define ALCDAYS2  1 "None or never used alcohol"
                       2 "1-2 days (ALCDAYS = 1-2)"
                       3 "3-4 days (ALCDAYS = 3-4)"
                       4 "5-19 days (ALCDAYS = 5-19)"
                       5 "20-30 days (ALCDAYS = 20-30)"
                       6 "UNKNOWN (ALCDAYS = 85,94,95,98)" ;
label define AGECAT3   1 "12-13 (12 LE IRAGE LE 13)"
                       2 "14-15 (14 LE IRAGE LE 15)"
                       3 "16-17 (16 LE IRAGE LE 17)"
                       4 "18-21 (18 LE IRAGE LE 21)"
                       5 "22-25 (22 LE IRAGE LE 25)"
                       6 "26-29 (26 LE IRAGE LE 29)"
                       7 "30-34 (30 LE IRAGE LE 34)"
                       8 "35-39 (35 LE IRAGE LE 39)"
                       9 "40-44 (40 LE IRAGE LE 44)"
                       10 "45-49 (45 LE IRAGE LE 49)"
                       11 "50-102 (50 LE IRAGE LE 102)" ;
label define AGECAT4   1 "12-20 (12 LE IRAGE LE 20)"
                       2 "21 AND OLDER (21 LE IRAGE LE 102)" ;
label define MJDY30A3  1 "1-2 days (MJDAY30A = 1-2)"
                       2 "3-4 days (MJDAY30A = 3-4)"
                       3 "5-19 days (MJDAY30A = 5-19)"
                       4 "20-30 days (MJDAY30A = 20-30)"
                       5 "NONE/NEVER USED MARIJUANA (MJDAY30A = 81,83,91,93)"
                       6 "UNKNOWN/NO ANSWER (MJDAY30A = 85,94,95,97,98)" ;
label define ALCDAYS3  1 "0 (ALCDAYS2 =1)" 2 "1-4 (ALCDAYS2 =2 OR 3)"
                       3 "5-19 (ALCDAYS2 =4)" 4 "20-30 (ALCDAYS2 =5)"
                       6 "UNKNOWN (ALCDAYS2 =6)" ;
label define DRINKER2  0 "No" 1 "Yes (DR5DAY=1-30, 90 OR ALCMON=1)" ;
label define HVYDRK3   0 "No (HVYDRK2 OR HVYDRK2 =0)" 1 "Yes" ;
label define AVCIG2    1 "0 (AVCIG = 81,83,91,93)"
                       2 "15 cigarettes or less (AVCIG = 1-3)"
                       3 "16 cigarettes or more (AVCIG = 4-6)"
                       4 "UNKNOWN (AVCIG = 85,98)" ;
label define RACESEX   1 "White male (SEX = 1 AND RACE = 1)"
                       2 "Black male (SEX = 1 AND RACE = 2)"
                       3 "Hispanic male (SEX = 1 AND RACE = 3)"
                       4 "White female (SEX = 2 AND RACE = 1)"
                       5 "Black female (SEX = 2 AND RACE = 2)"
                       6 "Hispanic female (SEX = 2 AND RACE = 3)"
                       99 "Other males and females (SEX=1 OR 2 AND RACE=4)" ;
label define NOTMARJ   0 "No (COCMON=0 AND INHMON=0 AND HALMON=0"
                       1 "Yes (COCMON=1 AND INHMON=1 AND HALMON=1" ;
label define RACESEX2  1 "White male (SEX = 1 AND RACE = 1)"
                       2 "Black male (SEX = 1 AND RACE = 2)"
                       3 "Hispanic male (SEX = 1 AND RACE = 3)"
                       4 "Other male (SEX = 1 AND RACE = 4)"
                       5 "White female (SEX = 2 AND RACE = 1)"
                       6 "Black female (SEX = 2 AND RACE = 2)"
                       7 "Hispanic female (SEX = 2 AND RACE = 3)"
                       8 "Other female (SEX = 2 AND RACE = 4)" ;
label define ANY4MENT  0 "Did not have in past year" 1 "Had in past year"
                       99 "Children age 12-17" ;
label define CIGTRY2   99 "LEGITIMATE SKIP/NO ANSWER" ;
label define ALCTRY2   99 "LEGITIMATE SKIP/NO ANSWER" ;
label define MJAGE2    99 "NEVER USED/NO ANSWER" ;
label define INHAGE2   99 "NEVER USED/NO ANSWER" ;
label define COCAGE2   99 "LEGITIMATE SKIP/NO ANSWER" ;
label define HALLAGE2  99 "NEVER USED/NO ANSWER" ;
label define HERAGE2   99 "NEVER USED/NO ANSWER" ;
label define STIMAGE2  99 "NEVER USED/NO ANSWER" ;
label define SEDAGE2   99 "NEVER USED/NO ANSWER" ;
label define TRANAGE2  99 "NEVER USED/NO ANSWER" ;
label define ANALAGE2  99 "LEGITIMATE SKIP/NO ANSWER" ;
label define ALCONLYL  0 "No" 1 "Yes (ALCFLAG=1 AND SUMFLAG=0)" ;
label define ALCONLYY  0 "No" 1 "Yes (ALCYR=1 AND SUMYR=0)" ;
label define ALCONLYM  0 "No" 1 "Yes (ALCMON=1 AND SUMMON=0)" ;
label define ILLONLYL  0 "No" 1 "Yes (SUMFLAG=1 AND ALCFLAG=0)" ;
label define ILLONLYY  0 "No" 1 "Yes (SUMYR=1 AND ALCYR=0)" ;
label define ILLONLYM  0 "No" 1 "Yes (SUMMON=1 AND ALCMON=0)" ;
label define MRJONLYL  0 "No" 1 "Yes (MJOFLAG=1 AND ALCFLAG=0)" ;
label define MRJONLYY  0 "No" 1 "Yes (MJOYR2=1 AND ALCYR=0)" ;
label define MRJONLYM  0 "No" 1 "Yes (MJOMON2=1 AND ALCMON=0)" ;
label define PSYONLYL  0 "No"
                       1 "Yes (PSYFLAG2=1,MRJFLAG=0,COCFLAG=0,INHFLAG=0" ;
label define PSYONLYY  0 "No" 1 "Yes (PSYYR2=1,MRJYR=0,COCYR=0,INHYR=0," ;
label define PSYONLYM  0 "No" 1 "Yes (PSYMON2=1,MRJMON=0,COCMON=0,INHMON=0," ;
label define OTHONLYL  0 "No"
                       1 "Yes (ALCFLAG=0 & MRJONLYL=0 & PSYONLYL=0 & ANY" ;
label define OTHONLYY  0 "No"
                       1 "Yes (ALCYR=0 & MRJONLYY=0 & PSYONLYY=0 & ANY" ;
label define OTHONLYM  0 "No"
                       1 "Yes (ALCMON=0 & MRJONLYM=0 & PSYONLYM=0 & ANY" ;
label define ALCILLL   0 "No" 1 "Yes (ALCFLAG=1 AND SUMFLAG=1)" ;
label define ALCILLY   0 "No" 1 "Yes (ALCYR=1 AND SUMYR=1)" ;
label define ALCILLM   0 "No" 1 "Yes (ALCMON=1 AND SUMMON=1)" ;
label define ALCMRJL   0 "No"
                       1 "Yes (ALCFLAG=1,MRJFLAG=1,PSYFLAG2=0,COCFLAG=0," ;
label define ALCMRJY   0 "No" 1 "Yes (ALCYR=1,MRJYR=1,PSYYR2=0,COCYR=0," ;
label define ALCMRJM   0 "No" 1 "Yes (ALCMON=1,MRJMON=1,PSYMON2=0,COCMON=0," ;
label define ALCPSYL   0 "No"
                       1 "Yes (ALCFLAG=1,PSYFLAG2=1,MRJFLAG=0,COCFLAG=0," ;
label define ALCPSYY   0 "No" 1 "Yes (ALCYR=1,PSYYR2=1,MRJYR=0,COCYR=0," ;
label define ALCPSYM   0 "No" 1 "Yes (ALCMON=1,PSYMON2=1,MRJMON=0,COCMON=0," ;
label define ALCOTHL   0 "No" 1 "Yes (ALCFLAG=1 & ALCMRJL=0 & ALCPSYL=0 &" ;
label define ALCOTHY   0 "No" 1 "Yes (ALCYR=1 & ALCMRJY=0 & ALCPSYY=0 &" ;
label define ALCOTHM   0 "No" 1 "Yes (ALCMON=1 & ALCMRJM=0 & ALCPSYM=0 &" ;
label define SUB1LIF   0 "No" 1 "Yes (IF ONLY ONE OF" ;
label define SUB2LIF   0 "No" 1 "Yes (IF ONLY TWO OF" ;
label define SUB3LIF   0 "No" 1 "Yes (IF THREE OR MORE OF" ;
label define SUB1YR    0 "No" 1 "Yes (IF ONLY ONE OF" ;
label define SUB2YR    0 "No" 1 "Yes (IF ONLY TWO OF" ;
label define SUB3YR    0 "No" 1 "Yes (IF THREE OR MORE OF" ;
label define SUB1MON   0 "No" 1 "Yes (IF ONLY ONE OF" ;
label define SUB2MON   0 "No" 1 "Yes (IF ONLY TWO OF" ;
label define SUB3MON   0 "No" 1 "Yes (IF THREE OR MORE OF" ;
label define PSYAGE    99 "NEVER USED/NO ANSWER" ;
label define TOTPROB   99.0000 "LEGITIMATE SKIP/NO ANSWER" ;
label define INT
                       99.0000 "BLANK (INCLUDES ADOLESCENTS WHO DID NOT ANSWER" ;
label define EXT       99 "BLANK (INCLUDES ADOLESCENTS WHO DID NOT ANSWER" ;
label define PR_EMOT
                       0 "No (INT LT 17 AND IRSEX=1 OR INT LT 22 AND IRSEX=2)"
                       1 "Yes (INT GE 17 AND IRSEX=1 OR INT GE 22 AND IRSEX=2"
                       99 "BLANK (INCLUDES ADOLESCENTS WHO DID NOT ANSWER" ;
label define PR_BEHAV  0 "No (EXT LT 19 & IRSEX=1 OR EXT LT 17 & IRSEX=2)"
                       1 "Yes (EXT GE 19 & IRSEX=1 OR EXT GE 17 & IRSEX=2)"
                       99 "BLANK (INCLUDES ADOLESCENTS WHO DID NOT ANSWER" ;
label define PR_TOTAL  0 "No (TOTPROB LT 54 AND IRSEX = 1) OR"
                       1 "Yes (TOTPROB GE 54 AND IRSEX = 1) OR"
                       99 "BLANK (INCLUDES ADOLESCENTS WHO DID NOT ANSWER" ;
label define PR_WD     0 "No (WITHDRWT LT 67)" 1 "Yes (WITHDRWT GE 67)"
                       99 "BLANK/NO ANSWER (WITHDRWT = 998,999)" ;
label define PR_SC     0 "No (SOMCOMT LT 67)" 1 "Yes (SOMCOMT GE 67)"
                       99 "BLANK/NO ANSWER (SOMCOMT = 998,999)" ;
label define PR_AD     0 "No (ANXDEPT LT 67)" 1 "Yes (ANXDEPT GE 67)"
                       99 "BLANK/NO ANSWER (ANXDEPT = 998,999)" ;
label define PR_SP     0 "No (SOCPROBT LT 67)" 1 "Yes (SOCPROBT GE 67)"
                       99 "BLANK/NO ANSWER (SOCPROBT = 998,999)" ;
label define PR_TP     0 "No (THPROBT LT 67)" 1 "Yes (THPROBT GE 67)"
                       99 "BLANK/NO ANSWER (THPROBT = 998,999)" ;
label define PR_AP     0 "No (ATTPROBT LT 67)" 1 "Yes (ATTPROBT GE 67)"
                       99 "BLANK/NO ANSWER (ATTPROBT = 998,999)" ;
label define PR_DB     0 "No (DELBEHT LT 67)" 1 "Yes (DELBEHT GE 67)"
                       99 "BLANK/NO ANSWER (DELBEHT = 998,999)" ;
label define PR_AB     0 "No (AGGBEHT LT)" 1 "Yes (AGGBEHT GE 67)"
                       99 "BLANK/NO ANSWER (AGGBEHT = 998,999)" ;
label define AGE       1 "12-13 (IRAGE = 12 OR 13)"
                       2 "14-15 (IRAGE = 14 OR 15)"
                       3 "16-17 (IRAGE = 16 OR 17)"
                       99 "18 or older (IRAGE GE 18)" ;
label define IRBTCIG2  0 "No (BTOLCIG = 2, 4, 89, 98, 99)"
                       1 "Yes (BTOLCIG = 1)" ;
label define IRBTALC2  0 "No (BTOLALC = 2, 4, 89, 98, 99)"
                       1 "Yes (BTOLALC = 1)" ;
label define IRBTMRJ2  0 "No (BTOLMRJ = 2, 4, 89, 98, 99)"
                       1 "Yes (BTOLMRJ = 1)" ;
label define IRBTCOC2  0 "No (BTOLCOC = 2, 4, 89, 98, 99)"
                       1 "Yes (BTOLCOC = 1)" ;
label define IRGRCIG2  0 "No (GRTMCIG = 2, 4, 89, 98, 99)"
                       1 "Yes (GRTMCIG = 1)" ;
label define IRGRALC2  0 "No (GRTMALC = 2, 4, 89, 98, 99)"
                       1 "Yes (GRTMALC = 1)" ;
label define IRGRMRJ2  0 "No (GRTMMRJ = 2, 4, 89, 98, 99)"
                       1 "Yes (GRTMMRJ = 1)" ;
label define IRGRCOC2  0 "No (GRTMCOC = 2, 4, 89, 98, 99)"
                       1 "Yes (GRTMCOC = 1)" ;
label define IRLACIG2  0 "No (LAMTCIG = 2, 4, 89, 98, 99)"
                       1 "Yes (LAMTCIG = 1)" ;
label define IRLAALC2  0 "No (LAMTALC = 2, 4, 89, 98, 99)"
                       1 "Yes (LAMTALC = 1)" ;
label define IRLAMRJ2  0 "No (LAMTMRJ = 2, 4, 89, 98, 99)"
                       1 "Yes (LAMTMRJ = 1)" ;
label define IRLACOC2  0 "No (LAMTCOC = 2, 4, 89, 98, 99)"
                       1 "Yes (LAMTCOC = 1)" ;
label define IRACCIG2  0 "No (ACRDCIG = 2, 4, 89, 98, 99)"
                       1 "Yes (ACRDCIG = 1)" ;
label define IRACALC2  0 "No (ACRDALC = 2, 4, 89, 98, 99)"
                       1 "Yes (ACRDALC = 1)" ;
label define IRACMRJ2  0 "No (ACRDMRJ = 2, 4, 89, 98, 99)"
                       1 "Yes (ACRDMRJ = 1)" ;
label define IRACCOC2  0 "No (ACRDCOC = 2, 4, 89, 98, 99)"
                       1 "Yes (ACRDCOC = 1)" ;
label define IREMCIG2  0 "No (EMPBCIG = 2, 4, 89, 98, 99)"
                       1 "Yes (EMPBCIG = 1)" ;
label define IREMALC2  0 "No (EMPBALC = 2, 4, 89, 98, 99)"
                       1 "Yes (EMPBALC = 1)" ;
label define IREMMRJ2  0 "No (EMPBMRJ = 2, 4, 89, 98, 99)"
                       1 "Yes (EMPBMRJ = 1)" ;
label define IREMCOC2  0 "No (EMPBCOC = 2, 4, 89, 98, 99)"
                       1 "Yes (EMPBCOC = 1)" ;
label define IRHLCIG2  0 "No (HLPBCIG = 2, 4, 89, 98, 99)"
                       1 "Yes (HLPBCIG = 1)" ;
label define IRHLALC2  0 "No (HLPBALC = 2, 4, 89, 98, 99)"
                       1 "Yes (HLPBALC = 1)" ;
label define IRHLMRJ2  0 "No (HLPBMRJ = 2, 4, 89, 98, 99)"
                       1 "Yes (HLPBMRJ = 1)" ;
label define IRHLCOC2  0 "No (HLPBCOC = 2, 4, 89, 98, 99)"
                       1 "Yes (HLPBCOC = 1)" ;
label define IRUCCIG2  0 "No (UCDCIG = 2, 4, 89, 98, 99)"
                       1 "Yes (UCDCIG = 1)" ;
label define IRUCALC2  0 "No (UCDALC = 2, 4, 89, 98, 99)"
                       1 "Yes (UCDALC = 1)" ;
label define IRUCMRJ2  0 "No (UCDMRJ = 2, 4, 89, 98, 99)"
                       1 "Yes (UCDMRJ = 1)" ;
label define IRUCCOC2  0 "No (UCDCOC = 2, 4, 89, 98, 99)"
                       1 "Yes (UCDCOC = 1)" ;
label define AVCIG3    0 "No (AVCIG = 1-3,81,83,85,91,93,98)"
                       1 "Yes (AVCIG = 4-6)" ;
label define ALCPROBS  0 "No" 1 "Yes" ;
label define MJPROBS   0 "No" 1 "Yes" ;
label define COCPROBS  0 "No" 1 "Yes" ;
label define CIGPROBS  0 "No" 1 "Yes" ;
label define MRJ2PROB  0 "No" 1 "Yes" ;
label define MRJ3PROB  0 "No" 1 "Yes" ;
label define COC2PROB  0 "No" 1 "Yes" ;
label define COC3PROB  0 "No" 1 "Yes" ;
label define CIG2PROB  0 "No" 1 "Yes" ;
label define CIG3PROB  0 "No" 1 "Yes" ;
label define ALC2PROB  0 "No" 1 "Yes" ;
label define ALC3PROB  0 "No" 1 "Yes" ;
label define MARUSE    1 "Less than 12 days (IRMJFQ = 7-9)"
                       2 "12-50 days (1-4 days/month) (IRMJFQ = 5-6)"
                       3 "51-300 days (1-7 days/week) (IRMJFQ = 2-4)"
                       4 "More than 300 days (daily or almost) (IRMJFQ = 1)"
                       5 "Did not use in past year (IRMJFQ = 10)" ;
label define COCUSE    1 "Less than 12 days (IRCOCFQ=7-9)"
                       2 "12-50 days (1-4 days/month) (IRCOCFQ=5-6)"
                       3 "51-300 days (1-7 days/week) (IRCOCFQ=2-4)"
                       4 "More than 300 days (daily or almost)(IRCOCFQ=1)"
                       5 "Has not used in past year (IRCOCFQ=10)" ;
label define ALCUSE    1 "Less than 12 days (IRALCFQ=7-9)"
                       2 "12-50 days (1-4 days/month)(IRALCFQ=5-6)"
                       3 "51-300 days (1-7 days/week)(IRALCFQ=2-4)"
                       4 "More than 300 days(daily or almost)(IRALCFQ=1)"
                       5 "HAS NOT USED IN PAST YEAR (IRALCFQ=10)" ;
label define TOTCAT    1 "$0" 2 "$1-$4,999" 3 "$5,000-$6,999"
                       4 "$7,000-$8,999" 5 "$9,000-$11,999"
                       6 "$12,000-$14,999" 7 "$15,000-$19,999"
                       8 "$20,000-$24,999" 9 "$25,000-$29,999"
                       10 "$30,000-$39,999" 11 "$40,000-$49,999"
                       12 "$50,000-$74,999" 13 "$75,000+" ;
label define FAMINC    1 "$0-$8,999" 2 "$9,000-$19,999" 3 "$20,000-$39,999"
                       4 "$40,000-$74,000" 5 "$75,000+" ;
label define FAMINC2   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" ;
label define FAMINC3   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" 8 "12-17 Years old" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace MARITAL = . if (MARITAL >= 81 & MARITAL <= 99)
replace NOMARR = . if (NOMARR >= 81 & NOMARR <= 99)
replace SERVICE = . if (SERVICE >= 81 & SERVICE <= 99)
replace MILSTAT = . if (MILSTAT >= 81 & MILSTAT <= 99)
replace EDUC = . if (EDUC >= 81 & EDUC <= 99)
replace DIPLOMA = . if (DIPLOMA >= 81 & DIPLOMA <= 99)
replace WORKSTAT = . if (WORKSTAT >= 81 & WORKSTAT <= 99)
replace HTININCH = . if (HTININCH >= 981 & HTININCH <= 999)
replace POUNDS = . if (POUNDS >= 981 & POUNDS <= 999)
replace HEALTH = . if (HEALTH >= 81 & HEALTH <= 99)
replace CIGEVER = . if (CIGEVER >= 81 & CIGEVER <= 99)
replace CIGTRY = . if (CIGTRY >= 981 & CIGTRY <= 999)
replace CIGTOT = . if (CIGTOT >= 81 & CIGTOT <= 99)
replace CIGREC = . if (CIGREC >= 81 & CIGREC <= 99)
replace CIG30USE = . if (CIG30USE >= 81 & CIG30USE <= 99)
replace AVCIG = . if (AVCIG >= 81 & AVCIG <= 99)
replace CIG30WOK = . if (CIG30WOK >= 81 & CIG30WOK <= 99)
replace CIGEVYDA = . if (CIGEVYDA >= 81 & CIGEVYDA <= 99)
replace CIGAGE = . if (CIGAGE >= 981 & CIGAGE <= 999)
replace CIGYRS = . if (CIGYRS >= 981 & CIGYRS <= 999)
replace SNUFEVER = . if (SNUFEVER >= 81 & SNUFEVER <= 99)
replace SNUFREC = . if (SNUFREC >= 81 & SNUFREC <= 99)
replace SKPALCRD = . if (SKPALCRD >= 81 & SKPALCRD <= 99)
replace ALCREAD = . if (ALCREAD >= 81 & ALCREAD <= 99)
replace ALCTRY = . if (ALCTRY >= 981 & ALCTRY <= 999)
replace ALCREC = . if (ALCREC >= 81 & ALCREC <= 99)
replace ALCPAT = . if (ALCPAT >= 81 & ALCPAT <= 99)
replace DRUNKYR = . if (DRUNKYR >= 81 & DRUNKYR <= 99)
replace ALCDAYS = . if (ALCDAYS >= 81 & ALCDAYS <= 99)
replace NODR30A = . if (NODR30A >= 81 & NODR30A <= 99)
replace DR5DAY = . if (DR5DAY >= 81 & DR5DAY <= 99)
replace MJAGE = . if (MJAGE >= 981 & MJAGE <= 999)
replace MJTOT = . if (MJTOT >= 81 & MJTOT <= 99)
replace MJREC = . if (MJREC >= 81 & MJREC <= 99)
replace MJYRFREQ = . if (MJYRFREQ >= 81 & MJYRFREQ <= 99)
replace MJDAY30A = . if (MJDAY30A >= 81 & MJDAY30A <= 99)
replace SKPCOCRD = . if (SKPCOCRD >= 81 & SKPCOCRD <= 99)
replace COCREAD = . if (COCREAD >= 81 & COCREAD <= 99)
replace COCAGE = . if (COCAGE >= 981 & COCAGE <= 999)
replace COCTOT = . if (COCTOT >= 81 & COCTOT <= 99)
replace COCREC = . if (COCREC >= 81 & COCREC <= 99)
replace COCYRFRQ = . if (COCYRFRQ >= 81 & COCYRFRQ <= 99)
replace COCUS30A = . if (COCUS30A >= 81 & COCUS30A <= 99)
replace SKPCRKRD = . if (SKPCRKRD >= 81 & SKPCRKRD <= 99)
replace CRKREAD = . if (CRKREAD >= 81 & CRKREAD <= 99)
replace CRKEVER = . if (CRKEVER >= 81 & CRKEVER <= 99)
replace CRKAGE = . if (CRKAGE >= 981 & CRKAGE <= 999)
replace CRKTOT = . if (CRKTOT >= 81 & CRKTOT <= 99)
replace CRAKREC = . if (CRAKREC >= 81 & CRAKREC <= 99)
replace CRKYRFRQ = . if (CRKYRFRQ >= 81 & CRKYRFRQ <= 99)
replace CRKUS30A = . if (CRKUS30A >= 81 & CRKUS30A <= 99)
replace SKPHERRD = . if (SKPHERRD >= 81 & SKPHERRD <= 99)
replace HERREAD = . if (HERREAD >= 81 & HERREAD <= 99)
replace HEREVER = . if (HEREVER >= 81 & HEREVER <= 99)
replace HERAGE = . if (HERAGE >= 981 & HERAGE <= 999)
replace HERTOT = . if (HERTOT >= 81 & HERTOT <= 99)
replace HERREC = . if (HERREC >= 81 & HERREC <= 99)
replace HERYRFRQ = . if (HERYRFRQ >= 81 & HERYRFRQ <= 99)
replace HER30USE = . if (HER30USE >= 81 & HER30USE <= 99)
replace SKPHALRD = . if (SKPHALRD >= 81 & SKPHALRD <= 99)
replace HALREAD = . if (HALREAD >= 81 & HALREAD <= 99)
replace LSD = . if (LSD >= 81 & LSD <= 99)
replace PCP = . if (PCP >= 81 & PCP <= 99)
replace PEYOTE = . if (PEYOTE >= 81 & PEYOTE <= 99)
replace MESC = . if (MESC >= 81 & MESC <= 99)
replace PSILCY = . if (PSILCY >= 81 & PSILCY <= 99)
replace ECSTASY = . if (ECSTASY >= 81 & ECSTASY <= 99)
replace HALDKNAM = . if (HALDKNAM >= 81 & HALDKNAM <= 99)
replace HALNOLST = . if (HALNOLST >= 81 & HALNOLST <= 99)
replace HALNEWA = . if (HALNEWA >= 9981 & HALNEWA <= 9999)
replace HALNEWB = . if (HALNEWB >= 9981 & HALNEWB <= 9999)
replace HALNEWC = . if (HALNEWC >= 9981 & HALNEWC <= 9999)
replace HALNEWD = . if (HALNEWD >= 9981 & HALNEWD <= 9999)
replace HALNEWE = . if (HALNEWE >= 9981 & HALNEWE <= 9999)
replace HALLAGE = . if (HALLAGE >= 981 & HALLAGE <= 999)
replace HALLTOT = . if (HALLTOT >= 81 & HALLTOT <= 99)
replace HALLREC = . if (HALLREC >= 81 & HALLREC <= 99)
replace HALYRFRQ = . if (HALYRFRQ >= 81 & HALYRFRQ <= 99)
replace HAL30USE = . if (HAL30USE >= 81 & HAL30USE <= 99)
replace LSDREC = . if (LSDREC >= 81 & LSDREC <= 99)
replace PCPREC = . if (PCPREC >= 81 & PCPREC <= 99)
replace SKPINHRD = . if (SKPINHRD >= 81 & SKPINHRD <= 99)
replace INHREAD = . if (INHREAD >= 81 & INHREAD <= 99)
replace AMYLNIT = . if (AMYLNIT >= 81 & AMYLNIT <= 99)
replace CLEFLU = . if (CLEFLU >= 81 & CLEFLU <= 99)
replace GAS = . if (GAS >= 81 & GAS <= 99)
replace GLUE = . if (GLUE >= 81 & GLUE <= 99)
replace ETHER = . if (ETHER >= 81 & ETHER <= 99)
replace SOLVENT = . if (SOLVENT >= 81 & SOLVENT <= 99)
replace LGAS = . if (LGAS >= 81 & LGAS <= 99)
replace NITOXID = . if (NITOXID >= 81 & NITOXID <= 99)
replace SPPAINT = . if (SPPAINT >= 81 & SPPAINT <= 99)
replace AEROS = . if (AEROS >= 81 & AEROS <= 99)
replace INHDKNAM = . if (INHDKNAM >= 81 & INHDKNAM <= 99)
replace INHNOLST = . if (INHNOLST >= 81 & INHNOLST <= 99)
replace INHNEWA = . if (INHNEWA >= 9981 & INHNEWA <= 9999)
replace INHNEWB = . if (INHNEWB >= 9981 & INHNEWB <= 9999)
replace INHNEWC = . if (INHNEWC >= 9981 & INHNEWC <= 9999)
replace INHNEWD = . if (INHNEWD >= 9981 & INHNEWD <= 9999)
replace INHNEWE = . if (INHNEWE >= 9981 & INHNEWE <= 9999)
replace INHAGE = . if (INHAGE >= 981 & INHAGE <= 999)
replace INHTOT = . if (INHTOT >= 81 & INHTOT <= 99)
replace INHREC = . if (INHREC >= 81 & INHREC <= 99)
replace INHYRFRQ = . if (INHYRFRQ >= 81 & INHYRFRQ <= 99)
replace INHDY30A = . if (INHDY30A >= 81 & INHDY30A <= 99)
replace SKPANLRD = . if (SKPANLRD >= 81 & SKPANLRD <= 99)
replace ANLREAD = . if (ANLREAD >= 81 & ANLREAD <= 99)
replace CODEINE = . if (CODEINE >= 81 & CODEINE <= 99)
replace DARVON = . if (DARVON >= 81 & DARVON <= 99)
replace DEMEROL = . if (DEMEROL >= 81 & DEMEROL <= 99)
replace DILAUD = . if (DILAUD >= 81 & DILAUD <= 99)
replace METHDON = . if (METHDON >= 81 & METHDON <= 99)
replace MORPHINE = . if (MORPHINE >= 81 & MORPHINE <= 99)
replace PERCODAN = . if (PERCODAN >= 81 & PERCODAN <= 99)
replace TALWIN = . if (TALWIN >= 81 & TALWIN <= 99)
replace TYLCOD = . if (TYLCOD >= 81 & TYLCOD <= 99)
replace ANLDKNAM = . if (ANLDKNAM >= 81 & ANLDKNAM <= 99)
replace ANLNOLST = . if (ANLNOLST >= 81 & ANLNOLST <= 99)
replace ANALNEWA = . if (ANALNEWA >= 9981 & ANALNEWA <= 9999)
replace ANALNEWB = . if (ANALNEWB >= 9981 & ANALNEWB <= 9999)
replace ANALNEWC = . if (ANALNEWC >= 9981 & ANALNEWC <= 9999)
replace ANALNEWD = . if (ANALNEWD >= 9981 & ANALNEWD <= 9999)
replace ANALNEWE = . if (ANALNEWE >= 9981 & ANALNEWE <= 9999)
replace ANALNONE = . if (ANALNONE >= 81 & ANALNONE <= 99)
replace ANALAGE = . if (ANALAGE >= 981 & ANALAGE <= 999)
replace ANALTOT = . if (ANALTOT >= 81 & ANALTOT <= 99)
replace ANALREC = . if (ANALREC >= 81 & ANALREC <= 99)
replace ANLYRFRQ = . if (ANLYRFRQ >= 81 & ANLYRFRQ <= 99)
replace SKPTRNRD = . if (SKPTRNRD >= 81 & SKPTRNRD <= 99)
replace TRNREAD = . if (TRNREAD >= 81 & TRNREAD <= 99)
replace ATARAX = . if (ATARAX >= 81 & ATARAX <= 99)
replace ATIVAN = . if (ATIVAN >= 81 & ATIVAN <= 99)
replace DIAZEPAM = . if (DIAZEPAM >= 81 & DIAZEPAM <= 99)
replace LIBRIUM = . if (LIBRIUM >= 81 & LIBRIUM <= 99)
replace TRANXENE = . if (TRANXENE >= 81 & TRANXENE <= 99)
replace VALIUM = . if (VALIUM >= 81 & VALIUM <= 99)
replace XANAX = . if (XANAX >= 81 & XANAX <= 99)
replace TRDKNAM = . if (TRDKNAM >= 81 & TRDKNAM <= 99)
replace TRNOLST = . if (TRNOLST >= 81 & TRNOLST <= 99)
replace TRNEWA = . if (TRNEWA >= 9981 & TRNEWA <= 9999)
replace TRNEWB = . if (TRNEWB >= 9981 & TRNEWB <= 9999)
replace TRNEWC = . if (TRNEWC >= 9981 & TRNEWC <= 9999)
replace TRNEWD = . if (TRNEWD >= 9981 & TRNEWD <= 9999)
replace TRNEWE = . if (TRNEWE >= 9981 & TRNEWE <= 9999)
replace NOTRANQ = . if (NOTRANQ >= 81 & NOTRANQ <= 99)
replace TRANAGE = . if (TRANAGE >= 981 & TRANAGE <= 999)
replace TRANTOT = . if (TRANTOT >= 81 & TRANTOT <= 99)
replace TRANREC = . if (TRANREC >= 81 & TRANREC <= 99)
replace TRNYRFRQ = . if (TRNYRFRQ >= 81 & TRNYRFRQ <= 99)
replace SKPSTMRD = . if (SKPSTMRD >= 81 & SKPSTMRD <= 99)
replace STMREAD = . if (STMREAD >= 81 & STMREAD <= 99)
replace BENZ = . if (BENZ >= 81 & BENZ <= 99)
replace BIPHET = . if (BIPHET >= 81 & BIPHET <= 99)
replace DEXAMYL = . if (DEXAMYL >= 81 & DEXAMYL <= 99)
replace DEXED = . if (DEXED >= 81 & DEXED <= 99)
replace FASTIN = . if (FASTIN >= 81 & FASTIN <= 99)
replace IONAMIN = . if (IONAMIN >= 81 & IONAMIN <= 99)
replace METHAMP = . if (METHAMP >= 81 & METHAMP <= 99)
replace METHI = . if (METHI >= 81 & METHI <= 99)
replace PRELUDIN = . if (PRELUDIN >= 81 & PRELUDIN <= 99)
replace STMDKNAM = . if (STMDKNAM >= 81 & STMDKNAM <= 99)
replace STMNOLST = . if (STMNOLST >= 81 & STMNOLST <= 99)
replace STIMNEWA = . if (STIMNEWA >= 9981 & STIMNEWA <= 9999)
replace STIMNEWB = . if (STIMNEWB >= 9981 & STIMNEWB <= 9999)
replace STIMNEWC = . if (STIMNEWC >= 9981 & STIMNEWC <= 9999)
replace STIMNEWD = . if (STIMNEWD >= 9981 & STIMNEWD <= 9999)
replace STIMNEWE = . if (STIMNEWE >= 9981 & STIMNEWE <= 9999)
replace NOSTIMS = . if (NOSTIMS >= 81 & NOSTIMS <= 99)
replace STIMAGE = . if (STIMAGE >= 981 & STIMAGE <= 999)
replace STIMTOT = . if (STIMTOT >= 81 & STIMTOT <= 99)
replace STIMREC = . if (STIMREC >= 81 & STIMREC <= 99)
replace STMYRFRQ = . if (STMYRFRQ >= 81 & STMYRFRQ <= 99)
replace SKPSEDRD = . if (SKPSEDRD >= 81 & SKPSEDRD <= 99)
replace SEDREAD = . if (SEDREAD >= 81 & SEDREAD <= 99)
replace DALMANE = . if (DALMANE >= 81 & DALMANE <= 99)
replace HALCION = . if (HALCION >= 81 & HALCION <= 99)
replace METHAQ = . if (METHAQ >= 81 & METHAQ <= 99)
replace NEMBUTAL = . if (NEMBUTAL >= 81 & NEMBUTAL <= 99)
replace PHENOBAR = . if (PHENOBAR >= 81 & PHENOBAR <= 99)
replace PLACIDYL = . if (PLACIDYL >= 81 & PLACIDYL <= 99)
replace SECONAL = . if (SECONAL >= 81 & SECONAL <= 99)
replace TUINAL = . if (TUINAL >= 81 & TUINAL <= 99)
replace SEDDKNAM = . if (SEDDKNAM >= 81 & SEDDKNAM <= 99)
replace SEDNOLST = . if (SEDNOLST >= 81 & SEDNOLST <= 99)
replace SEDNEWA = . if (SEDNEWA >= 9981 & SEDNEWA <= 9999)
replace SEDNEWB = . if (SEDNEWB >= 9981 & SEDNEWB <= 9999)
replace SEDNEWC = . if (SEDNEWC >= 9981 & SEDNEWC <= 9999)
replace SEDNEWD = . if (SEDNEWD >= 9981 & SEDNEWD <= 9999)
replace SEDNEWE = . if (SEDNEWE >= 9981 & SEDNEWE <= 9999)
replace NOSEDAT = . if (NOSEDAT >= 81 & NOSEDAT <= 99)
replace SEDAGE = . if (SEDAGE >= 981 & SEDAGE <= 999)
replace SEDTOT = . if (SEDTOT >= 81 & SEDTOT <= 99)
replace SEDREC = . if (SEDREC >= 81 & SEDREC <= 99)
replace SEDYRFRQ = . if (SEDYRFRQ >= 81 & SEDYRFRQ <= 99)
replace BIRMONTH = . if (BIRMONTH >= 81 & BIRMONTH <= 99)
replace BIRYEAR = . if (BIRYEAR >= 9981 & BIRYEAR <= 9999)
replace IRAGE = . if (IRAGE >= 981 & IRAGE <= 999)
replace IRHOGRP = . if (IRHOGRP >= 81 & IRHOGRP <= 99)
replace IRHOGRP2 = . if (IRHOGRP2 >= 81 & IRHOGRP2 <= 99)
replace IRMARIT = . if (IRMARIT >= 81 & IRMARIT <= 99)
replace IREDUC = . if (IREDUC >= 81 & IREDUC <= 99)
replace IRWORKST = . if (IRWORKST >= 81 & IRWORKST <= 99)
replace IRALCFQ = . if (IRALCFQ >= 81 & IRALCFQ <= 99)
replace IRMJFQ = . if (IRMJFQ >= 81 & IRMJFQ <= 99)
replace IRCOCFQ = . if (IRCOCFQ >= 81 & IRCOCFQ <= 99)
replace IRCRKFQ = . if (IRCRKFQ >= 81 & IRCRKFQ <= 99)
replace IRHERFQ = . if (IRHERFQ >= 81 & IRHERFQ <= 99)
replace IRHALFQ = . if (IRHALFQ >= 81 & IRHALFQ <= 99)
replace IRINHFQ = . if (IRINHFQ >= 81 & IRINHFQ <= 99)
replace IRANLFQ = . if (IRANLFQ >= 81 & IRANLFQ <= 99)
replace IRTRNFQ = . if (IRTRNFQ >= 81 & IRTRNFQ <= 99)
replace IRSTMFQ = . if (IRSTMFQ >= 81 & IRSTMFQ <= 99)
replace IRSEDFQ = . if (IRSEDFQ >= 81 & IRSEDFQ <= 99)
replace BINGEDRK = . if (BINGEDRK >= 81 & BINGEDRK <= 99)
replace HVYDRK2 = . if (HVYDRK2 >= 81 & HVYDRK2 <= 99)
replace BINGEHVY = . if (BINGEHVY >= 81 & BINGEHVY <= 99)
replace CG04 = . if (CG04 >= 81 & CG04 <= 99)
replace CG12 = . if (CG12 >= 81 & CG12 <= 99)
replace AL03 = . if (AL03 >= 81 & AL03 <= 99)
replace MJ04 = . if (MJ04 >= 81 & MJ04 <= 99)
replace CC04 = . if (CC04 >= 81 & CC04 <= 99)
replace CK04 = . if (CK04 >= 81 & CK04 <= 99)
replace HE04 = . if (HE04 >= 81 & HE04 <= 99)
replace LS04 = . if (LS04 >= 81 & LS04 <= 99)
replace LS07 = . if (LS07 >= 81 & LS07 <= 99)
replace LS08 = . if (LS08 >= 81 & LS08 <= 99)
replace IN04 = . if (IN04 >= 81 & IN04 <= 99)
replace PK04 = . if (PK04 >= 81 & PK04 <= 99)
replace TR04 = . if (TR04 >= 81 & TR04 <= 99)
replace ST04 = . if (ST04 >= 81 & ST04 <= 99)
replace SE04 = . if (SE04 >= 81 & SE04 <= 99)
replace SKPSDRD = . if (SKPSDRD >= 81 & SKPSDRD <= 99)
replace SDREAD = . if (SDREAD >= 81 & SDREAD <= 99)
replace HRANYFRM = . if (HRANYFRM >= 81 & HRANYFRM <= 99)
replace HERSMOKE = . if (HERSMOKE >= 81 & HERSMOKE <= 99)
replace HRSMKREC = . if (HRSMKREC >= 81 & HRSMKREC <= 99)
replace HERSNIFF = . if (HERSNIFF >= 81 & HERSNIFF <= 99)
replace HRSNFREC = . if (HRSNFREC >= 81 & HRSNFREC <= 99)
replace GNNDLLIF = . if (GNNDLLIF >= 81 & GNNDLLIF <= 99)
replace COCNEEDL = . if (COCNEEDL >= 81 & COCNEEDL <= 99)
replace CONDLREC = . if (CONDLREC >= 81 & CONDLREC <= 99)
replace HERNEEDL = . if (HERNEEDL >= 81 & HERNEEDL <= 99)
replace HRNDLREC = . if (HRNDLREC >= 81 & HRNDLREC <= 99)
replace STNEEDLE = . if (STNEEDLE >= 81 & STNEEDLE <= 99)
replace STNDLREC = . if (STNDLREC >= 81 & STNDLREC <= 99)
replace GNNDREUS = . if (GNNDREUS >= 81 & GNNDREUS <= 99)
replace GNNDLSH1 = . if (GNNDLSH1 >= 81 & GNNDLSH1 <= 99)
replace GNNDCLEN = . if (GNNDCLEN >= 81 & GNNDCLEN <= 99)
replace GNNDLSH2 = . if (GNNDLSH2 >= 81 & GNNDLSH2 <= 99)
replace GNNDGET = . if (GNNDGET >= 81 & GNNDGET <= 99)
replace GNNDGTSP = . if (GNNDGTSP >= 81 & GNNDGTSP <= 99)
replace SKPDRGRD = . if (SKPDRGRD >= 81 & SKPDRGRD <= 99)
replace DRGREAD = . if (DRGREAD >= 81 & DRGREAD <= 99)
replace USEDCIG = . if (USEDCIG >= 81 & USEDCIG <= 99)
replace USEDALC = . if (USEDALC >= 81 & USEDALC <= 99)
replace USEDMRJ = . if (USEDMRJ >= 81 & USEDMRJ <= 99)
replace USEDCOC = . if (USEDCOC >= 81 & USEDCOC <= 99)
replace USEDHER = . if (USEDHER >= 81 & USEDHER <= 99)
replace USEDHAL = . if (USEDHAL >= 81 & USEDHAL <= 99)
replace USEDINH = . if (USEDINH >= 81 & USEDINH <= 99)
replace USEDANL = . if (USEDANL >= 81 & USEDANL <= 99)
replace USEDTRN = . if (USEDTRN >= 81 & USEDTRN <= 99)
replace USEDSTM = . if (USEDSTM >= 81 & USEDSTM <= 99)
replace USEDSED = . if (USEDSED >= 81 & USEDSED <= 99)
replace NODRUGYR = . if (NODRUGYR >= 81 & NODRUGYR <= 99)
replace GRTMCIG = . if (GRTMCIG >= 81 & GRTMCIG <= 99)
replace GRTMALC = . if (GRTMALC >= 81 & GRTMALC <= 99)
replace GRTMMRJ = . if (GRTMMRJ >= 81 & GRTMMRJ <= 99)
replace GRTMCOC = . if (GRTMCOC >= 81 & GRTMCOC <= 99)
replace GRTMHER = . if (GRTMHER >= 81 & GRTMHER <= 99)
replace GRTMHAL = . if (GRTMHAL >= 81 & GRTMHAL <= 99)
replace GRTMINH = . if (GRTMINH >= 81 & GRTMINH <= 99)
replace GRTMANL = . if (GRTMANL >= 81 & GRTMANL <= 99)
replace GRTMTRN = . if (GRTMTRN >= 81 & GRTMTRN <= 99)
replace GRTMSTM = . if (GRTMSTM >= 81 & GRTMSTM <= 99)
replace GRTMSED = . if (GRTMSED >= 81 & GRTMSED <= 99)
replace LAMTCIG = . if (LAMTCIG >= 81 & LAMTCIG <= 99)
replace LAMTALC = . if (LAMTALC >= 81 & LAMTALC <= 99)
replace LAMTMRJ = . if (LAMTMRJ >= 81 & LAMTMRJ <= 99)
replace LAMTCOC = . if (LAMTCOC >= 81 & LAMTCOC <= 99)
replace LAMTHER = . if (LAMTHER >= 81 & LAMTHER <= 99)
replace LAMTHAL = . if (LAMTHAL >= 81 & LAMTHAL <= 99)
replace LAMTINH = . if (LAMTINH >= 81 & LAMTINH <= 99)
replace LAMTANL = . if (LAMTANL >= 81 & LAMTANL <= 99)
replace LAMTTRN = . if (LAMTTRN >= 81 & LAMTTRN <= 99)
replace LAMTSTM = . if (LAMTSTM >= 81 & LAMTSTM <= 99)
replace LAMTSED = . if (LAMTSED >= 81 & LAMTSED <= 99)
replace BTOLCIG = . if (BTOLCIG >= 81 & BTOLCIG <= 99)
replace BTOLALC = . if (BTOLALC >= 81 & BTOLALC <= 99)
replace BTOLMRJ = . if (BTOLMRJ >= 81 & BTOLMRJ <= 99)
replace BTOLCOC = . if (BTOLCOC >= 81 & BTOLCOC <= 99)
replace BTOLHER = . if (BTOLHER >= 81 & BTOLHER <= 99)
replace BTOLHAL = . if (BTOLHAL >= 81 & BTOLHAL <= 99)
replace BTOLINH = . if (BTOLINH >= 81 & BTOLINH <= 99)
replace BTOLANL = . if (BTOLANL >= 81 & BTOLANL <= 99)
replace BTOLTRN = . if (BTOLTRN >= 81 & BTOLTRN <= 99)
replace BTOLSTM = . if (BTOLSTM >= 81 & BTOLSTM <= 99)
replace BTOLSED = . if (BTOLSED >= 81 & BTOLSED <= 99)
replace ACRDCIG = . if (ACRDCIG >= 81 & ACRDCIG <= 99)
replace ACRDALC = . if (ACRDALC >= 81 & ACRDALC <= 99)
replace ACRDMRJ = . if (ACRDMRJ >= 81 & ACRDMRJ <= 99)
replace ACRDCOC = . if (ACRDCOC >= 81 & ACRDCOC <= 99)
replace ACRDHER = . if (ACRDHER >= 81 & ACRDHER <= 99)
replace ACRDHAL = . if (ACRDHAL >= 81 & ACRDHAL <= 99)
replace ACRDINH = . if (ACRDINH >= 81 & ACRDINH <= 99)
replace ACRDANL = . if (ACRDANL >= 81 & ACRDANL <= 99)
replace ACRDTRN = . if (ACRDTRN >= 81 & ACRDTRN <= 99)
replace ACRDSTM = . if (ACRDSTM >= 81 & ACRDSTM <= 99)
replace ACRDSED = . if (ACRDSED >= 81 & ACRDSED <= 99)
replace EMPBCIG = . if (EMPBCIG >= 81 & EMPBCIG <= 99)
replace EMPBALC = . if (EMPBALC >= 81 & EMPBALC <= 99)
replace EMPBMRJ = . if (EMPBMRJ >= 81 & EMPBMRJ <= 99)
replace EMPBCOC = . if (EMPBCOC >= 81 & EMPBCOC <= 99)
replace EMPBHER = . if (EMPBHER >= 81 & EMPBHER <= 99)
replace EMPBHAL = . if (EMPBHAL >= 81 & EMPBHAL <= 99)
replace EMPBINH = . if (EMPBINH >= 81 & EMPBINH <= 99)
replace EMPBANL = . if (EMPBANL >= 81 & EMPBANL <= 99)
replace EMPBTRN = . if (EMPBTRN >= 81 & EMPBTRN <= 99)
replace EMPBSTM = . if (EMPBSTM >= 81 & EMPBSTM <= 99)
replace EMPBSED = . if (EMPBSED >= 81 & EMPBSED <= 99)
replace HLPBCIG = . if (HLPBCIG >= 81 & HLPBCIG <= 99)
replace HLPBALC = . if (HLPBALC >= 81 & HLPBALC <= 99)
replace HLPBMRJ = . if (HLPBMRJ >= 81 & HLPBMRJ <= 99)
replace HLPBCOC = . if (HLPBCOC >= 81 & HLPBCOC <= 99)
replace HLPBHER = . if (HLPBHER >= 81 & HLPBHER <= 99)
replace HLPBHAL = . if (HLPBHAL >= 81 & HLPBHAL <= 99)
replace HLPBINH = . if (HLPBINH >= 81 & HLPBINH <= 99)
replace HLPBANL = . if (HLPBANL >= 81 & HLPBANL <= 99)
replace HLPBTRN = . if (HLPBTRN >= 81 & HLPBTRN <= 99)
replace HLPBSTM = . if (HLPBSTM >= 81 & HLPBSTM <= 99)
replace HLPBSED = . if (HLPBSED >= 81 & HLPBSED <= 99)
replace UCDCIG = . if (UCDCIG >= 81 & UCDCIG <= 99)
replace UCDALC = . if (UCDALC >= 81 & UCDALC <= 99)
replace UCDMRJ = . if (UCDMRJ >= 81 & UCDMRJ <= 99)
replace UCDCOC = . if (UCDCOC >= 81 & UCDCOC <= 99)
replace UCDHER = . if (UCDHER >= 81 & UCDHER <= 99)
replace UCDHAL = . if (UCDHAL >= 81 & UCDHAL <= 99)
replace UCDINH = . if (UCDINH >= 81 & UCDINH <= 99)
replace UCDANL = . if (UCDANL >= 81 & UCDANL <= 99)
replace UCDTRN = . if (UCDTRN >= 81 & UCDTRN <= 99)
replace UCDSTM = . if (UCDSTM >= 81 & UCDSTM <= 99)
replace UCDSED = . if (UCDSED >= 81 & UCDSED <= 99)
replace SKPSPTRD = . if (SKPSPTRD >= 81 & SKPSPTRD <= 99)
replace SPTREAD = . if (SPTREAD >= 81 & SPTREAD <= 99)
replace NDTXRCVD = . if (NDTXRCVD >= 81 & NDTXRCVD <= 99)
replace NDTXNEED = . if (NDTXNEED >= 81 & NDTXNEED <= 99)
replace NDTXALC = . if (NDTXALC >= 81 & NDTXALC <= 99)
replace NDTXMJ = . if (NDTXMJ >= 81 & NDTXMJ <= 99)
replace NDTXCOC = . if (NDTXCOC >= 81 & NDTXCOC <= 99)
replace NDTXHER = . if (NDTXHER >= 81 & NDTXHER <= 99)
replace NDTXHAL = . if (NDTXHAL >= 81 & NDTXHAL <= 99)
replace NDTXINH = . if (NDTXINH >= 81 & NDTXINH <= 99)
replace NDTXANL = . if (NDTXANL >= 81 & NDTXANL <= 99)
replace NDTXTRAN = . if (NDTXTRAN >= 81 & NDTXTRAN <= 99)
replace NDTXSTIM = . if (NDTXSTIM >= 81 & NDTXSTIM <= 99)
replace NDTXSED = . if (NDTXSED >= 81 & NDTXSED <= 99)
replace NDTXSOD = . if (NDTXSOD >= 81 & NDTXSOD <= 99)
replace NDTXDRG1 = . if (NDTXDRG1 >= 9981 & NDTXDRG1 <= 9999)
replace NDTXDRG2 = . if (NDTXDRG2 >= 9981 & NDTXDRG2 <= 9999)
replace NDTXDRG3 = . if (NDTXDRG3 >= 9981 & NDTXDRG3 <= 9999)
replace NDTXDRG4 = . if (NDTXDRG4 >= 9981 & NDTXDRG4 <= 9999)
replace NDTXDRG5 = . if (NDTXDRG5 >= 9981 & NDTXDRG5 <= 9999)
replace NDTXSTEP = . if (NDTXSTEP >= 81 & NDTXSTEP <= 99)
replace NDTXTRSP = . if (NDTXTRSP >= 81 & NDTXTRSP <= 99)
replace NDTXTFAR = . if (NDTXTFAR >= 81 & NDTXTFAR <= 99)
replace NDTXBDHR = . if (NDTXBDHR >= 81 & NDTXBDHR <= 99)
replace NDTXOPEN = . if (NDTXOPEN >= 81 & NDTXOPEN <= 99)
replace NDTXTYPE = . if (NDTXTYPE >= 81 & NDTXTYPE <= 99)
replace NDTXMONY = . if (NDTXMONY >= 81 & NDTXMONY <= 99)
replace NDTXHCAP = . if (NDTXHCAP >= 81 & NDTXHCAP <= 99)
replace NDTXTCMP = . if (NDTXTCMP >= 81 & NDTXTCMP <= 99)
replace NDTXLANG = . if (NDTXLANG >= 81 & NDTXLANG <= 99)
replace NDTXSPSV = . if (NDTXSPSV >= 81 & NDTXSPSV <= 99)
replace NDTXSOR = . if (NDTXSOR >= 81 & NDTXSOR <= 99)
replace NDTXRSC1 = . if (NDTXRSC1 >= 81 & NDTXRSC1 <= 99)
replace BOOKED = . if (BOOKED >= 81 & BOOKED <= 99)
replace NOBOOKYR = . if (NOBOOKYR >= 81 & NOBOOKYR <= 99)
replace BKLARCNY = . if (BKLARCNY >= 81 & BKLARCNY <= 99)
replace BKBURGL = . if (BKBURGL >= 81 & BKBURGL <= 99)
replace BKAGASLT = . if (BKAGASLT >= 81 & BKAGASLT <= 99)
replace BKSMASLT = . if (BKSMASLT >= 81 & BKSMASLT <= 99)
replace BKMVTHFT = . if (BKMVTHFT >= 81 & BKMVTHFT <= 99)
replace BKROB = . if (BKROB >= 81 & BKROB <= 99)
replace BKRAPE = . if (BKRAPE >= 81 & BKRAPE <= 99)
replace BKMURDER = . if (BKMURDER >= 81 & BKMURDER <= 99)
replace BKARSON = . if (BKARSON >= 81 & BKARSON <= 99)
replace BKDRVINF = . if (BKDRVINF >= 81 & BKDRVINF <= 99)
replace BKDRUNK = . if (BKDRUNK >= 81 & BKDRUNK <= 99)
replace BKDRUG = . if (BKDRUG >= 81 & BKDRUG <= 99)
replace BKPROS = . if (BKPROS >= 81 & BKPROS <= 99)
replace BKVANDAL = . if (BKVANDAL >= 81 & BKVANDAL <= 99)
replace BKOTH = . if (BKOTH >= 81 & BKOTH <= 99)
replace BKOTHOFF = . if (BKOTHOFF >= 81 & BKOTHOFF <= 99)
replace PROBATON = . if (PROBATON >= 81 & PROBATON <= 99)
replace PAROLE = . if (PAROLE >= 81 & PAROLE <= 99)
replace STRSTEAL = . if (STRSTEAL >= 81 & STRSTEAL <= 99)
replace OTHSTEAL = . if (OTHSTEAL >= 81 & OTHSTEAL <= 99)
replace DAMAGE = . if (DAMAGE >= 81 & DAMAGE <= 99)
replace CARSTEAL = . if (CARSTEAL >= 81 & CARSTEAL <= 99)
replace FORCEMON = . if (FORCEMON >= 81 & FORCEMON <= 99)
replace BREAKIN = . if (BREAKIN >= 81 & BREAKIN <= 99)
replace PHYFIGHT = . if (PHYFIGHT >= 81 & PHYFIGHT <= 99)
replace HURTBAD = . if (HURTBAD >= 81 & HURTBAD <= 99)
replace GUNMONEY = . if (GUNMONEY >= 81 & GUNMONEY <= 99)
replace DRVALDR = . if (DRVALDR >= 81 & DRVALDR <= 99)
replace DRIVEAL = . if (DRIVEAL >= 81 & DRIVEAL <= 99)
replace DRIVEDR = . if (DRIVEDR >= 81 & DRIVEDR <= 99)
replace SOLDDRUG = . if (SOLDDRUG >= 81 & SOLDDRUG <= 99)
replace OTHDOING = . if (OTHDOING >= 81 & OTHDOING <= 99)
replace OTHDOSP1 = . if (OTHDOSP1 >= 81 & OTHDOSP1 <= 99)
replace OTHDOSP2 = . if (OTHDOSP2 >= 81 & OTHDOSP2 <= 99)
replace SKPTMTRD = . if (SKPTMTRD >= 81 & SKPTMTRD <= 99)
replace TMTREAD = . if (TMTREAD >= 81 & TMTREAD <= 99)
replace TXEVER = . if (TXEVER >= 81 & TXEVER <= 99)
replace TXTIMELF = . if (TXTIMELF >= 981 & TXTIMELF <= 999)
replace TXYRFREQ = . if (TXYRFREQ >= 981 & TXYRFREQ <= 999)
replace TXALHOSP = . if (TXALHOSP >= 81 & TXALHOSP <= 99)
replace TXALRFIN = . if (TXALRFIN >= 81 & TXALRFIN <= 99)
replace TXALRFOP = . if (TXALRFOP >= 81 & TXALRFOP <= 99)
replace TXALMHC = . if (TXALMHC >= 81 & TXALMHC <= 99)
replace TXALEMRG = . if (TXALEMRG >= 81 & TXALEMRG <= 99)
replace TXALDOC = . if (TXALDOC >= 81 & TXALDOC <= 99)
replace TXALJAIL = . if (TXALJAIL >= 81 & TXALJAIL <= 99)
replace TXALSHG = . if (TXALSHG >= 81 & TXALSHG <= 99)
replace TXALSOP = . if (TXALSOP >= 81 & TXALSOP <= 99)
replace TXALSP = . if (TXALSP >= 81 & TXALSP <= 99)
replace TXDRHOSP = . if (TXDRHOSP >= 81 & TXDRHOSP <= 99)
replace TXDRFIN = . if (TXDRFIN >= 81 & TXDRFIN <= 99)
replace TXDRFOP = . if (TXDRFOP >= 81 & TXDRFOP <= 99)
replace TXDRMHC = . if (TXDRMHC >= 81 & TXDRMHC <= 99)
replace TXDREMRG = . if (TXDREMRG >= 81 & TXDREMRG <= 99)
replace TXDRDOC = . if (TXDRDOC >= 81 & TXDRDOC <= 99)
replace TXDRJAIL = . if (TXDRJAIL >= 81 & TXDRJAIL <= 99)
replace TXDRSHG = . if (TXDRSHG >= 81 & TXDRSHG <= 99)
replace TXDRSOP = . if (TXDRSOP >= 81 & TXDRSOP <= 99)
replace TXDRSP = . if (TXDRSP >= 81 & TXDRSP <= 99)
replace TXYREMRG = . if (TXYREMRG >= 981 & TXYREMRG <= 999)
replace TXADGREC = . if (TXADGREC >= 81 & TXADGREC <= 99)
replace TXLTHOSP = . if (TXLTHOSP >= 81 & TXLTHOSP <= 99)
replace TXLTRFIN = . if (TXLTRFIN >= 81 & TXLTRFIN <= 99)
replace TXLTRFOP = . if (TXLTRFOP >= 81 & TXLTRFOP <= 99)
replace TXLTMHC = . if (TXLTMHC >= 81 & TXLTMHC <= 99)
replace TXLTEMRG = . if (TXLTEMRG >= 81 & TXLTEMRG <= 99)
replace TXLTDOC = . if (TXLTDOC >= 81 & TXLTDOC <= 99)
replace TXLTJAIL = . if (TXLTJAIL >= 81 & TXLTJAIL <= 99)
replace TXLTSHG = . if (TXLTSHG >= 81 & TXLTSHG <= 99)
replace TXLTSOP = . if (TXLTSOP >= 81 & TXLTSOP <= 99)
replace TXLTSP = . if (TXLTSP >= 81 & TXLTSP <= 99)
replace TXLTALC = . if (TXLTALC >= 81 & TXLTALC <= 99)
replace TXLTMJ = . if (TXLTMJ >= 81 & TXLTMJ <= 99)
replace TXLTCOC = . if (TXLTCOC >= 81 & TXLTCOC <= 99)
replace TXLTHER = . if (TXLTHER >= 81 & TXLTHER <= 99)
replace TXLTHAL = . if (TXLTHAL >= 81 & TXLTHAL <= 99)
replace TXLTINH = . if (TXLTINH >= 81 & TXLTINH <= 99)
replace TXLTANL = . if (TXLTANL >= 81 & TXLTANL <= 99)
replace TXLTRAN = . if (TXLTRAN >= 81 & TXLTRAN <= 99)
replace TXLTSTIM = . if (TXLTSTIM >= 81 & TXLTSTIM <= 99)
replace TXLTSED = . if (TXLTSED >= 81 & TXLTSED <= 99)
replace TXLTSOD = . if (TXLTSOD >= 81 & TXLTSOD <= 99)
replace TXLTA = . if (TXLTA >= 9981 & TXLTA <= 9999)
replace TXLTB = . if (TXLTB >= 9981 & TXLTB <= 9999)
replace TXLTC = . if (TXLTC >= 9981 & TXLTC <= 9999)
replace TXLTD = . if (TXLTD >= 9981 & TXLTD <= 9999)
replace TXLTE = . if (TXLTE >= 9981 & TXLTE <= 9999)
replace TXDRGA = . if (TXDRGA >= 9981 & TXDRGA <= 9999)
replace TXDRGB = . if (TXDRGB >= 9981 & TXDRGB <= 9999)
replace TXDRGC = . if (TXDRGC >= 9981 & TXDRGC <= 9999)
replace TXDRGD = . if (TXDRGD >= 9981 & TXDRGD <= 9999)
replace TXDRGE = . if (TXDRGE >= 9981 & TXDRGE <= 9999)
replace TXOUTC = . if (TXOUTC >= 81 & TXOUTC <= 99)
replace TXTIME = . if (TXTIME >= 9981 & TXTIME <= 9999)
replace TXPDINS = . if (TXPDINS >= 81 & TXPDINS <= 99)
replace TXPDCARE = . if (TXPDCARE >= 81 & TXPDCARE <= 99)
replace TXPDCAID = . if (TXPDCAID >= 81 & TXPDCAID <= 99)
replace TXPDSAVE = . if (TXPDSAVE >= 81 & TXPDSAVE <= 99)
replace TXPDFMLY = . if (TXPDFMLY >= 81 & TXPDFMLY <= 99)
replace TXPDEMPL = . if (TXPDEMPL >= 81 & TXPDEMPL <= 99)
replace TXPDFREE = . if (TXPDFREE >= 81 & TXPDFREE <= 99)
replace TXPDSOS = . if (TXPDSOS >= 81 & TXPDSOS <= 99)
replace TXPDSP = . if (TXPDSP >= 81 & TXPDSP <= 99)
replace TXENROLL = . if (TXENROLL >= 81 & TXENROLL <= 99)
replace SKPYCANS = . if (SKPYCANS == 9)
replace SKPYCRD = . if (SKPYCRD >= 81 & SKPYCRD <= 99)
replace YCREAD = . if (YCREAD >= 81 & YCREAD <= 99)
replace YACTYNG = . if (YACTYNG >= 81 & YACTYNG <= 99)
replace YALLERGY = . if (YALLERGY >= 81 & YALLERGY <= 99)
replace YARGUE = . if (YARGUE >= 81 & YARGUE <= 99)
replace YASTHMA = . if (YASTHMA >= 81 & YASTHMA <= 99)
replace YACOPPSX = . if (YACOPPSX >= 81 & YACOPPSX <= 99)
replace YLKANIML = . if (YLKANIML >= 81 & YLKANIML <= 99)
replace YBRAG = . if (YBRAG >= 81 & YBRAG <= 99)
replace YTRBCONC = . if (YTRBCONC >= 81 & YTRBCONC <= 99)
replace YCNTHGTS = . if (YCNTHGTS >= 81 & YCNTHGTS <= 99)
replace YTRBSIT = . if (YTRBSIT >= 81 & YTRBSIT <= 99)
replace YDPTADLT = . if (YDPTADLT >= 81 & YDPTADLT <= 99)
replace YFLONELY = . if (YFLONELY >= 81 & YFLONELY <= 99)
replace YFLCONFU = . if (YFLCONFU >= 81 & YFLCONFU <= 99)
replace YCRYLOT = . if (YCRYLOT >= 81 & YCRYLOT <= 99)
replace YHONEST = . if (YHONEST >= 81 & YHONEST <= 99)
replace YMEANOTH = . if (YMEANOTH >= 81 & YMEANOTH <= 99)
replace YDAYDREM = . if (YDAYDREM >= 81 & YDAYDREM <= 99)
replace YTRYKLSF = . if (YTRYKLSF >= 81 & YTRYKLSF <= 99)
replace YTRYATTN = . if (YTRYATTN >= 81 & YTRYATTN <= 99)
replace YDSTYTHG = . if (YDSTYTHG >= 81 & YDSTYTHG <= 99)
replace YDSTYOTH = . if (YDSTYOTH >= 81 & YDSTYOTH <= 99)
replace YDSBYPAR = . if (YDSBYPAR >= 81 & YDSBYPAR <= 99)
replace YDSBYSCH = . if (YDSBYSCH >= 81 & YDSBYSCH <= 99)
replace YDNTEATW = . if (YDNTEATW >= 81 & YDNTEATW <= 99)
replace YDNTKIDS = . if (YDNTKIDS >= 81 & YDNTKIDS <= 99)
replace YDNTGLTY = . if (YDNTGLTY >= 81 & YDNTGLTY <= 99)
replace YJEALOTH = . if (YJEALOTH >= 81 & YJEALOTH <= 99)
replace YHELPOTH = . if (YHELPOTH >= 81 & YHELPOTH <= 99)
replace YAFRPLAC = . if (YAFRPLAC >= 81 & YAFRPLAC <= 99)
replace YAFRSCHL = . if (YAFRSCHL >= 81 & YAFRSCHL <= 99)
replace YAFRBAD = . if (YAFRBAD >= 81 & YAFRBAD <= 99)
replace YFLPRFCT = . if (YFLPRFCT >= 81 & YFLPRFCT <= 99)
replace YFLNOLOV = . if (YFLNOLOV >= 81 & YFLNOLOV <= 99)
replace YFLGETME = . if (YFLGETME >= 81 & YFLGETME <= 99)
replace YFLWTHLS = . if (YFLWTHLS >= 81 & YFLWTHLS <= 99)
replace YACCHURT = . if (YACCHURT >= 81 & YACCHURT <= 99)
replace YFIGHTS = . if (YFIGHTS >= 81 & YFIGHTS <= 99)
replace YGTEASED = . if (YGTEASED >= 81 & YGTEASED <= 99)
replace YKIDSTRB = . if (YKIDSTRB >= 81 & YKIDSTRB <= 99)
replace YHRVOICS = . if (YHRVOICS >= 81 & YHRVOICS <= 99)
replace YACTTNK = . if (YACTTNK >= 81 & YACTTNK <= 99)
replace YALONE = . if (YALONE >= 81 & YALONE <= 99)
replace YLIE = . if (YLIE >= 81 & YLIE <= 99)
replace YBITNAIL = . if (YBITNAIL >= 81 & YBITNAIL <= 99)
replace YNERVOUS = . if (YNERVOUS >= 81 & YNERVOUS <= 99)
replace YBTWITCH = . if (YBTWITCH >= 81 & YBTWITCH <= 99)
replace YNGHTMAR = . if (YNGHTMAR >= 81 & YNGHTMAR <= 99)
replace YNOTKIDS = . if (YNOTKIDS >= 81 & YNOTKIDS <= 99)
replace YDOBETTR = . if (YDOBETTR >= 81 & YDOBETTR <= 99)
replace YANXIOUS = . if (YANXIOUS >= 81 & YANXIOUS <= 99)
replace YFLDIZZY = . if (YFLDIZZY >= 81 & YFLDIZZY <= 99)
replace YFLGUILT = . if (YFLGUILT >= 81 & YFLGUILT <= 99)
replace YEATMUCH = . if (YEATMUCH >= 81 & YEATMUCH <= 99)
replace YFLTIRED = . if (YFLTIRED >= 81 & YFLTIRED <= 99)
replace YOVRWGHT = . if (YOVRWGHT >= 81 & YOVRWGHT <= 99)
replace YACHES = . if (YACHES >= 81 & YACHES <= 99)
replace YHEADACH = . if (YHEADACH >= 81 & YHEADACH <= 99)
replace YNAUSEA = . if (YNAUSEA >= 81 & YNAUSEA <= 99)
replace YEYEPROB = . if (YEYEPROB >= 81 & YEYEPROB <= 99)
replace YRASHES = . if (YRASHES >= 81 & YRASHES <= 99)
replace YCRAMPS = . if (YCRAMPS >= 81 & YCRAMPS <= 99)
replace YVOMIT = . if (YVOMIT >= 81 & YVOMIT <= 99)
replace YATTACK = . if (YATTACK >= 81 & YATTACK <= 99)
replace YPKBPART = . if (YPKBPART >= 81 & YPKBPART <= 99)
replace YPFRNDLY = . if (YPFRNDLY >= 81 & YPFRNDLY <= 99)
replace YTRYTHNG = . if (YTRYTHNG >= 81 & YTRYTHNG <= 99)
replace YSCPOOR = . if (YSCPOOR >= 81 & YSCPOOR <= 99)
replace YCLUMSY = . if (YCLUMSY >= 81 & YCLUMSY <= 99)
replace YOLDKIDS = . if (YOLDKIDS >= 81 & YOLDKIDS <= 99)
replace YYNGKIDS = . if (YYNGKIDS >= 81 & YYNGKIDS <= 99)
replace YRFSTALK = . if (YRFSTALK >= 81 & YRFSTALK <= 99)
replace YREPACTN = . if (YREPACTN >= 81 & YREPACTN <= 99)
replace YRUNHOME = . if (YRUNHOME >= 81 & YRUNHOME <= 99)
replace YSCREAM = . if (YSCREAM >= 81 & YSCREAM <= 99)
replace YSECRET = . if (YSECRET >= 81 & YSECRET <= 99)
replace YSEETHNG = . if (YSEETHNG >= 81 & YSEETHNG <= 99)
replace YSLFCONS = . if (YSLFCONS >= 81 & YSLFCONS <= 99)
replace YSETFIRE = . if (YSETFIRE >= 81 & YSETFIRE <= 99)
replace YWELHNDS = . if (YWELHNDS >= 81 & YWELHNDS <= 99)
replace YSHOWOFF = . if (YSHOWOFF >= 81 & YSHOWOFF <= 99)
replace YSHY = . if (YSHY >= 81 & YSHY <= 99)
replace YSLPLESS = . if (YSLPLESS >= 81 & YSLPLESS <= 99)
replace YSLPMORE = . if (YSLPMORE >= 81 & YSLPMORE <= 99)
replace YGDIMAG = . if (YGDIMAG >= 81 & YGDIMAG <= 99)
replace YSPCHPRB = . if (YSPCHPRB >= 81 & YSPCHPRB <= 99)
replace YSTDRGHT = . if (YSTDRGHT >= 81 & YSTDRGHT <= 99)
replace YSTEALHO = . if (YSTEALHO >= 81 & YSTEALHO <= 99)
replace YSTEALPL = . if (YSTEALPL >= 81 & YSTEALPL <= 99)
replace YDNTNEED = . if (YDNTNEED >= 81 & YDNTNEED <= 99)
replace YDOSTRNG = . if (YDOSTRNG >= 81 & YDOSTRNG <= 99)
replace YTHSTRNG = . if (YTHSTRNG >= 81 & YTHSTRNG <= 99)
replace YSTUBORN = . if (YSTUBORN >= 81 & YSTUBORN <= 99)
replace YMOODS = . if (YMOODS >= 81 & YMOODS <= 99)
replace YENJOY = . if (YENJOY >= 81 & YENJOY <= 99)
replace YSUSPICS = . if (YSUSPICS >= 81 & YSUSPICS <= 99)
replace YDRTLANG = . if (YDRTLANG >= 81 & YDRTLANG <= 99)
replace YTHKKLSF = . if (YTHKKLSF >= 81 & YTHKKLSF <= 99)
replace YLKLAUGH = . if (YLKLAUGH >= 81 & YLKLAUGH <= 99)
replace YTALKMCH = . if (YTALKMCH >= 81 & YTALKMCH <= 99)
replace YTEASE = . if (YTEASE >= 81 & YTEASE <= 99)
replace YTEMPER = . if (YTEMPER >= 81 & YTEMPER <= 99)
replace YTHNKSEX = . if (YTHNKSEX >= 81 & YTHNKSEX <= 99)
replace YTHRTPEO = . if (YTHRTPEO >= 81 & YTHRTPEO <= 99)
replace YLKHELP = . if (YLKHELP >= 81 & YLKHELP <= 99)
replace YCONNEAT = . if (YCONNEAT >= 81 & YCONNEAT <= 99)
replace YTRBSLEP = . if (YTRBSLEP >= 81 & YTRBSLEP <= 99)
replace YSKIPSCH = . if (YSKIPSCH >= 81 & YSKIPSCH <= 99)
replace YNOENRGY = . if (YNOENRGY >= 81 & YNOENRGY <= 99)
replace YUNHAPPY = . if (YUNHAPPY >= 81 & YUNHAPPY <= 99)
replace YLOUDER = . if (YLOUDER >= 81 & YLOUDER <= 99)
replace YUSEDRUG = . if (YUSEDRUG >= 81 & YUSEDRUG <= 99)
replace YFAIROTH = . if (YFAIROTH >= 81 & YFAIROTH <= 99)
replace YENJYJOK = . if (YENJYJOK >= 81 & YENJYJOK <= 99)
replace YLIFEASY = . if (YLIFEASY >= 81 & YLIFEASY <= 99)
replace YTRYHELP = . if (YTRYHELP >= 81 & YTRYHELP <= 99)
replace YWSOPPSX = . if (YWSOPPSX >= 81 & YWSOPPSX <= 99)
replace YINVOTH = . if (YINVOTH >= 81 & YINVOTH <= 99)
replace YWORRY = . if (YWORRY >= 81 & YWORRY <= 99)
replace MOVESPYR = . if (MOVESPYR >= 81 & MOVESPYR <= 99)
replace STUDENT = . if (STUDENT >= 81 & STUDENT <= 99)
replace ESTUDENT = . if (ESTUDENT >= 81 & ESTUDENT <= 99)
replace SCHDAYS = . if (SCHDAYS >= 81 & SCHDAYS <= 99)
replace ESCHDAYS = . if (ESCHDAYS >= 81 & ESCHDAYS <= 99)
replace SKIPPED = . if (SKIPPED >= 81 & SKIPPED <= 99)
replace ESKIPPED = . if (ESKIPPED >= 81 & ESKIPPED <= 99)
replace NJOBSPYR = . if (NJOBSPYR >= 81 & NJOBSPYR <= 99)
replace PAYMO = . if (PAYMO >= 81 & PAYMO <= 99)
replace PAYYR = . if (PAYYR >= 981 & PAYYR <= 999)
replace SKPWKST3 = . if (SKPWKST3 >= 81 & SKPWKST3 <= 99)
replace WORKDAYS = . if (WORKDAYS >= 81 & WORKDAYS <= 99)
replace WORKBLAH = . if (WORKBLAH >= 81 & WORKBLAH <= 99)
replace SKPPREG = . if (SKPPREG == 9)
replace PREGNANT = . if (PREGNANT >= 81 & PREGNANT <= 99)
replace PREGMOS = . if (PREGMOS >= 81 & PREGMOS <= 99)
replace SKPCWE = . if (SKPCWE == 9)
replace CWE = . if (CWE >= 81 & CWE <= 99)
replace CWESC1 = . if (CWESC1 >= 981 & CWESC1 <= 999)
replace CWESC2 = . if (CWESC2 >= 981 & CWESC2 <= 999)
replace FULLPART = . if (FULLPART >= 81 & FULLPART <= 99)
replace TOTPEOP = . if (TOTPEOP >= 81 & TOTPEOP <= 99)
replace SKPMHC = . if (SKPMHC == 9)
replace DEPRESS = . if (DEPRESS >= 81 & DEPRESS <= 99)
replace DEPDAYS = . if (DEPDAYS >= 81 & DEPDAYS <= 99)
replace DEPFREQ = . if (DEPFREQ >= 81 & DEPFREQ <= 99)
replace LOSTINT1 = . if (LOSTINT1 >= 81 & LOSTINT1 <= 99)
replace TIRED1 = . if (TIRED1 >= 81 & TIRED1 <= 99)
replace WTCHNG1 = . if (WTCHNG1 >= 81 & WTCHNG1 <= 99)
replace LBSCHNG1 = . if (LBSCHNG1 >= 981 & LBSCHNG1 <= 999)
replace SLPLOSS1 = . if (SLPLOSS1 >= 81 & SLPLOSS1 <= 99)
replace SLPFREQ1 = . if (SLPFREQ1 >= 81 & SLPFREQ1 <= 99)
replace CONCEN1 = . if (CONCEN1 >= 81 & CONCEN1 <= 99)
replace DOWN1 = . if (DOWN1 >= 81 & DOWN1 <= 99)
replace IDEAT1 = . if (IDEAT1 >= 81 & IDEAT1 <= 99)
replace SKPDEP1 = . if (SKPDEP1 >= 81 & SKPDEP1 <= 99)
replace DEPWKS1 = . if (DEPWKS1 >= 81 & DEPWKS1 <= 99)
replace DEPMO1 = . if (DEPMO1 >= 81 & DEPMO1 <= 99)
replace DEPYR1 = . if (DEPYR1 >= 981 & DEPYR1 <= 999)
replace LOSTINT2 = . if (LOSTINT2 >= 81 & LOSTINT2 <= 99)
replace LOSINDAY = . if (LOSINDAY >= 81 & LOSINDAY <= 99)
replace LOSINFRQ = . if (LOSINFRQ >= 81 & LOSINFRQ <= 99)
replace TIRED2 = . if (TIRED2 >= 81 & TIRED2 <= 99)
replace WTCHNG2 = . if (WTCHNG2 >= 81 & WTCHNG2 <= 99)
replace LBSCHNG2 = . if (LBSCHNG2 >= 981 & LBSCHNG2 <= 999)
replace SLPLOSS2 = . if (SLPLOSS2 >= 81 & SLPLOSS2 <= 99)
replace SLPFREQ2 = . if (SLPFREQ2 >= 81 & SLPFREQ2 <= 99)
replace CONCEN2 = . if (CONCEN2 >= 81 & CONCEN2 <= 99)
replace DOWN2 = . if (DOWN2 >= 81 & DOWN2 <= 99)
replace IDEAT2 = . if (IDEAT2 >= 81 & IDEAT2 <= 99)
replace SKPDEP2 = . if (SKPDEP2 >= 81 & SKPDEP2 <= 99)
replace DEPWKS2 = . if (DEPWKS2 >= 81 & DEPWKS2 <= 99)
replace DEPMO2 = . if (DEPMO2 >= 81 & DEPMO2 <= 99)
replace DEPYR2 = . if (DEPYR2 >= 981 & DEPYR2 <= 999)
replace WORRIED = . if (WORRIED >= 81 & WORRIED <= 99)
replace WOREND = . if (WOREND >= 81 & WOREND <= 99)
replace WORNOMO1 = . if (WORNOMO1 >= 9981 & WORNOMO1 <= 9999)
replace WORHAPN1 = . if (WORHAPN1 >= 81 & WORHAPN1 <= 99)
replace WORSERI1 = . if (WORSERI1 >= 81 & WORSERI1 <= 99)
replace WORDIFF1 = . if (WORDIFF1 >= 81 & WORDIFF1 <= 99)
replace WORNOMO2 = . if (WORNOMO2 >= 9981 & WORNOMO2 <= 9999)
replace WORHAPN2 = . if (WORHAPN2 >= 81 & WORHAPN2 <= 99)
replace WORSERI2 = . if (WORSERI2 >= 81 & WORSERI2 <= 99)
replace WORDIFF2 = . if (WORDIFF2 >= 81 & WORDIFF2 <= 99)
replace SKPWOR = . if (SKPWOR >= 81 & SKPWOR <= 99)
replace WORREST = . if (WORREST >= 81 & WORREST <= 99)
replace WOREDGE = . if (WOREDGE >= 81 & WOREDGE <= 99)
replace WORIRRIT = . if (WORIRRIT >= 81 & WORIRRIT <= 99)
replace WORHEART = . if (WORHEART >= 81 & WORHEART <= 99)
replace WORTIRED = . if (WORTIRED >= 81 & WORTIRED <= 99)
replace WORSLEEP = . if (WORSLEEP >= 81 & WORSLEEP <= 99)
replace WORFAINT = . if (WORFAINT >= 81 & WORFAINT <= 99)
replace FEARPUB = . if (FEARPUB >= 81 & FEARPUB <= 99)
replace FEAROUT = . if (FEAROUT >= 81 & FEAROUT <= 99)
replace FEARBRDG = . if (FEARBRDG >= 81 & FEARBRDG <= 99)
replace SKPFEAR1 = . if (SKPFEAR1 >= 81 & SKPFEAR1 <= 99)
replace FEAROFT = . if (FEAROFT >= 81 & FEAROFT <= 99)
replace FEARYRS = . if (FEARYRS >= 81 & FEARYRS <= 99)
replace FEARMOS = . if (FEARMOS >= 81 & FEARMOS <= 99)
replace FEARFANT = . if (FEARFANT >= 81 & FEARFANT <= 99)
replace FEARTRAP = . if (FEARTRAP >= 81 & FEARTRAP <= 99)
replace FEARHELP = . if (FEARHELP >= 81 & FEARHELP <= 99)
replace PANIC1 = . if (PANIC1 >= 81 & PANIC1 <= 99)
replace PANIC2 = . if (PANIC2 >= 81 & PANIC2 <= 99)
replace PANICNUM = . if (PANICNUM >= 981 & PANICNUM <= 999)
replace PANICMO = . if (PANICMO >= 81 & PANICMO <= 99)
replace PANICYR = . if (PANICYR >= 981 & PANICYR <= 999)
replace PANIDANG = . if (PANIDANG >= 81 & PANIDANG <= 99)
replace SKPFEAR2 = . if (SKPFEAR2 >= 81 & SKPFEAR2 <= 99)
replace PANIFEAR = . if (PANIFEAR >= 81 & PANIFEAR <= 99)
replace PANINOFR = . if (PANINOFR >= 81 & PANINOFR <= 99)
replace PANIHART = . if (PANIHART >= 81 & PANIHART <= 99)
replace PANIPAIN = . if (PANIPAIN >= 81 & PANIPAIN <= 99)
replace PANISWET = . if (PANISWET >= 81 & PANISWET <= 99)
replace PANISHAK = . if (PANISHAK >= 81 & PANISHAK <= 99)
replace PANIHOT = . if (PANIHOT >= 81 & PANIHOT <= 99)
replace PANIUNRL = . if (PANIUNRL >= 81 & PANIUNRL <= 99)
replace NUERTMT = . if (NUERTMT >= 81 & NUERTMT <= 99)
replace NUHSPOV = . if (NUHSPOV >= 81 & NUHSPOV <= 99)
replace NUHSPPE = . if (NUHSPPE >= 81 & NUHSPPE <= 99)
replace OUTPTPE = . if (OUTPTPE >= 81 & OUTPTPE <= 99)
replace PROXABLE = . if (PROXABLE >= 81 & PROXABLE <= 99)
replace PROXYREL = . if (PROXYREL >= 981 & PROXYREL <= 999)
replace PROXHOME = . if (PROXHOME >= 81 & PROXHOME <= 99)
replace PROXJOIN = . if (PROXJOIN >= 81 & PROXJOIN <= 99)
replace CAREUSU = . if (CAREUSU >= 81 & CAREUSU <= 99)
replace NCARERSN = . if (NCARERSN >= 81 & NCARERSN <= 99)
replace NCRRSNSP = . if (NCRRSNSP >= 81 & NCRRSNSP <= 99)
replace NCRRSNSC = . if (NCRRSNSC >= 81 & NCRRSNSC <= 99)
replace CAREOFT = . if (CAREOFT >= 81 & CAREOFT <= 99)
replace PYRCARE = . if (PYRCARE >= 81 & PYRCARE <= 99)
replace PYRCRTYP = . if (PYRCRTYP >= 81 & PYRCRTYP <= 99)
replace PYRCRTSP = . if (PYRCRTSP >= 81 & PYRCRTSP <= 99)
replace PYRCRTSC = . if (PYRCRTSC >= 81 & PYRCRTSC <= 99)
replace CARENOW = . if (CARENOW >= 81 & CARENOW <= 99)
replace MNRSNNCR = . if (MNRSNNCR >= 81 & MNRSNNCR <= 99)
replace MNRSNNSP = . if (MNRSNNSP >= 81 & MNRSNNSP <= 99)
replace MNRSNNSC = . if (MNRSNNSC >= 81 & MNRSNNSC <= 99)
replace UCARETYP = . if (UCARETYP >= 81 & UCARETYP <= 99)
replace UCRTYPSP = . if (UCRTYPSP >= 81 & UCRTYPSP <= 99)
replace UCRTYPSC = . if (UCRTYPSC >= 81 & UCRTYPSC <= 99)
replace MEDICARE = . if (MEDICARE >= 81 & MEDICARE <= 99)
replace MEDICAID = . if (MEDICAID >= 81 & MEDICAID <= 99)
replace CHAMPUS = . if (CHAMPUS >= 81 & CHAMPUS <= 99)
replace PRVHLTIN = . if (PRVHLTIN >= 81 & PRVHLTIN <= 99)
replace GRPHLTIN = . if (GRPHLTIN >= 81 & GRPHLTIN <= 99)
replace PDHINPRM = . if (PDHINPRM >= 81 & PDHINPRM <= 99)
replace HLTINALC = . if (HLTINALC >= 81 & HLTINALC <= 99)
replace HLTINDRG = . if (HLTINDRG >= 81 & HLTINDRG <= 99)
replace HLTINMNT = . if (HLTINMNT >= 81 & HLTINMNT <= 99)
replace SOC1 = . if (SOC1 >= 81 & SOC1 <= 99)
replace SOC2 = . if (SOC2 >= 81 & SOC2 <= 99)
replace SSI1 = . if (SSI1 >= 81 & SSI1 <= 99)
replace SSI2 = . if (SSI2 >= 81 & SSI2 <= 99)
replace PUB1 = . if (PUB1 >= 81 & PUB1 <= 99)
replace PUB2 = . if (PUB2 >= 81 & PUB2 <= 99)
replace AFDC = . if (AFDC >= 81 & AFDC <= 99)
replace INT1 = . if (INT1 >= 81 & INT1 <= 99)
replace INT2 = . if (INT2 >= 81 & INT2 <= 99)
replace CHD1 = . if (CHD1 >= 81 & CHD1 <= 99)
replace CHD2 = . if (CHD2 >= 81 & CHD2 <= 99)
replace OTH1 = . if (OTH1 >= 81 & OTH1 <= 99)
replace OTH2 = . if (OTH2 >= 81 & OTH2 <= 99)
replace FSTAMP = . if (FSTAMP >= 81 & FSTAMP <= 99)
replace PINC1 = . if (PINC1 >= 81 & PINC1 <= 99)
replace SKPTFMIN = . if (SKPTFMIN >= 81 & SKPTFMIN <= 99)
replace FINC1 = . if (FINC1 >= 81 & FINC1 <= 99)
replace TELNO = . if (TELNO >= 81 & TELNO <= 99)
replace IRAFDC = . if (IRAFDC >= 81 & IRAFDC <= 99)
replace IRFINC1 = . if (IRFINC1 >= 81 & IRFINC1 <= 99)
replace IRPEOP = . if (IRPEOP >= 81 & IRPEOP <= 99)
replace PREG2 = . if (PREG2 >= 81 & PREG2 <= 99)
replace TRIMEST = . if (TRIMEST >= 81 & TRIMEST <= 99)
replace INDCAT = . if (INDCAT >= 81 & INDCAT <= 99)
replace NEEDLREC = . if (NEEDLREC >= 81 & NEEDLREC <= 99)
replace WITHDRW = . if (WITHDRW >= 81 & WITHDRW <= 99)
replace SOMCOM = . if (SOMCOM >= 81 & SOMCOM <= 99)
replace ANXDEP = . if (ANXDEP >= 81 & ANXDEP <= 99)
replace SOCPROB = . if (SOCPROB >= 81 & SOCPROB <= 99)
replace THPROB = . if (THPROB >= 81 & THPROB <= 99)
replace ATTPROB = . if (ATTPROB >= 81 & ATTPROB <= 99)
replace DELBEH = . if (DELBEH >= 81 & DELBEH <= 99)
replace AGGBEH = . if (AGGBEH >= 81 & AGGBEH <= 99)
replace WITHDRWT = . if (WITHDRWT >= 981 & WITHDRWT <= 999)
replace SOMCOMT = . if (SOMCOMT >= 981 & SOMCOMT <= 999)
replace ANXDEPT = . if (ANXDEPT >= 981 & ANXDEPT <= 999)
replace SOCPROBT = . if (SOCPROBT >= 981 & SOCPROBT <= 999)
replace THPROBT = . if (THPROBT >= 981 & THPROBT <= 999)
replace ATTPROBT = . if (ATTPROBT >= 981 & ATTPROBT <= 999)
replace DELBEHT = . if (DELBEHT >= 981 & DELBEHT <= 999)
replace AGGBEHT = . if (AGGBEHT >= 981 & AGGBEHT <= 999)
replace MDESFS1 = . if (MDESFS1 >= 81 & MDESFS1 <= 99)
replace PROBMDE1 = . if (PROBMDE1 == 99.0000)
replace MDE1 = . if (MDE1 >= 81 & MDE1 <= 99)
replace GADSFS1 = . if (GADSFS1 >= 81 & GADSFS1 <= 99)
replace PROBGAD1 = . if (PROBGAD1 == 99.0000)
replace GAD1 = . if (GAD1 >= 81 & GAD1 <= 99)
replace AGPSFS1 = . if (AGPSFS1 >= 81 & AGPSFS1 <= 99)
replace PROBAGP1 = . if (PROBAGP1 >= 81 & PROBAGP1 <= 99)
replace AGP1 = . if (AGP1 >= 81 & AGP1 <= 99)
replace PASFS1 = . if (PASFS1 >= 81 & PASFS1 <= 99)
replace PROBPA1 = . if (PROBPA1 == 99.0000)
replace PA1 = . if (PA1 >= 81 & PA1 <= 99)
replace BHOUR = . if (BHOUR >= 81 & BHOUR <= 99)
replace BMIN = . if (BMIN >= 81 & BMIN <= 99)
replace BAP = . if (BAP >= 81 & BAP <= 99)
replace EAP = . if (EAP >= 81 & EAP <= 99)
replace UNDINT = . if (UNDINT >= 81 & UNDINT <= 99)
replace COOPINT = . if (COOPINT >= 81 & COOPINT <= 99)
replace PRIVACY = . if (PRIVACY >= 81 & PRIVACY <= 99)
replace PPRES = . if (PPRES >= 81 & PPRES <= 99)
replace SPRES = . if (SPRES >= 81 & SPRES <= 99)
replace PARPRES = . if (PARPRES >= 81 & PARPRES <= 99)
replace OARPRES = . if (OARPRES >= 81 & OARPRES <= 99)
replace OAPRES = . if (OAPRES >= 81 & OAPRES <= 99)
replace CPRES = . if (CPRES >= 81 & CPRES <= 99)
replace OPRESNSP = . if (OPRESNSP >= 81 & OPRESNSP <= 99)
replace OPRESSPA = . if (OPRESSPA >= 981 & OPRESSPA <= 999)
replace OPRESSPB = . if (OPRESSPB >= 981 & OPRESSPB <= 999)
replace WHOMARKD = . if (WHOMARKD >= 81 & WHOMARKD <= 99)
replace GQTYPE = . if (GQTYPE == 9)
replace ROCCUP2 = . if (ROCCUP2 >= 981 & ROCCUP2 <= 999)
replace BUSINES2 = . if (BUSINES2 >= 981 & BUSINES2 <= 999)
replace INTMONTH = . if (INTMONTH >= 81 & INTMONTH <= 99)
replace RELINTHH = . if (RELINTHH >= 81 & RELINTHH <= 99)
replace FERTAGE = . if (FERTAGE >= 81 & FERTAGE <= 99)
replace PREG3 = . if (PREG3 >= 81 & PREG3 <= 99)
replace TRIMEST2 = . if (TRIMEST2 >= 81 & TRIMEST2 <= 99)
replace MJTOT3 = . if (MJTOT3 >= 81 & MJTOT3 <= 99)
replace COCTOT3 = . if (COCTOT3 >= 81 & COCTOT3 <= 99)
replace AGECAT3 = . if (AGECAT3 >= 81 & AGECAT3 <= 99)
replace RACESEX = . if (RACESEX >= 81 & RACESEX <= 99)
replace ANY4MENT = . if (ANY4MENT >= 81 & ANY4MENT <= 99)
replace CIGTRY2 = . if (CIGTRY2 >= 81 & CIGTRY2 <= 99)
replace ALCTRY2 = . if (ALCTRY2 >= 81 & ALCTRY2 <= 99)
replace MJAGE2 = . if (MJAGE2 >= 81 & MJAGE2 <= 99)
replace INHAGE2 = . if (INHAGE2 >= 81 & INHAGE2 <= 99)
replace COCAGE2 = . if (COCAGE2 >= 81 & COCAGE2 <= 99)
replace HALLAGE2 = . if (HALLAGE2 >= 81 & HALLAGE2 <= 99)
replace HERAGE2 = . if (HERAGE2 >= 81 & HERAGE2 <= 99)
replace STIMAGE2 = . if (STIMAGE2 >= 81 & STIMAGE2 <= 99)
replace SEDAGE2 = . if (SEDAGE2 >= 81 & SEDAGE2 <= 99)
replace TRANAGE2 = . if (TRANAGE2 >= 81 & TRANAGE2 <= 99)
replace ANALAGE2 = . if (ANALAGE2 >= 81 & ANALAGE2 <= 99)
replace PSYAGE = . if (PSYAGE >= 81 & PSYAGE <= 99)
replace TOTPROB = . if (TOTPROB == 99.0000)
replace INT = . if (INT == 99.0000)
replace EXT = . if (EXT >= 81 & EXT <= 99)
replace PR_EMOT = . if (PR_EMOT >= 81 & PR_EMOT <= 99)
replace PR_BEHAV = . if (PR_BEHAV >= 81 & PR_BEHAV <= 99)
replace PR_TOTAL = . if (PR_TOTAL >= 81 & PR_TOTAL <= 99)
replace PR_WD = . if (PR_WD >= 81 & PR_WD <= 99)
replace PR_SC = . if (PR_SC >= 81 & PR_SC <= 99)
replace PR_AD = . if (PR_AD >= 81 & PR_AD <= 99)
replace PR_SP = . if (PR_SP >= 81 & PR_SP <= 99)
replace PR_TP = . if (PR_TP >= 81 & PR_TP <= 99)
replace PR_AP = . if (PR_AP >= 81 & PR_AP <= 99)
replace PR_DB = . if (PR_DB >= 81 & PR_DB <= 99)
replace PR_AB = . if (PR_AB >= 81 & PR_AB <= 99)
replace AGE = . if (AGE >= 81 & AGE <= 99)
replace EHOUR = . if (EHOUR >= 81 & EHOUR <= 99)
replace EMIN = . if (EMIN >= 81 & EMIN <= 99)
replace TOTCAT = . if (TOTCAT >= 81 & TOTCAT <= 99)


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

